@@ -1,20 +1,20 @@
 var group__PkgAlgebraicFoundationsAlgebraicStructuresConcepts =
 [
-    [ "Div", "classAlgebraicStructureTraits___1_1Div.html", [
+    [ "AlgebraicStructureTraits_::Div", "classAlgebraicStructureTraits___1_1Div.html", [
       [ "first_argument", "classAlgebraicStructureTraits___1_1Div.html#a2221f3a3836951b9bdafee575e5f5ec8", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1Div.html#ae57539dd8e7177c94aa78a5693925c7a", null ],
       [ "second_argument", "classAlgebraicStructureTraits___1_1Div.html#a78d65d1b2438fbb1ac10915daac71126", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1Div.html#a50b615fd0ccc54b00e13bf064f6d0cac", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1Div.html#ae62ca58dbd01d0c06680520669e82f26", null ]
     ] ],
-    [ "Divides", "classAlgebraicStructureTraits___1_1Divides.html", [
+    [ "AlgebraicStructureTraits_::Divides", "classAlgebraicStructureTraits___1_1Divides.html", [
       [ "first_argument", "classAlgebraicStructureTraits___1_1Divides.html#ac5f26801185bf8947b3ef6f28d838a44", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1Divides.html#af413e9f93587fe361aec9514d56330a5", null ],
       [ "second_argument", "classAlgebraicStructureTraits___1_1Divides.html#a9919fd99dfbfc6a1dbcd1e66d24908b5", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1Divides.html#a894373a9ddcc36f197b163b164329494", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1Divides.html#a4dd9d13ec48ff9deaedfb5b74f12362c", null ]
     ] ],
-    [ "DivMod", "classAlgebraicStructureTraits___1_1DivMod.html", [
+    [ "AlgebraicStructureTraits_::DivMod", "classAlgebraicStructureTraits___1_1DivMod.html", [
       [ "first_argument_type", "classAlgebraicStructureTraits___1_1DivMod.html#abcc093d3867c5350a149bf98e8c2c188", null ],
       [ "fourth_argument_type", "classAlgebraicStructureTraits___1_1DivMod.html#afba070def261ce586079b59e12154bd4", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1DivMod.html#a7f5812bce8f7421df0f667e88384bbe0", null ],
@@ -23,75 +23,75 @@ var group__PkgAlgebraicFoundationsAlgebraicStructuresConcepts =
       [ "operator()", "classAlgebraicStructureTraits___1_1DivMod.html#a951c607df9b988ac2295355449f408e3", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1DivMod.html#a020bac320f70e0ebed04ace7efe1b8e6", null ]
     ] ],
-    [ "Gcd", "classAlgebraicStructureTraits___1_1Gcd.html", [
+    [ "AlgebraicStructureTraits_::Gcd", "classAlgebraicStructureTraits___1_1Gcd.html", [
       [ "first_argument", "classAlgebraicStructureTraits___1_1Gcd.html#a676801de8d9ae688195ce442756ac2e8", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1Gcd.html#acb5efabe07f4b3b172cd674338ce5003", null ],
       [ "second_argument", "classAlgebraicStructureTraits___1_1Gcd.html#ac85beeefe39af598a32be86f1d96c9d0", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1Gcd.html#abef57d1e24f6d97e750908cf9c9b194c", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1Gcd.html#ae2786845462fa675eb176188ed319849", null ]
     ] ],
-    [ "IntegralDivision", "classAlgebraicStructureTraits___1_1IntegralDivision.html", [
+    [ "AlgebraicStructureTraits_::IntegralDivision", "classAlgebraicStructureTraits___1_1IntegralDivision.html", [
       [ "first_argument", "classAlgebraicStructureTraits___1_1IntegralDivision.html#af98cffe57f3c7fe8ed77ecab52df0aa2", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1IntegralDivision.html#a3659959e8714835321b0c6ad131dad8f", null ],
       [ "second_argument", "classAlgebraicStructureTraits___1_1IntegralDivision.html#a2304f1b96a789496d05ca75243970994", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1IntegralDivision.html#af7570840e1396d8bd08544e885f1cfd6", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1IntegralDivision.html#a420a8e28d6dc10c604c8cf08bed9a793", null ]
     ] ],
-    [ "Inverse", "classAlgebraicStructureTraits___1_1Inverse.html", [
+    [ "AlgebraicStructureTraits_::Inverse", "classAlgebraicStructureTraits___1_1Inverse.html", [
       [ "argument_type", "classAlgebraicStructureTraits___1_1Inverse.html#a7702d06468c32100e146ef8da2b19472", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1Inverse.html#a54a11ac9d007ddc03db35867d86a3085", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1Inverse.html#a95442535f1c161df8d28548f862df3f7", null ]
     ] ],
-    [ "IsOne", "classAlgebraicStructureTraits___1_1IsOne.html", [
+    [ "AlgebraicStructureTraits_::IsOne", "classAlgebraicStructureTraits___1_1IsOne.html", [
       [ "argument_type", "classAlgebraicStructureTraits___1_1IsOne.html#a7bc014d8825a73eb1b031f67daf4c4dd", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1IsOne.html#a14f6d9d8ad6039953f8506ead8569e30", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1IsOne.html#abeffbe7065a181d89589ab5596d76134", null ]
     ] ],
-    [ "IsSquare", "classAlgebraicStructureTraits___1_1IsSquare.html", [
+    [ "AlgebraicStructureTraits_::IsSquare", "classAlgebraicStructureTraits___1_1IsSquare.html", [
       [ "first_argument", "classAlgebraicStructureTraits___1_1IsSquare.html#af40e7da60471f9a4fcd631bbde8fbe4e", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1IsSquare.html#a3d6546c3a853b4f75bb422fe9ee144e3", null ],
       [ "second_argument", "classAlgebraicStructureTraits___1_1IsSquare.html#a361573058715fe7b8f4f2c1e2f425901", null ],
-      [ "operator()", "classAlgebraicStructureTraits___1_1IsSquare.html#a85b739b62782434f1d8fb5c49a65efa4", null ],
-      [ "operator()", "classAlgebraicStructureTraits___1_1IsSquare.html#a9c0862d97fdd0a027586a5a8fa9e94a8", null ]
+      [ "operator()", "classAlgebraicStructureTraits___1_1IsSquare.html#a9c0862d97fdd0a027586a5a8fa9e94a8", null ],
+      [ "operator()", "classAlgebraicStructureTraits___1_1IsSquare.html#a85b739b62782434f1d8fb5c49a65efa4", null ]
     ] ],
-    [ "IsZero", "classAlgebraicStructureTraits___1_1IsZero.html", [
+    [ "AlgebraicStructureTraits_::IsZero", "classAlgebraicStructureTraits___1_1IsZero.html", [
       [ "argument_type", "classAlgebraicStructureTraits___1_1IsZero.html#abfb287a1cd7b20b437b164825d266219", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1IsZero.html#a6762d007509576a7f6a3e7ff42aef30a", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1IsZero.html#a68e006df58e020bd9bff24cf08b35ac2", null ]
     ] ],
-    [ "KthRoot", "classAlgebraicStructureTraits___1_1KthRoot.html", [
+    [ "AlgebraicStructureTraits_::KthRoot", "classAlgebraicStructureTraits___1_1KthRoot.html", [
       [ "first_argument", "classAlgebraicStructureTraits___1_1KthRoot.html#a39e3b34abb036b0311c30aedf292f02f", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1KthRoot.html#a990ef50fc60d40f0fff5283c686c0178", null ],
       [ "second_argument", "classAlgebraicStructureTraits___1_1KthRoot.html#a251faca3a58a2263ec1c611c554cd5b0", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1KthRoot.html#ace1d1103059dabc20273c1acc1070dfb", null ]
     ] ],
-    [ "Mod", "classAlgebraicStructureTraits___1_1Mod.html", [
+    [ "AlgebraicStructureTraits_::Mod", "classAlgebraicStructureTraits___1_1Mod.html", [
       [ "first_argument", "classAlgebraicStructureTraits___1_1Mod.html#a619487891d17aa5f755a07a50147fb4e", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1Mod.html#a460bd0a3530426124961960248044117", null ],
       [ "second_argument", "classAlgebraicStructureTraits___1_1Mod.html#af468d3fe837d706b2dbb994160bc1919", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1Mod.html#a05af77fd4857f21b8244de89c1410db2", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1Mod.html#a58e5c4fc931e264af481925be8d5154d", null ]
     ] ],
-    [ "RootOf", "classAlgebraicStructureTraits___1_1RootOf.html", [
+    [ "AlgebraicStructureTraits_::RootOf", "classAlgebraicStructureTraits___1_1RootOf.html", [
       [ "result_type", "classAlgebraicStructureTraits___1_1RootOf.html#a23626dec71c1eb9ee1eb07f8037d9759", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1RootOf.html#a8afe44f0aa412f53fd9e6c30022332fb", null ]
     ] ],
-    [ "Simplify", "classAlgebraicStructureTraits___1_1Simplify.html", [
+    [ "AlgebraicStructureTraits_::Simplify", "classAlgebraicStructureTraits___1_1Simplify.html", [
       [ "argument_type", "classAlgebraicStructureTraits___1_1Simplify.html#a5b7c08fab4b3ff4831919a441bfdcab3", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1Simplify.html#ace2ad38da4137bcc07d3bf66ec94a21a", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1Simplify.html#a13de5333d1b28d84d72e7f844d6e8cbd", null ]
     ] ],
-    [ "Sqrt", "classAlgebraicStructureTraits___1_1Sqrt.html", [
+    [ "AlgebraicStructureTraits_::Sqrt", "classAlgebraicStructureTraits___1_1Sqrt.html", [
       [ "argument_type", "classAlgebraicStructureTraits___1_1Sqrt.html#a1b7bc3270986a590eaa9a51172cc750b", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1Sqrt.html#af619aa536f6667011a57a3fa0391e56e", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1Sqrt.html#aaa63418d66a8fde815a8993f0bfb4460", null ]
     ] ],
-    [ "Square", "classAlgebraicStructureTraits___1_1Square.html", [
+    [ "AlgebraicStructureTraits_::Square", "classAlgebraicStructureTraits___1_1Square.html", [
       [ "argument_type", "classAlgebraicStructureTraits___1_1Square.html#ad72b6cd210856f4562174adaa2a99710", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1Square.html#a27385598eb988e99c47567dd2962685d", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1Square.html#ae1fc4ee05f97903a8892bd0bed0691fc", null ]
     ] ],
-    [ "UnitPart", "classAlgebraicStructureTraits___1_1UnitPart.html", [
+    [ "AlgebraicStructureTraits_::UnitPart", "classAlgebraicStructureTraits___1_1UnitPart.html", [
       [ "argument_type", "classAlgebraicStructureTraits___1_1UnitPart.html#a184ddeb1eeec0588fe2a81af52d67e44", null ],
       [ "result_type", "classAlgebraicStructureTraits___1_1UnitPart.html#a39695b4d0a024a5c55d4bbbb1a94e402", null ],
       [ "operator()", "classAlgebraicStructureTraits___1_1UnitPart.html#a934d25a64731dd1363ac9a68c2342fc9", null ]
@@ -120,6 +120,7 @@ var group__PkgAlgebraicFoundationsAlgebraicStructuresConcepts =
       [ "Unit_part", "classAlgebraicStructureTraits.html#aba5aea58a3a31be5f487a6bb1f7cf8e3", null ]
     ] ],
     [ "EuclideanRing", "classEuclideanRing.html", null ],
+    [ "ExplicitInteroperable", "classExplicitInteroperable.html", null ],
     [ "Field", "classField.html", [
       [ "operator/", "classField.html#a1baae2f982f216711eb1c81f2a291073", null ],
       [ "operator/=", "classField.html#ad5dada1c263f0af611819bb0dfe7ccab", null ]
@@ -128,6 +129,7 @@ var group__PkgAlgebraicFoundationsAlgebraicStructuresConcepts =
     [ "FieldWithKthRoot", "classFieldWithKthRoot.html", null ],
     [ "FieldWithRootOf", "classFieldWithRootOf.html", null ],
     [ "FieldWithSqrt", "classFieldWithSqrt.html", null ],
+    [ "Fraction", "classFraction.html", null ],
     [ "FractionTraits", "classFractionTraits.html", [
       [ "Common_factor", "classFractionTraits.html#abc51eea7ae3ec76c3e51c118a2fc32f9", null ],
       [ "Compose", "classFractionTraits.html#a899f5bf1642e5efa1f217086e9722202", null ],
@@ -137,21 +139,28 @@ var group__PkgAlgebraicFoundationsAlgebraicStructuresConcepts =
       [ "Numerator_type", "classFractionTraits.html#a994af73edb9982c0db266d5e5edf4eca", null ],
       [ "Type", "classFractionTraits.html#a22f07042a7c69a887e0a30856109fcd7", null ]
     ] ],
-    [ "Decompose", "classFractionTraits___1_1Decompose.html", [
+    [ "FractionTraits_::Decompose", "classFractionTraits___1_1Decompose.html", [
       [ "operator()", "classFractionTraits___1_1Decompose.html#a3e695a259b83a3493160b1591276e413", null ]
     ] ],
-    [ "Compose", "classFractionTraits___1_1Compose.html", [
+    [ "FractionTraits_::Compose", "classFractionTraits___1_1Compose.html", [
       [ "first_argument_type", "classFractionTraits___1_1Compose.html#ac472c25ba7f6889d28af664287080309", null ],
       [ "result_type", "classFractionTraits___1_1Compose.html#acddcdeaf38508f6887eec1dd4e5aaa94", null ],
       [ "second_argument_type", "classFractionTraits___1_1Compose.html#ade236be9d1242c211e321c7b1ae853cf", null ],
       [ "operator()", "classFractionTraits___1_1Compose.html#a3b539af773ff86277ab82a70b393a103", null ]
     ] ],
-    [ "CommonFactor", "classFractionTraits___1_1CommonFactor.html", [
+    [ "FractionTraits_::CommonFactor", "classFractionTraits___1_1CommonFactor.html", [
       [ "first_argument_type", "classFractionTraits___1_1CommonFactor.html#a02c7723971e8d5c6f7fc5fcb4e1f2573", null ],
       [ "result_type", "classFractionTraits___1_1CommonFactor.html#a2c184af1fa1224405edb51b6caf4cfc2", null ],
       [ "second_argument_type", "classFractionTraits___1_1CommonFactor.html#ac43c388e2596c70128b2e318892d0170", null ],
       [ "operator()", "classFractionTraits___1_1CommonFactor.html#a2ca26745ec123de09fa8f9afaab4f069", null ]
     ] ],
+    [ "FromDoubleConstructible", "classFromDoubleConstructible.html", [
+      [ "FromDoubleConstructible", "classFromDoubleConstructible.html#ab65518892628c4304ba3da7cf3b7ec89", null ]
+    ] ],
+    [ "FromIntConstructible", "classFromIntConstructible.html", [
+      [ "FromIntConstructible", "classFromIntConstructible.html#a1d9607b44c2f1aa950e293de20364f90", null ]
+    ] ],
+    [ "ImplicitInteroperable", "classImplicitInteroperable.html", null ],
     [ "IntegralDomain", "classIntegralDomain.html", null ],
     [ "IntegralDomainWithoutDivision", "classIntegralDomainWithoutDivision.html", [
       [ "operator!=", "classIntegralDomainWithoutDivision.html#ad6321a6e2922e02f8f177530058f35f8", null ],
@@ -173,44 +182,44 @@ var group__PkgAlgebraicFoundationsAlgebraicStructuresConcepts =
       [ "operator>", "classRealEmbeddable.html#a3ee88fbcdfce6ccc6bf55add5854ee19", null ],
       [ "operator>=", "classRealEmbeddable.html#a2829e52e7fe3a31fdeee6d2756b1fc54", null ]
     ] ],
-    [ "Abs", "classRealEmbeddableTraits___1_1Abs.html", [
+    [ "RealEmbeddableTraits_::Abs", "classRealEmbeddableTraits___1_1Abs.html", [
       [ "argument_type", "classRealEmbeddableTraits___1_1Abs.html#a2663d046297f52b3c33a28bde1f51e49", null ],
       [ "result_type", "classRealEmbeddableTraits___1_1Abs.html#adf23d11ae6130442a3f24b1b4a0a766f", null ],
       [ "operator()", "classRealEmbeddableTraits___1_1Abs.html#a6ab03b06cdad48a8fe61d208bfbfba9b", null ]
     ] ],
-    [ "Compare", "classRealEmbeddableTraits___1_1Compare.html", [
+    [ "RealEmbeddableTraits_::Compare", "classRealEmbeddableTraits___1_1Compare.html", [
       [ "first_argument_type", "classRealEmbeddableTraits___1_1Compare.html#a8013b3ae0d6eea44f2bf8401dd8c31a4", null ],
       [ "result_type", "classRealEmbeddableTraits___1_1Compare.html#abe4b885a8c81de120deb70667674dd70", null ],
       [ "second_argument_type", "classRealEmbeddableTraits___1_1Compare.html#af47942a3440079fc3cc95c6bf7286793", null ],
       [ "operator()", "classRealEmbeddableTraits___1_1Compare.html#a514211dbc535d3809879e4b1b89b2d07", null ],
       [ "operator()", "classRealEmbeddableTraits___1_1Compare.html#ab02eeba3ed342181950e06d97b24b154", null ]
     ] ],
-    [ "IsNegative", "classRealEmbeddableTraits___1_1IsNegative.html", [
+    [ "RealEmbeddableTraits_::IsNegative", "classRealEmbeddableTraits___1_1IsNegative.html", [
       [ "argument_type", "classRealEmbeddableTraits___1_1IsNegative.html#a9e2258cb8bb32bc3f46ce962c3891d51", null ],
       [ "result_type", "classRealEmbeddableTraits___1_1IsNegative.html#abb98fe614cc7ec915564136db6388122", null ],
       [ "operator()", "classRealEmbeddableTraits___1_1IsNegative.html#a88eeb00a38a70fcf460efc29ca3cbd05", null ]
     ] ],
-    [ "IsPositive", "classRealEmbeddableTraits___1_1IsPositive.html", [
+    [ "RealEmbeddableTraits_::IsPositive", "classRealEmbeddableTraits___1_1IsPositive.html", [
       [ "argument_type", "classRealEmbeddableTraits___1_1IsPositive.html#a5e346c3f7cf73e30ef47e59d6caa9eda", null ],
       [ "result_type", "classRealEmbeddableTraits___1_1IsPositive.html#a4ca0199b09d3db0d474db7a5bc02231e", null ],
       [ "operator()", "classRealEmbeddableTraits___1_1IsPositive.html#a91a43194a8a04e3b99742a5c86dc68c7", null ]
     ] ],
-    [ "IsZero", "classRealEmbeddableTraits___1_1IsZero.html", [
+    [ "RealEmbeddableTraits_::IsZero", "classRealEmbeddableTraits___1_1IsZero.html", [
       [ "argument_type", "classRealEmbeddableTraits___1_1IsZero.html#a839a7e420c1f5220ec0b994d120db152", null ],
       [ "result_type", "classRealEmbeddableTraits___1_1IsZero.html#a0ff48b66d480aa82a00109a5c991c915", null ],
       [ "operator()", "classRealEmbeddableTraits___1_1IsZero.html#af00539ff4e7fc3505b319b45b37ac5dd", null ]
     ] ],
-    [ "Sgn", "classRealEmbeddableTraits___1_1Sgn.html", [
+    [ "RealEmbeddableTraits_::Sgn", "classRealEmbeddableTraits___1_1Sgn.html", [
       [ "argument_type", "classRealEmbeddableTraits___1_1Sgn.html#a88885e3526ee996666dbe51e408479a1", null ],
       [ "result_type", "classRealEmbeddableTraits___1_1Sgn.html#a9f4e9e6a395589b733bba7873698c453", null ],
       [ "operator()", "classRealEmbeddableTraits___1_1Sgn.html#a7dc091f8662b0647f1d78b260fc64817", null ]
     ] ],
-    [ "ToDouble", "classRealEmbeddableTraits___1_1ToDouble.html", [
+    [ "RealEmbeddableTraits_::ToDouble", "classRealEmbeddableTraits___1_1ToDouble.html", [
       [ "argument_type", "classRealEmbeddableTraits___1_1ToDouble.html#a8a063a081876976aaab1a59eeebca103", null ],
       [ "result_type", "classRealEmbeddableTraits___1_1ToDouble.html#aea2ee18b1bc796915c09c0f6e3b91562", null ],
       [ "operator()", "classRealEmbeddableTraits___1_1ToDouble.html#a3dbe90a1454061c54b8f81c686e7e4c4", null ]
     ] ],
-    [ "ToInterval", "classRealEmbeddableTraits___1_1ToInterval.html", [
+    [ "RealEmbeddableTraits_::ToInterval", "classRealEmbeddableTraits___1_1ToInterval.html", [
       [ "argument_type", "classRealEmbeddableTraits___1_1ToInterval.html#a6fcd3b15f44329dd8fdc3d57924d5139", null ],
       [ "result_type", "classRealEmbeddableTraits___1_1ToInterval.html#a45d2eca50b930e649a6792b1bfa933ce", null ],
       [ "operator()", "classRealEmbeddableTraits___1_1ToInterval.html#aae57c5ca9a9d4faa615d663e9ffee628", null ]
