@@ -1,13 +1,13 @@
 var NAVTREEINDEX0 =
 {
 "AlgebraicFoundationsClassified.html":[2],
-"Algebraic_foundations_2algebraic_structure_dispatch_8cpp-example.html":[7,0],
-"Algebraic_foundations_2fraction_traits_8cpp-example.html":[7,1],
-"Algebraic_foundations_2implicit_interoperable_dispatch_8cpp-example.html":[7,2],
-"Algebraic_foundations_2integralize_8cpp-example.html":[7,3],
-"Algebraic_foundations_2interoperable_8cpp-example.html":[7,4],
-"annotated.html":[6],
-"citelist.html":[5],
+"Algebraic_foundations_2algebraic_structure_dispatch_8cpp-example.html":[5,0],
+"Algebraic_foundations_2fraction_traits_8cpp-example.html":[5,1],
+"Algebraic_foundations_2implicit_interoperable_dispatch_8cpp-example.html":[5,2],
+"Algebraic_foundations_2integralize_8cpp-example.html":[5,3],
+"Algebraic_foundations_2interoperable_8cpp-example.html":[5,4],
+"annotated.html":[4],
+"citelist.html":[3],
 "classAlgebraicStructureTraits.html":[1,0,0,16],
 "classAlgebraicStructureTraits.html#a0f3982b5d79f3d1e20da27c04950c946":[1,0,0,16,4],
 "classAlgebraicStructureTraits.html#a1330587c996aa714eea4a314ecc42c6f":[1,0,0,16,7],
@@ -73,8 +73,8 @@ var NAVTREEINDEX0 =
 "classAlgebraicStructureTraits___1_1IsSquare.html":[1,0,0,7],
 "classAlgebraicStructureTraits___1_1IsSquare.html#a361573058715fe7b8f4f2c1e2f425901":[1,0,0,7,2],
 "classAlgebraicStructureTraits___1_1IsSquare.html#a3d6546c3a853b4f75bb422fe9ee144e3":[1,0,0,7,1],
-"classAlgebraicStructureTraits___1_1IsSquare.html#a85b739b62782434f1d8fb5c49a65efa4":[1,0,0,7,3],
-"classAlgebraicStructureTraits___1_1IsSquare.html#a9c0862d97fdd0a027586a5a8fa9e94a8":[1,0,0,7,4],
+"classAlgebraicStructureTraits___1_1IsSquare.html#a85b739b62782434f1d8fb5c49a65efa4":[1,0,0,7,4],
+"classAlgebraicStructureTraits___1_1IsSquare.html#a9c0862d97fdd0a027586a5a8fa9e94a8":[1,0,0,7,3],
 "classAlgebraicStructureTraits___1_1IsSquare.html#af40e7da60471f9a4fcd631bbde8fbe4e":[1,0,0,7,0],
 "classAlgebraicStructureTraits___1_1IsZero.html":[1,0,0,8],
 "classAlgebraicStructureTraits___1_1IsZero.html#a6762d007509576a7f6a3e7ff42aef30a":[1,0,0,8,1],
@@ -114,110 +114,110 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Fraction__traits.html":[1,0,11],
 "classCGAL_1_1Real__embeddable__traits.html":[1,0,12],
 "classEuclideanRing.html":[1,0,0,17],
-"classExplicitInteroperable.html":[6,6],
-"classField.html":[1,0,0,18],
-"classField.html#a1baae2f982f216711eb1c81f2a291073":[1,0,0,18,0],
-"classField.html#ad5dada1c263f0af611819bb0dfe7ccab":[1,0,0,18,1],
-"classFieldNumberType.html":[1,0,0,19],
-"classFieldWithKthRoot.html":[1,0,0,20],
-"classFieldWithRootOf.html":[1,0,0,21],
-"classFieldWithSqrt.html":[1,0,0,22],
-"classFraction.html":[6,12],
-"classFractionTraits.html":[1,0,0,23],
-"classFractionTraits.html#a22f07042a7c69a887e0a30856109fcd7":[1,0,0,23,6],
-"classFractionTraits.html#a41958a4848767bbbfe142895d21765d3":[1,0,0,23,3],
-"classFractionTraits.html#a7bd114852e8c6b65655dc70e62ab1df0":[1,0,0,23,2],
-"classFractionTraits.html#a899f5bf1642e5efa1f217086e9722202":[1,0,0,23,1],
-"classFractionTraits.html#a994af73edb9982c0db266d5e5edf4eca":[1,0,0,23,5],
-"classFractionTraits.html#abc51eea7ae3ec76c3e51c118a2fc32f9":[1,0,0,23,0],
-"classFractionTraits.html#adccf11bdb413fee30cb4f229c9450ee7":[1,0,0,23,4],
-"classFractionTraits___1_1CommonFactor.html":[1,0,0,26],
-"classFractionTraits___1_1CommonFactor.html#a02c7723971e8d5c6f7fc5fcb4e1f2573":[1,0,0,26,0],
-"classFractionTraits___1_1CommonFactor.html#a2c184af1fa1224405edb51b6caf4cfc2":[1,0,0,26,1],
-"classFractionTraits___1_1CommonFactor.html#a2ca26745ec123de09fa8f9afaab4f069":[1,0,0,26,3],
-"classFractionTraits___1_1CommonFactor.html#ac43c388e2596c70128b2e318892d0170":[1,0,0,26,2],
-"classFractionTraits___1_1Compose.html":[1,0,0,25],
-"classFractionTraits___1_1Compose.html#a3b539af773ff86277ab82a70b393a103":[1,0,0,25,3],
-"classFractionTraits___1_1Compose.html#ac472c25ba7f6889d28af664287080309":[1,0,0,25,0],
-"classFractionTraits___1_1Compose.html#acddcdeaf38508f6887eec1dd4e5aaa94":[1,0,0,25,1],
-"classFractionTraits___1_1Compose.html#ade236be9d1242c211e321c7b1ae853cf":[1,0,0,25,2],
-"classFractionTraits___1_1Decompose.html":[1,0,0,24],
-"classFractionTraits___1_1Decompose.html#a3e695a259b83a3493160b1591276e413":[1,0,0,24,0],
-"classFromDoubleConstructible.html":[6,14],
-"classFromDoubleConstructible.html#ab65518892628c4304ba3da7cf3b7ec89":[6,14,0],
-"classFromIntConstructible.html":[6,15],
-"classFromIntConstructible.html#a1d9607b44c2f1aa950e293de20364f90":[6,15,0],
-"classImplicitInteroperable.html":[6,16],
-"classIntegralDomain.html":[1,0,0,27],
-"classIntegralDomainWithoutDivision.html":[1,0,0,28],
-"classIntegralDomainWithoutDivision.html#a286c309332a7ccf0f8c767875a076af2":[1,0,0,28,5],
-"classIntegralDomainWithoutDivision.html#a3f6ae6a9fa48d907e0e60e7671cc2d4f":[1,0,0,28,6],
-"classIntegralDomainWithoutDivision.html#a557348392cee4109ef7b21c9a25eb576":[1,0,0,28,7],
-"classIntegralDomainWithoutDivision.html#a6e29e776672c831928bd2f920c446bd4":[1,0,0,28,9],
-"classIntegralDomainWithoutDivision.html#a844e5abb25ff58c78e3c7cda682d26ec":[1,0,0,28,2],
-"classIntegralDomainWithoutDivision.html#ab8e7ca0c415200f346bc851867715e30":[1,0,0,28,4],
-"classIntegralDomainWithoutDivision.html#ac28ce58cc26b6ccfb65667b1b38e9605":[1,0,0,28,1],
-"classIntegralDomainWithoutDivision.html#ad6321a6e2922e02f8f177530058f35f8":[1,0,0,28,0],
-"classIntegralDomainWithoutDivision.html#ade891fa308266c824b3aa9071b5f17ff":[1,0,0,28,8],
-"classIntegralDomainWithoutDivision.html#ae4cb9ba3cf18a1635f1e29c91a45f86e":[1,0,0,28,3],
-"classRealEmbeddable.html":[1,0,0,29],
-"classRealEmbeddable.html#a0f3f72df36199c34fecb093ae1ddf600":[1,0,0,29,0],
-"classRealEmbeddable.html#a2829e52e7fe3a31fdeee6d2756b1fc54":[1,0,0,29,5],
-"classRealEmbeddable.html#a3b639b62203afd58df9628820b160fbd":[1,0,0,29,2],
-"classRealEmbeddable.html#a3ee88fbcdfce6ccc6bf55add5854ee19":[1,0,0,29,4],
-"classRealEmbeddable.html#a4255c5fbbeeb0d3c0f685eddcb63afb8":[1,0,0,29,3],
-"classRealEmbeddable.html#a8260145d1e674a44028f8e1a0f3ef14f":[1,0,0,29,1],
-"classRealEmbeddableTraits.html":[1,0,0,38],
-"classRealEmbeddableTraits.html#a0f5fd64e004f097e44b5c5471db4f1cf":[1,0,0,38,4],
-"classRealEmbeddableTraits.html#a155667c6a84d3f92507f10ceeae38f47":[1,0,0,38,8],
-"classRealEmbeddableTraits.html#a1d0fd786282a78583addec6d759302ff":[1,0,0,38,9],
-"classRealEmbeddableTraits.html#a3a39c123ba2ae0844410ff78578d25f8":[1,0,0,38,5],
-"classRealEmbeddableTraits.html#a4786e99294cd21185a554c31f1b43282":[1,0,0,38,7],
-"classRealEmbeddableTraits.html#a529776d3dbb51ad44f171ee7e20e672a":[1,0,0,38,1],
-"classRealEmbeddableTraits.html#a74642a286b40aacb1145cac62dbfc066":[1,0,0,38,11],
-"classRealEmbeddableTraits.html#aa0be471ad6efa53832dbc97e5cb29348":[1,0,0,38,2],
-"classRealEmbeddableTraits.html#aa3e78d202789fed4a9b9ebe988ef0a71":[1,0,0,38,10],
-"classRealEmbeddableTraits.html#abc1b87bea2e996aa49793f5e1717908d":[1,0,0,38,3],
-"classRealEmbeddableTraits.html#ac9d15d1c8eb2068021c42c016888c526":[1,0,0,38,0],
-"classRealEmbeddableTraits.html#accb6b922ae1f36fa684f552dcd668271":[1,0,0,38,6],
-"classRealEmbeddableTraits.html#aeb25ed0ddd16efdcf2126f6019b1a469":[1,0,0,38,12],
-"classRealEmbeddableTraits___1_1Abs.html":[1,0,0,30],
-"classRealEmbeddableTraits___1_1Abs.html#a2663d046297f52b3c33a28bde1f51e49":[1,0,0,30,0],
-"classRealEmbeddableTraits___1_1Abs.html#a6ab03b06cdad48a8fe61d208bfbfba9b":[1,0,0,30,2],
-"classRealEmbeddableTraits___1_1Abs.html#adf23d11ae6130442a3f24b1b4a0a766f":[1,0,0,30,1],
-"classRealEmbeddableTraits___1_1Compare.html":[1,0,0,31],
-"classRealEmbeddableTraits___1_1Compare.html#a514211dbc535d3809879e4b1b89b2d07":[1,0,0,31,3],
-"classRealEmbeddableTraits___1_1Compare.html#a8013b3ae0d6eea44f2bf8401dd8c31a4":[1,0,0,31,0],
-"classRealEmbeddableTraits___1_1Compare.html#ab02eeba3ed342181950e06d97b24b154":[1,0,0,31,4],
-"classRealEmbeddableTraits___1_1Compare.html#abe4b885a8c81de120deb70667674dd70":[1,0,0,31,1],
-"classRealEmbeddableTraits___1_1Compare.html#af47942a3440079fc3cc95c6bf7286793":[1,0,0,31,2],
-"classRealEmbeddableTraits___1_1IsNegative.html":[1,0,0,32],
-"classRealEmbeddableTraits___1_1IsNegative.html#a88eeb00a38a70fcf460efc29ca3cbd05":[1,0,0,32,2],
-"classRealEmbeddableTraits___1_1IsNegative.html#a9e2258cb8bb32bc3f46ce962c3891d51":[1,0,0,32,0],
-"classRealEmbeddableTraits___1_1IsNegative.html#abb98fe614cc7ec915564136db6388122":[1,0,0,32,1],
-"classRealEmbeddableTraits___1_1IsPositive.html":[1,0,0,33],
-"classRealEmbeddableTraits___1_1IsPositive.html#a4ca0199b09d3db0d474db7a5bc02231e":[1,0,0,33,1],
-"classRealEmbeddableTraits___1_1IsPositive.html#a5e346c3f7cf73e30ef47e59d6caa9eda":[1,0,0,33,0],
-"classRealEmbeddableTraits___1_1IsPositive.html#a91a43194a8a04e3b99742a5c86dc68c7":[1,0,0,33,2],
-"classRealEmbeddableTraits___1_1IsZero.html":[1,0,0,34],
-"classRealEmbeddableTraits___1_1IsZero.html#a0ff48b66d480aa82a00109a5c991c915":[1,0,0,34,1],
-"classRealEmbeddableTraits___1_1IsZero.html#a839a7e420c1f5220ec0b994d120db152":[1,0,0,34,0],
-"classRealEmbeddableTraits___1_1IsZero.html#af00539ff4e7fc3505b319b45b37ac5dd":[1,0,0,34,2],
-"classRealEmbeddableTraits___1_1Sgn.html":[1,0,0,35],
-"classRealEmbeddableTraits___1_1Sgn.html#a7dc091f8662b0647f1d78b260fc64817":[1,0,0,35,2],
-"classRealEmbeddableTraits___1_1Sgn.html#a88885e3526ee996666dbe51e408479a1":[1,0,0,35,0],
-"classRealEmbeddableTraits___1_1Sgn.html#a9f4e9e6a395589b733bba7873698c453":[1,0,0,35,1],
-"classRealEmbeddableTraits___1_1ToDouble.html":[1,0,0,36],
-"classRealEmbeddableTraits___1_1ToDouble.html#a3dbe90a1454061c54b8f81c686e7e4c4":[1,0,0,36,2],
-"classRealEmbeddableTraits___1_1ToDouble.html#a8a063a081876976aaab1a59eeebca103":[1,0,0,36,0],
-"classRealEmbeddableTraits___1_1ToDouble.html#aea2ee18b1bc796915c09c0f6e3b91562":[1,0,0,36,1],
-"classRealEmbeddableTraits___1_1ToInterval.html":[1,0,0,37],
-"classRealEmbeddableTraits___1_1ToInterval.html#a45d2eca50b930e649a6792b1bfa933ce":[1,0,0,37,1],
-"classRealEmbeddableTraits___1_1ToInterval.html#a6fcd3b15f44329dd8fdc3d57924d5139":[1,0,0,37,0],
-"classRealEmbeddableTraits___1_1ToInterval.html#aae57c5ca9a9d4faa615d663e9ffee628":[1,0,0,37,2],
-"classRingNumberType.html":[1,0,0,39],
-"classUniqueFactorizationDomain.html":[1,0,0,40],
-"examples.html":[7],
+"classExplicitInteroperable.html":[1,0,0,18],
+"classField.html":[1,0,0,19],
+"classField.html#a1baae2f982f216711eb1c81f2a291073":[1,0,0,19,0],
+"classField.html#ad5dada1c263f0af611819bb0dfe7ccab":[1,0,0,19,1],
+"classFieldNumberType.html":[1,0,0,20],
+"classFieldWithKthRoot.html":[1,0,0,21],
+"classFieldWithRootOf.html":[1,0,0,22],
+"classFieldWithSqrt.html":[1,0,0,23],
+"classFraction.html":[1,0,0,24],
+"classFractionTraits.html":[1,0,0,25],
+"classFractionTraits.html#a22f07042a7c69a887e0a30856109fcd7":[1,0,0,25,6],
+"classFractionTraits.html#a41958a4848767bbbfe142895d21765d3":[1,0,0,25,3],
+"classFractionTraits.html#a7bd114852e8c6b65655dc70e62ab1df0":[1,0,0,25,2],
+"classFractionTraits.html#a899f5bf1642e5efa1f217086e9722202":[1,0,0,25,1],
+"classFractionTraits.html#a994af73edb9982c0db266d5e5edf4eca":[1,0,0,25,5],
+"classFractionTraits.html#abc51eea7ae3ec76c3e51c118a2fc32f9":[1,0,0,25,0],
+"classFractionTraits.html#adccf11bdb413fee30cb4f229c9450ee7":[1,0,0,25,4],
+"classFractionTraits___1_1CommonFactor.html":[1,0,0,28],
+"classFractionTraits___1_1CommonFactor.html#a02c7723971e8d5c6f7fc5fcb4e1f2573":[1,0,0,28,0],
+"classFractionTraits___1_1CommonFactor.html#a2c184af1fa1224405edb51b6caf4cfc2":[1,0,0,28,1],
+"classFractionTraits___1_1CommonFactor.html#a2ca26745ec123de09fa8f9afaab4f069":[1,0,0,28,3],
+"classFractionTraits___1_1CommonFactor.html#ac43c388e2596c70128b2e318892d0170":[1,0,0,28,2],
+"classFractionTraits___1_1Compose.html":[1,0,0,27],
+"classFractionTraits___1_1Compose.html#a3b539af773ff86277ab82a70b393a103":[1,0,0,27,3],
+"classFractionTraits___1_1Compose.html#ac472c25ba7f6889d28af664287080309":[1,0,0,27,0],
+"classFractionTraits___1_1Compose.html#acddcdeaf38508f6887eec1dd4e5aaa94":[1,0,0,27,1],
+"classFractionTraits___1_1Compose.html#ade236be9d1242c211e321c7b1ae853cf":[1,0,0,27,2],
+"classFractionTraits___1_1Decompose.html":[1,0,0,26],
+"classFractionTraits___1_1Decompose.html#a3e695a259b83a3493160b1591276e413":[1,0,0,26,0],
+"classFromDoubleConstructible.html":[1,0,0,29],
+"classFromDoubleConstructible.html#ab65518892628c4304ba3da7cf3b7ec89":[1,0,0,29,0],
+"classFromIntConstructible.html":[1,0,0,30],
+"classFromIntConstructible.html#a1d9607b44c2f1aa950e293de20364f90":[1,0,0,30,0],
+"classImplicitInteroperable.html":[1,0,0,31],
+"classIntegralDomain.html":[1,0,0,32],
+"classIntegralDomainWithoutDivision.html":[1,0,0,33],
+"classIntegralDomainWithoutDivision.html#a286c309332a7ccf0f8c767875a076af2":[1,0,0,33,5],
+"classIntegralDomainWithoutDivision.html#a3f6ae6a9fa48d907e0e60e7671cc2d4f":[1,0,0,33,6],
+"classIntegralDomainWithoutDivision.html#a557348392cee4109ef7b21c9a25eb576":[1,0,0,33,7],
+"classIntegralDomainWithoutDivision.html#a6e29e776672c831928bd2f920c446bd4":[1,0,0,33,9],
+"classIntegralDomainWithoutDivision.html#a844e5abb25ff58c78e3c7cda682d26ec":[1,0,0,33,2],
+"classIntegralDomainWithoutDivision.html#ab8e7ca0c415200f346bc851867715e30":[1,0,0,33,4],
+"classIntegralDomainWithoutDivision.html#ac28ce58cc26b6ccfb65667b1b38e9605":[1,0,0,33,1],
+"classIntegralDomainWithoutDivision.html#ad6321a6e2922e02f8f177530058f35f8":[1,0,0,33,0],
+"classIntegralDomainWithoutDivision.html#ade891fa308266c824b3aa9071b5f17ff":[1,0,0,33,8],
+"classIntegralDomainWithoutDivision.html#ae4cb9ba3cf18a1635f1e29c91a45f86e":[1,0,0,33,3],
+"classRealEmbeddable.html":[1,0,0,34],
+"classRealEmbeddable.html#a0f3f72df36199c34fecb093ae1ddf600":[1,0,0,34,0],
+"classRealEmbeddable.html#a2829e52e7fe3a31fdeee6d2756b1fc54":[1,0,0,34,5],
+"classRealEmbeddable.html#a3b639b62203afd58df9628820b160fbd":[1,0,0,34,2],
+"classRealEmbeddable.html#a3ee88fbcdfce6ccc6bf55add5854ee19":[1,0,0,34,4],
+"classRealEmbeddable.html#a4255c5fbbeeb0d3c0f685eddcb63afb8":[1,0,0,34,3],
+"classRealEmbeddable.html#a8260145d1e674a44028f8e1a0f3ef14f":[1,0,0,34,1],
+"classRealEmbeddableTraits.html":[1,0,0,43],
+"classRealEmbeddableTraits.html#a0f5fd64e004f097e44b5c5471db4f1cf":[1,0,0,43,4],
+"classRealEmbeddableTraits.html#a155667c6a84d3f92507f10ceeae38f47":[1,0,0,43,8],
+"classRealEmbeddableTraits.html#a1d0fd786282a78583addec6d759302ff":[1,0,0,43,9],
+"classRealEmbeddableTraits.html#a3a39c123ba2ae0844410ff78578d25f8":[1,0,0,43,5],
+"classRealEmbeddableTraits.html#a4786e99294cd21185a554c31f1b43282":[1,0,0,43,7],
+"classRealEmbeddableTraits.html#a529776d3dbb51ad44f171ee7e20e672a":[1,0,0,43,1],
+"classRealEmbeddableTraits.html#a74642a286b40aacb1145cac62dbfc066":[1,0,0,43,11],
+"classRealEmbeddableTraits.html#aa0be471ad6efa53832dbc97e5cb29348":[1,0,0,43,2],
+"classRealEmbeddableTraits.html#aa3e78d202789fed4a9b9ebe988ef0a71":[1,0,0,43,10],
+"classRealEmbeddableTraits.html#abc1b87bea2e996aa49793f5e1717908d":[1,0,0,43,3],
+"classRealEmbeddableTraits.html#ac9d15d1c8eb2068021c42c016888c526":[1,0,0,43,0],
+"classRealEmbeddableTraits.html#accb6b922ae1f36fa684f552dcd668271":[1,0,0,43,6],
+"classRealEmbeddableTraits.html#aeb25ed0ddd16efdcf2126f6019b1a469":[1,0,0,43,12],
+"classRealEmbeddableTraits___1_1Abs.html":[1,0,0,35],
+"classRealEmbeddableTraits___1_1Abs.html#a2663d046297f52b3c33a28bde1f51e49":[1,0,0,35,0],
+"classRealEmbeddableTraits___1_1Abs.html#a6ab03b06cdad48a8fe61d208bfbfba9b":[1,0,0,35,2],
+"classRealEmbeddableTraits___1_1Abs.html#adf23d11ae6130442a3f24b1b4a0a766f":[1,0,0,35,1],
+"classRealEmbeddableTraits___1_1Compare.html":[1,0,0,36],
+"classRealEmbeddableTraits___1_1Compare.html#a514211dbc535d3809879e4b1b89b2d07":[1,0,0,36,3],
+"classRealEmbeddableTraits___1_1Compare.html#a8013b3ae0d6eea44f2bf8401dd8c31a4":[1,0,0,36,0],
+"classRealEmbeddableTraits___1_1Compare.html#ab02eeba3ed342181950e06d97b24b154":[1,0,0,36,4],
+"classRealEmbeddableTraits___1_1Compare.html#abe4b885a8c81de120deb70667674dd70":[1,0,0,36,1],
+"classRealEmbeddableTraits___1_1Compare.html#af47942a3440079fc3cc95c6bf7286793":[1,0,0,36,2],
+"classRealEmbeddableTraits___1_1IsNegative.html":[1,0,0,37],
+"classRealEmbeddableTraits___1_1IsNegative.html#a88eeb00a38a70fcf460efc29ca3cbd05":[1,0,0,37,2],
+"classRealEmbeddableTraits___1_1IsNegative.html#a9e2258cb8bb32bc3f46ce962c3891d51":[1,0,0,37,0],
+"classRealEmbeddableTraits___1_1IsNegative.html#abb98fe614cc7ec915564136db6388122":[1,0,0,37,1],
+"classRealEmbeddableTraits___1_1IsPositive.html":[1,0,0,38],
+"classRealEmbeddableTraits___1_1IsPositive.html#a4ca0199b09d3db0d474db7a5bc02231e":[1,0,0,38,1],
+"classRealEmbeddableTraits___1_1IsPositive.html#a5e346c3f7cf73e30ef47e59d6caa9eda":[1,0,0,38,0],
+"classRealEmbeddableTraits___1_1IsPositive.html#a91a43194a8a04e3b99742a5c86dc68c7":[1,0,0,38,2],
+"classRealEmbeddableTraits___1_1IsZero.html":[1,0,0,39],
+"classRealEmbeddableTraits___1_1IsZero.html#a0ff48b66d480aa82a00109a5c991c915":[1,0,0,39,1],
+"classRealEmbeddableTraits___1_1IsZero.html#a839a7e420c1f5220ec0b994d120db152":[1,0,0,39,0],
+"classRealEmbeddableTraits___1_1IsZero.html#af00539ff4e7fc3505b319b45b37ac5dd":[1,0,0,39,2],
+"classRealEmbeddableTraits___1_1Sgn.html":[1,0,0,40],
+"classRealEmbeddableTraits___1_1Sgn.html#a7dc091f8662b0647f1d78b260fc64817":[1,0,0,40,2],
+"classRealEmbeddableTraits___1_1Sgn.html#a88885e3526ee996666dbe51e408479a1":[1,0,0,40,0],
+"classRealEmbeddableTraits___1_1Sgn.html#a9f4e9e6a395589b733bba7873698c453":[1,0,0,40,1],
+"classRealEmbeddableTraits___1_1ToDouble.html":[1,0,0,41],
+"classRealEmbeddableTraits___1_1ToDouble.html#a3dbe90a1454061c54b8f81c686e7e4c4":[1,0,0,41,2],
+"classRealEmbeddableTraits___1_1ToDouble.html#a8a063a081876976aaab1a59eeebca103":[1,0,0,41,0],
+"classRealEmbeddableTraits___1_1ToDouble.html#aea2ee18b1bc796915c09c0f6e3b91562":[1,0,0,41,1],
+"classRealEmbeddableTraits___1_1ToInterval.html":[1,0,0,42],
+"classRealEmbeddableTraits___1_1ToInterval.html#a45d2eca50b930e649a6792b1bfa933ce":[1,0,0,42,1],
+"classRealEmbeddableTraits___1_1ToInterval.html#a6fcd3b15f44329dd8fdc3d57924d5139":[1,0,0,42,0],
+"classRealEmbeddableTraits___1_1ToInterval.html#aae57c5ca9a9d4faa615d663e9ffee628":[1,0,0,42,2],
+"classRingNumberType.html":[1,0,0,44],
+"classUniqueFactorizationDomain.html":[1,0,0,45],
+"examples.html":[5],
 "group__PkgAlgebraicFoundationsAlgebraicStructuresConcepts.html":[1,0,0],
 "group__PkgAlgebraicFoundationsRef.html":[1,0],
 "group__PkgAlgebraicFoundationsRef.html#ga0397c01d0ea2364b92e98141e221e9bb":[1,0,14],
@@ -226,6 +226,7 @@ var NAVTREEINDEX0 =
 "group__PkgAlgebraicFoundationsRef.html#ga1f1bcd74fce34fd532445590bbda5cd5":[1,0,33],
 "group__PkgAlgebraicFoundationsRef.html#ga3152b245b3c1c2fccd78e1dc27942598":[1,0,19],
 "group__PkgAlgebraicFoundationsRef.html#ga3445213fb9bc055253f5c346ce1693f6":[1,0,16],
+"group__PkgAlgebraicFoundationsRef.html#ga45f5e8d23f5dea2bc433436cb062e2b5":[1,0,34],
 "group__PkgAlgebraicFoundationsRef.html#ga46969193a368780228dd0855cdc424b2":[1,0,35],
 "group__PkgAlgebraicFoundationsRef.html#ga5339b0f11fdc9babbc5ca0b33f4a982c":[1,0,30],
 "group__PkgAlgebraicFoundationsRef.html#ga59e55b9e023c50ddb15c89fae4b68387":[1,0,18],
@@ -238,16 +239,15 @@ var NAVTREEINDEX0 =
 "group__PkgAlgebraicFoundationsRef.html#gab922269072ee9ee99ba8c541418b2e11":[1,0,31],
 "group__PkgAlgebraicFoundationsRef.html#gabac14fc6cb4f556c19958b60f3305b9d":[1,0,26],
 "group__PkgAlgebraicFoundationsRef.html#gabbfc28149479e41f56111ffe692c07d5":[1,0,22],
-"group__PkgAlgebraicFoundationsRef.html#gac30124cb713e69f02816e2b91c655fa6":[1,0,34],
 "group__PkgAlgebraicFoundationsRef.html#gac6bc445c0fc83ed997549ce869b7bae7":[1,0,27],
 "group__PkgAlgebraicFoundationsRef.html#gade2b63594fb6827c33c0dcd73b4c7cfe":[1,0,17],
 "group__PkgAlgebraicFoundationsRef.html#gae246e686f794e878361621e6d4898b5a":[1,0,15],
 "group__PkgAlgebraicFoundationsRef.html#gaf3d75d272a29458960987a8f248ec636":[1,0,29],
-"hasModels.html":[4],
-"index.html":[],
 "index.html":[0],
+"index.html":[],
 "index.html#Algebraic_foundationsAlgebraic":[0,1],
 "index.html#Algebraic_foundationsAlgebraicCategory":[0,1,1],
 "index.html#Algebraic_foundationsDesign":[0,6],
-"index.html#Algebraic_foundationsExactandNumericalSensitive":[0,1,2]
+"index.html#Algebraic_foundationsExactandNumericalSensitive":[0,1,2],
+"index.html#Algebraic_foundationsExamples":[0,4,0]
 };
