@@ -2,8 +2,8 @@ var classCGAL_1_1Random__points__on__sphere__d =
 [
     [ "difference_type", "classCGAL_1_1Random__points__on__sphere__d.html#a17f384074c061883797ffc92498c4351", null ],
     [ "iterator_category", "classCGAL_1_1Random__points__on__sphere__d.html#ada9511d163582e98f4abd8d8c907f340", null ],
+    [ "pointer", "classCGAL_1_1Random__points__on__sphere__d.html#aa1ff148deb28709e58c0fde6e8ac2d59", null ],
+    [ "reference", "classCGAL_1_1Random__points__on__sphere__d.html#a36c44f2c1fc2d9c666fdead36d997a66", null ],
     [ "value_type", "classCGAL_1_1Random__points__on__sphere__d.html#a56efa3745d99ca13d83da56ac6951ebb", null ],
-    [ "Random_points_on_sphere_d", "classCGAL_1_1Random__points__on__sphere__d.html#ac522a329eb98d26f31ece8e356da3375", null ],
-    [ "pointer", "classCGAL_1_1Random__points__on__sphere__d.html#add865ea7beb8d0c072c46e636e08e4d7", null ],
-    [ "reference", "classCGAL_1_1Random__points__on__sphere__d.html#a2bcd06756dece4c26f65f3709592ae88", null ]
+    [ "Random_points_on_sphere_d", "classCGAL_1_1Random__points__on__sphere__d.html#ac522a329eb98d26f31ece8e356da3375", null ]
 ];
\ No newline at end of file
