@@ -1,5 +1,9 @@
 var NAVTREEINDEX6 =
 {
+"classKernel_1_1ConstructPointOn__3.html#aa18da4ad00632312e6eb56d5d9a40830":[1,0,0,1,171,0],
+"classKernel_1_1ConstructPointOn__3.html#abfb9500422554965bdd3d5b9d0f544d3":[1,0,0,1,171,3],
+"classKernel_1_1ConstructPoint__2.html":[1,0,0,1,172],
+"classKernel_1_1ConstructPoint__2.html#a01fa962280ec1c2f9ebd4556a8c537ac":[1,0,0,1,172,1],
 "classKernel_1_1ConstructPoint__2.html#a7c7ea25d064afd979fba0a63ba2066b1":[1,0,0,1,172,0],
 "classKernel_1_1ConstructPoint__2.html#adc5e1c868cc832e27e9de797c33a6b68":[1,0,0,1,172,2],
 "classKernel_1_1ConstructPoint__3.html":[1,0,0,1,173],
@@ -7,13 +11,15 @@ var NAVTREEINDEX6 =
 "classKernel_1_1ConstructPoint__3.html#a8a6d2e5f5d546e269293f96d7e74813e":[1,0,0,1,173,1],
 "classKernel_1_1ConstructPoint__3.html#abc81173f20fe694f465b080e0281d0d7":[1,0,0,1,173,2],
 "classKernel_1_1ConstructProjectedPoint__2.html":[1,0,0,1,174],
+"classKernel_1_1ConstructProjectedPoint__2.html#a369a679d8194ef59bc1eb947f1d307d8":[1,0,0,1,174,1],
 "classKernel_1_1ConstructProjectedPoint__2.html#a61f7570c737e48fe65bdf23c2d1073df":[1,0,0,1,174,0],
+"classKernel_1_1ConstructProjectedPoint__2.html#ab1cb99c0be3a4067c2e1c6b6a9e2092e":[1,0,0,1,174,2],
 "classKernel_1_1ConstructProjectedPoint__3.html":[1,0,0,1,175],
-"classKernel_1_1ConstructProjectedPoint__3.html#a1d3dace7a282f27f76749fb44dfac63f":[1,0,0,1,175,2],
+"classKernel_1_1ConstructProjectedPoint__3.html#a1d3dace7a282f27f76749fb44dfac63f":[1,0,0,1,175,3],
 "classKernel_1_1ConstructProjectedPoint__3.html#a90efad657269d9a548d208b2ad43be53":[1,0,0,1,175,1],
 "classKernel_1_1ConstructProjectedPoint__3.html#aa6a69663d382eda1545fbe09334fdf3c":[1,0,0,1,175,4],
 "classKernel_1_1ConstructProjectedPoint__3.html#ab0bcfb87b684eb7c163f986806865004":[1,0,0,1,175,0],
-"classKernel_1_1ConstructProjectedPoint__3.html#add919ed5851b36c2a18abe3c0382c1e4":[1,0,0,1,175,3],
+"classKernel_1_1ConstructProjectedPoint__3.html#add919ed5851b36c2a18abe3c0382c1e4":[1,0,0,1,175,2],
 "classKernel_1_1ConstructProjectedXYPoint__2.html":[1,0,0,1,176],
 "classKernel_1_1ConstructProjectedXYPoint__2.html#a25c4cc1a82ba54efece8d250e07cdbd7":[1,0,0,1,176,0],
 "classKernel_1_1ConstructRadicalAxis__2.html":[1,0,0,1,177],
@@ -23,21 +29,21 @@ var NAVTREEINDEX6 =
 "classKernel_1_1ConstructRadicalPlane__3.html":[1,0,0,1,179],
 "classKernel_1_1ConstructRadicalPlane__3.html#a2738404afa6916d8168cc1cfd9bc6f8b":[1,0,0,1,179,0],
 "classKernel_1_1ConstructRay__2.html":[1,0,0,1,180],
-"classKernel_1_1ConstructRay__2.html#a1ca2885852180be501c23b54f38c6eff":[1,0,0,1,180,2],
-"classKernel_1_1ConstructRay__2.html#aaf17643370636830ca5ac402ee9270b4":[1,0,0,1,180,0],
-"classKernel_1_1ConstructRay__2.html#ac96021d7cbdabda05f734ec7fb6cf96b":[1,0,0,1,180,3],
-"classKernel_1_1ConstructRay__2.html#af36248b39f3b3a997b797e0aa2af82fa":[1,0,0,1,180,1],
+"classKernel_1_1ConstructRay__2.html#a1ca2885852180be501c23b54f38c6eff":[1,0,0,1,180,0],
+"classKernel_1_1ConstructRay__2.html#aaf17643370636830ca5ac402ee9270b4":[1,0,0,1,180,2],
+"classKernel_1_1ConstructRay__2.html#ac96021d7cbdabda05f734ec7fb6cf96b":[1,0,0,1,180,1],
+"classKernel_1_1ConstructRay__2.html#af36248b39f3b3a997b797e0aa2af82fa":[1,0,0,1,180,3],
 "classKernel_1_1ConstructRay__3.html":[1,0,0,1,181],
-"classKernel_1_1ConstructRay__3.html#a25471f1d37e126060e250376580c3041":[1,0,0,1,181,0],
-"classKernel_1_1ConstructRay__3.html#a9041513992451e945d62c9e44be86112":[1,0,0,1,181,3],
-"classKernel_1_1ConstructRay__3.html#ae3eb5d2d7d88616daf256f2bcc5b07d7":[1,0,0,1,181,1],
-"classKernel_1_1ConstructRay__3.html#aeb16d1dcdab03fe8aabdbe8108c44d32":[1,0,0,1,181,2],
+"classKernel_1_1ConstructRay__3.html#a25471f1d37e126060e250376580c3041":[1,0,0,1,181,2],
+"classKernel_1_1ConstructRay__3.html#a9041513992451e945d62c9e44be86112":[1,0,0,1,181,1],
+"classKernel_1_1ConstructRay__3.html#ae3eb5d2d7d88616daf256f2bcc5b07d7":[1,0,0,1,181,3],
+"classKernel_1_1ConstructRay__3.html#aeb16d1dcdab03fe8aabdbe8108c44d32":[1,0,0,1,181,0],
 "classKernel_1_1ConstructScaledVector__2.html":[1,0,0,1,182],
-"classKernel_1_1ConstructScaledVector__2.html#a467c9cad1f78863521e53e1d70906d03":[1,0,0,1,182,1],
-"classKernel_1_1ConstructScaledVector__2.html#ad6ef649ed7c6615c108a34db52d1bc59":[1,0,0,1,182,0],
+"classKernel_1_1ConstructScaledVector__2.html#a467c9cad1f78863521e53e1d70906d03":[1,0,0,1,182,0],
+"classKernel_1_1ConstructScaledVector__2.html#ad6ef649ed7c6615c108a34db52d1bc59":[1,0,0,1,182,1],
 "classKernel_1_1ConstructScaledVector__3.html":[1,0,0,1,183],
-"classKernel_1_1ConstructScaledVector__3.html#a477478ac7b21aebfc1bcec35d3f87f42":[1,0,0,1,183,1],
-"classKernel_1_1ConstructScaledVector__3.html#a95e8e15f2b8da1d2748d9ee7de8768f3":[1,0,0,1,183,0],
+"classKernel_1_1ConstructScaledVector__3.html#a477478ac7b21aebfc1bcec35d3f87f42":[1,0,0,1,183,0],
+"classKernel_1_1ConstructScaledVector__3.html#a95e8e15f2b8da1d2748d9ee7de8768f3":[1,0,0,1,183,1],
 "classKernel_1_1ConstructSecondPoint__2.html":[1,0,0,1,184],
 "classKernel_1_1ConstructSecondPoint__2.html#aff4f2f3db860164ec3ae81a18e857cc3":[1,0,0,1,184,0],
 "classKernel_1_1ConstructSecondPoint__3.html":[1,0,0,1,185],
@@ -47,18 +53,18 @@ var NAVTREEINDEX6 =
 "classKernel_1_1ConstructSegment__3.html":[1,0,0,1,187],
 "classKernel_1_1ConstructSegment__3.html#af128171f91a5026b265d4c8f761556f7":[1,0,0,1,187,0],
 "classKernel_1_1ConstructSource__2.html":[1,0,0,1,188],
-"classKernel_1_1ConstructSource__2.html#a36ca1189925540584ef81b924dcb1562":[1,0,0,1,188,0],
-"classKernel_1_1ConstructSource__2.html#a72bbe38735664bf7d245accf1e570a68":[1,0,0,1,188,1],
+"classKernel_1_1ConstructSource__2.html#a36ca1189925540584ef81b924dcb1562":[1,0,0,1,188,1],
+"classKernel_1_1ConstructSource__2.html#a72bbe38735664bf7d245accf1e570a68":[1,0,0,1,188,0],
 "classKernel_1_1ConstructSource__3.html":[1,0,0,1,189],
-"classKernel_1_1ConstructSource__3.html#a3c79923d082d9661cfc3cb1b650b865f":[1,0,0,1,189,0],
-"classKernel_1_1ConstructSource__3.html#afa8c281ec7ba08d9f925259a308010bc":[1,0,0,1,189,1],
+"classKernel_1_1ConstructSource__3.html#a3c79923d082d9661cfc3cb1b650b865f":[1,0,0,1,189,1],
+"classKernel_1_1ConstructSource__3.html#afa8c281ec7ba08d9f925259a308010bc":[1,0,0,1,189,0],
 "classKernel_1_1ConstructSphere__3.html":[1,0,0,1,190],
-"classKernel_1_1ConstructSphere__3.html#a15e5e6190c9b62280240052425c9930e":[1,0,0,1,190,1],
-"classKernel_1_1ConstructSphere__3.html#a3931f2464ad5e3c9f7694930356c27d7":[1,0,0,1,190,2],
-"classKernel_1_1ConstructSphere__3.html#a578bebba763d1fd3abc3899ccbaca855":[1,0,0,1,190,4],
-"classKernel_1_1ConstructSphere__3.html#a7dab70c9b83666ddc359c8cc03ecfb82":[1,0,0,1,190,0],
-"classKernel_1_1ConstructSphere__3.html#ab050f9a640a537761a995e20ee9849f3":[1,0,0,1,190,5],
-"classKernel_1_1ConstructSphere__3.html#adab884a8708ad7e6368bcdcc835170a6":[1,0,0,1,190,3],
+"classKernel_1_1ConstructSphere__3.html#a15e5e6190c9b62280240052425c9930e":[1,0,0,1,190,3],
+"classKernel_1_1ConstructSphere__3.html#a3931f2464ad5e3c9f7694930356c27d7":[1,0,0,1,190,4],
+"classKernel_1_1ConstructSphere__3.html#a578bebba763d1fd3abc3899ccbaca855":[1,0,0,1,190,2],
+"classKernel_1_1ConstructSphere__3.html#a7dab70c9b83666ddc359c8cc03ecfb82":[1,0,0,1,190,1],
+"classKernel_1_1ConstructSphere__3.html#ab050f9a640a537761a995e20ee9849f3":[1,0,0,1,190,0],
+"classKernel_1_1ConstructSphere__3.html#adab884a8708ad7e6368bcdcc835170a6":[1,0,0,1,190,5],
 "classKernel_1_1ConstructSumOfVectors__2.html":[1,0,0,1,191],
 "classKernel_1_1ConstructSumOfVectors__2.html#a24090bc99798bed77f625dd451fa373e":[1,0,0,1,191,0],
 "classKernel_1_1ConstructSumOfVectors__3.html":[1,0,0,1,192],
@@ -72,8 +78,8 @@ var NAVTREEINDEX6 =
 "classKernel_1_1ConstructTetrahedron__3.html":[1,0,0,1,196],
 "classKernel_1_1ConstructTetrahedron__3.html#a050198f413127758e8a8a7133b7237bd":[1,0,0,1,196,0],
 "classKernel_1_1ConstructTranslatedPoint__2.html":[1,0,0,1,197],
-"classKernel_1_1ConstructTranslatedPoint__2.html#aa5d1e1b3089e49a32d8cf1d60c72b935":[1,0,0,1,197,1],
-"classKernel_1_1ConstructTranslatedPoint__2.html#ab8ff379bf836bde7c64b8506e181eed6":[1,0,0,1,197,0],
+"classKernel_1_1ConstructTranslatedPoint__2.html#aa5d1e1b3089e49a32d8cf1d60c72b935":[1,0,0,1,197,0],
+"classKernel_1_1ConstructTranslatedPoint__2.html#ab8ff379bf836bde7c64b8506e181eed6":[1,0,0,1,197,1],
 "classKernel_1_1ConstructTranslatedPoint__3.html":[1,0,0,1,198],
 "classKernel_1_1ConstructTranslatedPoint__3.html#a6912d03683fd4e5dbedbca072b460b99":[1,0,0,1,198,1],
 "classKernel_1_1ConstructTranslatedPoint__3.html#a7e61a9cd5368452af22a4114c82db98e":[1,0,0,1,198,0],
@@ -85,35 +91,35 @@ var NAVTREEINDEX6 =
 "classKernel_1_1ConstructUnitNormal__3.html#af52f0200f5a8f15da4ff1729849f4cef":[1,0,0,1,201,0],
 "classKernel_1_1ConstructVector__2.html":[1,0,0,1,202],
 "classKernel_1_1ConstructVector__2.html#a4d3c929999e6b1eecd63307c5bebab1e":[1,0,0,1,202,6],
-"classKernel_1_1ConstructVector__2.html#a56811757789d71a566b13ee86a7a90fc":[1,0,0,1,202,0],
+"classKernel_1_1ConstructVector__2.html#a56811757789d71a566b13ee86a7a90fc":[1,0,0,1,202,3],
 "classKernel_1_1ConstructVector__2.html#a5a7d56e589df4d2487a77c8d0602e3e1":[1,0,0,1,202,2],
-"classKernel_1_1ConstructVector__2.html#a6c8d4c1b6a56392c34a10868d2482fe8":[1,0,0,1,202,1],
+"classKernel_1_1ConstructVector__2.html#a6c8d4c1b6a56392c34a10868d2482fe8":[1,0,0,1,202,0],
 "classKernel_1_1ConstructVector__2.html#a87acd718350d56f0347427ce1bf702a7":[1,0,0,1,202,4],
-"classKernel_1_1ConstructVector__2.html#ab4fc4a886e18906b685946f5ccf469f9":[1,0,0,1,202,5],
-"classKernel_1_1ConstructVector__2.html#ad25e50a78605652e062f0774dd573646":[1,0,0,1,202,3],
+"classKernel_1_1ConstructVector__2.html#ab4fc4a886e18906b685946f5ccf469f9":[1,0,0,1,202,1],
+"classKernel_1_1ConstructVector__2.html#ad25e50a78605652e062f0774dd573646":[1,0,0,1,202,5],
 "classKernel_1_1ConstructVector__3.html":[1,0,0,1,203],
-"classKernel_1_1ConstructVector__3.html#a165a6f439792b1dd1b669a314a446569":[1,0,0,1,203,1],
-"classKernel_1_1ConstructVector__3.html#a2a9cf2319d1127fa3b4a476b0d39bcdf":[1,0,0,1,203,3],
+"classKernel_1_1ConstructVector__3.html#a165a6f439792b1dd1b669a314a446569":[1,0,0,1,203,0],
+"classKernel_1_1ConstructVector__3.html#a2a9cf2319d1127fa3b4a476b0d39bcdf":[1,0,0,1,203,5],
 "classKernel_1_1ConstructVector__3.html#a3cb9482318a4f0baa5ca10eb609dd77e":[1,0,0,1,203,2],
 "classKernel_1_1ConstructVector__3.html#a4dac6e18d033d738c65ee9e77075bf6e":[1,0,0,1,203,4],
-"classKernel_1_1ConstructVector__3.html#a519e87b215c9a9d90604c83c73d5d73e":[1,0,0,1,203,5],
+"classKernel_1_1ConstructVector__3.html#a519e87b215c9a9d90604c83c73d5d73e":[1,0,0,1,203,1],
 "classKernel_1_1ConstructVector__3.html#a9e77d55edabd4dd52e1ec9c6ac2aa041":[1,0,0,1,203,6],
-"classKernel_1_1ConstructVector__3.html#ab14e10bb07bdb4aeb089b109f06cd807":[1,0,0,1,203,0],
+"classKernel_1_1ConstructVector__3.html#ab14e10bb07bdb4aeb089b109f06cd807":[1,0,0,1,203,3],
 "classKernel_1_1ConstructVertex__2.html":[1,0,0,1,204],
-"classKernel_1_1ConstructVertex__2.html#a2cb3a962b5e11838f5dcda1e98eed9c3":[1,0,0,1,204,0],
+"classKernel_1_1ConstructVertex__2.html#a2cb3a962b5e11838f5dcda1e98eed9c3":[1,0,0,1,204,1],
 "classKernel_1_1ConstructVertex__2.html#a3142969c136f9a5de491a9505de7e9c5":[1,0,0,1,204,2],
-"classKernel_1_1ConstructVertex__2.html#a73fa0e80b1e9f32f4376efc3234ff799":[1,0,0,1,204,1],
+"classKernel_1_1ConstructVertex__2.html#a73fa0e80b1e9f32f4376efc3234ff799":[1,0,0,1,204,0],
 "classKernel_1_1ConstructVertex__3.html":[1,0,0,1,205],
-"classKernel_1_1ConstructVertex__3.html#a0352b1c3962712caedaa6fab0931a000":[1,0,0,1,205,3],
-"classKernel_1_1ConstructVertex__3.html#a8995ccf20716cd985ba1c8087bb77080":[1,0,0,1,205,1],
-"classKernel_1_1ConstructVertex__3.html#abb14ec0125f1d95c031bf61f7ba1d66a":[1,0,0,1,205,2],
-"classKernel_1_1ConstructVertex__3.html#abb173c9c3adb4cba686a688e1a1d2d4c":[1,0,0,1,205,0],
+"classKernel_1_1ConstructVertex__3.html#a0352b1c3962712caedaa6fab0931a000":[1,0,0,1,205,2],
+"classKernel_1_1ConstructVertex__3.html#a8995ccf20716cd985ba1c8087bb77080":[1,0,0,1,205,0],
+"classKernel_1_1ConstructVertex__3.html#abb14ec0125f1d95c031bf61f7ba1d66a":[1,0,0,1,205,3],
+"classKernel_1_1ConstructVertex__3.html#abb173c9c3adb4cba686a688e1a1d2d4c":[1,0,0,1,205,1],
 "classKernel_1_1ConstructWeightedCircumcenter__2.html":[1,0,0,1,206],
 "classKernel_1_1ConstructWeightedCircumcenter__2.html#a4b3c59554c3738996fb9729b23238004":[1,0,0,1,206,0],
 "classKernel_1_1ConstructWeightedCircumcenter__3.html":[1,0,0,1,207],
-"classKernel_1_1ConstructWeightedCircumcenter__3.html#a20095ced7a81c9cf3ebbf1518ee82b9c":[1,0,0,1,207,0],
+"classKernel_1_1ConstructWeightedCircumcenter__3.html#a20095ced7a81c9cf3ebbf1518ee82b9c":[1,0,0,1,207,2],
 "classKernel_1_1ConstructWeightedCircumcenter__3.html#a4368a5082df48df11114ced622b2e762":[1,0,0,1,207,1],
-"classKernel_1_1ConstructWeightedCircumcenter__3.html#aeb5649b36e888fe8722e2445fd46a6d2":[1,0,0,1,207,2],
+"classKernel_1_1ConstructWeightedCircumcenter__3.html#aeb5649b36e888fe8722e2445fd46a6d2":[1,0,0,1,207,0],
 "classKernel_1_1ConstructWeightedPoint__2.html":[1,0,0,1,208],
 "classKernel_1_1ConstructWeightedPoint__2.html#a04ef384df4ee7b53ff855e2dd66f06ca":[1,0,0,1,208,2],
 "classKernel_1_1ConstructWeightedPoint__2.html#a077a2fa6f85c0572348798c1ff1e7753":[1,0,0,1,208,0],
@@ -123,8 +129,8 @@ var NAVTREEINDEX6 =
 "classKernel_1_1ConstructWeightedPoint__3.html#a994ab0c1285e32b33cf1df67c3a8b481":[1,0,0,1,209,0],
 "classKernel_1_1ConstructWeightedPoint__3.html#ae5538fffaa44b1b0c0f0f269b5a0d2a1":[1,0,0,1,209,1],
 "classKernel_1_1CoplanarOrientation__3.html":[1,0,0,1,210],
-"classKernel_1_1CoplanarOrientation__3.html#aa24994f282b13f45a7f4019e481f67b4":[1,0,0,1,210,0],
-"classKernel_1_1CoplanarOrientation__3.html#aac655e1b87550abef70ad395c7b55d16":[1,0,0,1,210,1],
+"classKernel_1_1CoplanarOrientation__3.html#aa24994f282b13f45a7f4019e481f67b4":[1,0,0,1,210,1],
+"classKernel_1_1CoplanarOrientation__3.html#aac655e1b87550abef70ad395c7b55d16":[1,0,0,1,210,0],
 "classKernel_1_1CoplanarSideOfBoundedCircle__3.html":[1,0,0,1,211],
 "classKernel_1_1CoplanarSideOfBoundedCircle__3.html#a9a64fe3d40d2f9c740c1e06f619177b8":[1,0,0,1,211,0],
 "classKernel_1_1Coplanar__3.html":[1,0,0,1,212],
@@ -152,43 +158,43 @@ var NAVTREEINDEX6 =
 "classKernel_1_1Equal__2.html":[1,0,0,1,222],
 "classKernel_1_1Equal__2.html#a04fcc68d3eca46e61a78b04962bbfe14":[1,0,0,1,222,7],
 "classKernel_1_1Equal__2.html#a1e95d9b277d246dd3beaa3186164bd95":[1,0,0,1,222,3],
-"classKernel_1_1Equal__2.html#a2d8fd0770587c2b3a38738968d39900d":[1,0,0,1,222,0],
-"classKernel_1_1Equal__2.html#a4031555fb327fbc38a919782644a0230":[1,0,0,1,222,6],
-"classKernel_1_1Equal__2.html#a4182955999ada0612389e4c261945130":[1,0,0,1,222,2],
-"classKernel_1_1Equal__2.html#ab3f1fcdd4db8a24272f2554c9d11bb87":[1,0,0,1,222,1],
-"classKernel_1_1Equal__2.html#ab480b7a287645a11c209adbdcf0ca31a":[1,0,0,1,222,5],
-"classKernel_1_1Equal__2.html#adeb7bf5778b72df36e8b8efb9a3c16a9":[1,0,0,1,222,4],
-"classKernel_1_1Equal__2.html#afd9c6b2c1da3ef5742dc03894a68ff58":[1,0,0,1,222,8],
+"classKernel_1_1Equal__2.html#a2d8fd0770587c2b3a38738968d39900d":[1,0,0,1,222,4],
+"classKernel_1_1Equal__2.html#a4031555fb327fbc38a919782644a0230":[1,0,0,1,222,0],
+"classKernel_1_1Equal__2.html#a4182955999ada0612389e4c261945130":[1,0,0,1,222,1],
+"classKernel_1_1Equal__2.html#ab3f1fcdd4db8a24272f2554c9d11bb87":[1,0,0,1,222,8],
+"classKernel_1_1Equal__2.html#ab480b7a287645a11c209adbdcf0ca31a":[1,0,0,1,222,6],
+"classKernel_1_1Equal__2.html#adeb7bf5778b72df36e8b8efb9a3c16a9":[1,0,0,1,222,5],
+"classKernel_1_1Equal__2.html#afd9c6b2c1da3ef5742dc03894a68ff58":[1,0,0,1,222,2],
 "classKernel_1_1Equal__3.html":[1,0,0,1,223],
-"classKernel_1_1Equal__3.html#a1748db160ba97d513319b539677d4b81":[1,0,0,1,223,7],
-"classKernel_1_1Equal__3.html#a27dca9791b2203867b041d134013264a":[1,0,0,1,223,1],
-"classKernel_1_1Equal__3.html#a2d13a9e2babf9d82db3aeef3c3e0d9f1":[1,0,0,1,223,2],
+"classKernel_1_1Equal__3.html#a1748db160ba97d513319b539677d4b81":[1,0,0,1,223,0],
+"classKernel_1_1Equal__3.html#a27dca9791b2203867b041d134013264a":[1,0,0,1,223,11],
+"classKernel_1_1Equal__3.html#a2d13a9e2babf9d82db3aeef3c3e0d9f1":[1,0,0,1,223,1],
 "classKernel_1_1Equal__3.html#a3744b1d15cf3768f9b550f47cddd7bfb":[1,0,0,1,223,8],
 "classKernel_1_1Equal__3.html#a39fe241fc6ba392575b26dbc41347fa7":[1,0,0,1,223,3],
-"classKernel_1_1Equal__3.html#a4f19cf5f905179f0af11a87f997f0fcd":[1,0,0,1,223,11],
-"classKernel_1_1Equal__3.html#a566bcceff1a016f6095ebfab46aa76b8":[1,0,0,1,223,9],
-"classKernel_1_1Equal__3.html#a674eba752bf2db04e2c3d0d5d6b34e48":[1,0,0,1,223,5],
-"classKernel_1_1Equal__3.html#a740a5fd5f47aea2b0a7613c8fca16c2e":[1,0,0,1,223,10],
+"classKernel_1_1Equal__3.html#a4f19cf5f905179f0af11a87f997f0fcd":[1,0,0,1,223,2],
+"classKernel_1_1Equal__3.html#a566bcceff1a016f6095ebfab46aa76b8":[1,0,0,1,223,10],
+"classKernel_1_1Equal__3.html#a674eba752bf2db04e2c3d0d5d6b34e48":[1,0,0,1,223,6],
+"classKernel_1_1Equal__3.html#a740a5fd5f47aea2b0a7613c8fca16c2e":[1,0,0,1,223,9],
 "classKernel_1_1Equal__3.html#a8ed86933b6fdb296329dacff56b22bd5":[1,0,0,1,223,4],
-"classKernel_1_1Equal__3.html#aafbf1f4bd80c09ba88e0763e2df72fe9":[1,0,0,1,223,0],
-"classKernel_1_1Equal__3.html#af376958033b636928fb920a15ba5975f":[1,0,0,1,223,6],
+"classKernel_1_1Equal__3.html#aafbf1f4bd80c09ba88e0763e2df72fe9":[1,0,0,1,223,5],
+"classKernel_1_1Equal__3.html#af376958033b636928fb920a15ba5975f":[1,0,0,1,223,7],
 "classKernel_1_1HasOnBoundary__2.html":[1,0,0,1,224],
 "classKernel_1_1HasOnBoundary__2.html#a290c44969eef34b202b9125bf7337c80":[1,0,0,1,224,2],
 "classKernel_1_1HasOnBoundary__2.html#a6e55e99e3bd61acdb3541d0026f29b2d":[1,0,0,1,224,0],
 "classKernel_1_1HasOnBoundary__2.html#ad598f0aa9bd5a08637e5fccc7c00ff95":[1,0,0,1,224,1],
 "classKernel_1_1HasOnBoundary__3.html":[1,0,0,1,225],
-"classKernel_1_1HasOnBoundary__3.html#a02ddbb9a3895c18316d3d367e9883ceb":[1,0,0,1,225,2],
-"classKernel_1_1HasOnBoundary__3.html#a22b74d530951bbd3f561059ec4629b11":[1,0,0,1,225,0],
-"classKernel_1_1HasOnBoundary__3.html#ace03f72d51be814b0c0cb672374b1ddb":[1,0,0,1,225,1],
+"classKernel_1_1HasOnBoundary__3.html#a02ddbb9a3895c18316d3d367e9883ceb":[1,0,0,1,225,0],
+"classKernel_1_1HasOnBoundary__3.html#a22b74d530951bbd3f561059ec4629b11":[1,0,0,1,225,1],
+"classKernel_1_1HasOnBoundary__3.html#ace03f72d51be814b0c0cb672374b1ddb":[1,0,0,1,225,2],
 "classKernel_1_1HasOnBoundedSide__2.html":[1,0,0,1,226],
 "classKernel_1_1HasOnBoundedSide__2.html#a8b30f3ecd76a9bfe5ea37614e2a2f505":[1,0,0,1,226,0],
 "classKernel_1_1HasOnBoundedSide__2.html#ab478e8289ca03b229d091ea17450279d":[1,0,0,1,226,1],
 "classKernel_1_1HasOnBoundedSide__2.html#aed0f3d341534cf2dbf5ed228618170ab":[1,0,0,1,226,2],
 "classKernel_1_1HasOnBoundedSide__3.html":[1,0,0,1,227],
-"classKernel_1_1HasOnBoundedSide__3.html#a0bfac78507f1fe1c9f946408f7f1b0b9":[1,0,0,1,227,0],
-"classKernel_1_1HasOnBoundedSide__3.html#a140f0de6d600f58133edbbd2c054aea4":[1,0,0,1,227,2],
-"classKernel_1_1HasOnBoundedSide__3.html#a675b12efd4ff8c3d83997e59db3ff0f6":[1,0,0,1,227,1],
-"classKernel_1_1HasOnBoundedSide__3.html#a879efe7f55b4ae8f2bd0d1acca42b6e4":[1,0,0,1,227,3],
+"classKernel_1_1HasOnBoundedSide__3.html#a0bfac78507f1fe1c9f946408f7f1b0b9":[1,0,0,1,227,1],
+"classKernel_1_1HasOnBoundedSide__3.html#a140f0de6d600f58133edbbd2c054aea4":[1,0,0,1,227,0],
+"classKernel_1_1HasOnBoundedSide__3.html#a675b12efd4ff8c3d83997e59db3ff0f6":[1,0,0,1,227,3],
+"classKernel_1_1HasOnBoundedSide__3.html#a879efe7f55b4ae8f2bd0d1acca42b6e4":[1,0,0,1,227,2],
 "classKernel_1_1HasOnNegativeSide__2.html":[1,0,0,1,228],
 "classKernel_1_1HasOnNegativeSide__2.html#a427070bc873950567d37dbff39a07108":[1,0,0,1,228,0],
 "classKernel_1_1HasOnNegativeSide__2.html#a5ac5d40b076ca97d8c8130720e46dba4":[1,0,0,1,228,1],
@@ -210,24 +216,24 @@ var NAVTREEINDEX6 =
 "classKernel_1_1HasOnUnboundedSide__2.html#a3108f91c2698eaf62e85b84fef0c6731":[1,0,0,1,232,1],
 "classKernel_1_1HasOnUnboundedSide__2.html#a8ca70b14d279c41a5c1d314b1de22b59":[1,0,0,1,232,2],
 "classKernel_1_1HasOnUnboundedSide__3.html":[1,0,0,1,233],
-"classKernel_1_1HasOnUnboundedSide__3.html#a3778b1b8f39cad82d92a5bcbd49a9086":[1,0,0,1,233,0],
-"classKernel_1_1HasOnUnboundedSide__3.html#a4b2c27a0593727a253a416adadc37d29":[1,0,0,1,233,2],
-"classKernel_1_1HasOnUnboundedSide__3.html#a690242150d4b9397e441273361574774":[1,0,0,1,233,1],
+"classKernel_1_1HasOnUnboundedSide__3.html#a3778b1b8f39cad82d92a5bcbd49a9086":[1,0,0,1,233,1],
+"classKernel_1_1HasOnUnboundedSide__3.html#a4b2c27a0593727a253a416adadc37d29":[1,0,0,1,233,0],
+"classKernel_1_1HasOnUnboundedSide__3.html#a690242150d4b9397e441273361574774":[1,0,0,1,233,2],
 "classKernel_1_1HasOn__2.html":[1,0,0,1,234],
 "classKernel_1_1HasOn__2.html#a89e1963bd17ae3b2d80fc87d67ee5257":[1,0,0,1,234,1],
 "classKernel_1_1HasOn__2.html#ab938ddb802eb51b69cb1f819aef30f6e":[1,0,0,1,234,0],
 "classKernel_1_1HasOn__2.html#ad5837ab009b676cdf3bb4c236560a656":[1,0,0,1,234,2],
 "classKernel_1_1HasOn__3.html":[1,0,0,1,235],
-"classKernel_1_1HasOn__3.html#a151e1848d8dd2bb056872b6d7ef6ecdc":[1,0,0,1,235,6],
-"classKernel_1_1HasOn__3.html#a2fd2e8f39e040d6103262654d97ef1ff":[1,0,0,1,235,2],
+"classKernel_1_1HasOn__3.html#a151e1848d8dd2bb056872b6d7ef6ecdc":[1,0,0,1,235,2],
+"classKernel_1_1HasOn__3.html#a2fd2e8f39e040d6103262654d97ef1ff":[1,0,0,1,235,5],
 "classKernel_1_1HasOn__3.html#a3e045b4b4e9d7d7509285c047793b7f2":[1,0,0,1,235,0],
-"classKernel_1_1HasOn__3.html#a7342749b4d33bd15d4dd309a26f7b8a7":[1,0,0,1,235,5],
+"classKernel_1_1HasOn__3.html#a7342749b4d33bd15d4dd309a26f7b8a7":[1,0,0,1,235,3],
 "classKernel_1_1HasOn__3.html#a81614d85aa609ec6a282cf0bbebb48ae":[1,0,0,1,235,4],
-"classKernel_1_1HasOn__3.html#aaa9462bbfe01f162d21359ab744e910d":[1,0,0,1,235,3],
+"classKernel_1_1HasOn__3.html#aaa9462bbfe01f162d21359ab744e910d":[1,0,0,1,235,6],
 "classKernel_1_1HasOn__3.html#ace46b50f7294499722f854af7ff2de6a":[1,0,0,1,235,9],
 "classKernel_1_1HasOn__3.html#ae4bb7458bbc06eae0b66c3f759383641":[1,0,0,1,235,1],
-"classKernel_1_1HasOn__3.html#aedbeef9a5bf64bc0d0ec656df98067e3":[1,0,0,1,235,8],
-"classKernel_1_1HasOn__3.html#afc33d5b0386c2b72d365ddc9b4297fea":[1,0,0,1,235,7],
+"classKernel_1_1HasOn__3.html#aedbeef9a5bf64bc0d0ec656df98067e3":[1,0,0,1,235,7],
+"classKernel_1_1HasOn__3.html#afc33d5b0386c2b72d365ddc9b4297fea":[1,0,0,1,235,8],
 "classKernel_1_1Intersect__2.html":[1,0,0,1,236],
 "classKernel_1_1Intersect__2.html#a5635fa0675ce91e4b81d7a28f78f3a5f":[1,0,0,1,236,0],
 "classKernel_1_1Intersect__3.html":[1,0,0,1,237],
@@ -243,11 +249,5 @@ var NAVTREEINDEX6 =
 "classKernel_1_1IsDegenerate__3.html#a03e984dc8e24518d2805feee41573f68":[1,0,0,1,239,8],
 "classKernel_1_1IsDegenerate__3.html#a29c56292e18d3dd07e79f2fbde373286":[1,0,0,1,239,2],
 "classKernel_1_1IsDegenerate__3.html#a3df365dab543fc779c23aa031b3aa741":[1,0,0,1,239,3],
-"classKernel_1_1IsDegenerate__3.html#a54569687958fd4914c48fa5d85d804a3":[1,0,0,1,239,1],
-"classKernel_1_1IsDegenerate__3.html#a5dc48e597385a16e47e6b49924332c5c":[1,0,0,1,239,5],
-"classKernel_1_1IsDegenerate__3.html#a66b8341f36ead262054f1b2780b2f854":[1,0,0,1,239,0],
-"classKernel_1_1IsDegenerate__3.html#aacdefe20996a2956bf20dccecacbead0":[1,0,0,1,239,7],
-"classKernel_1_1IsDegenerate__3.html#af601554273f3da019d1a85019cbf73ab":[1,0,0,1,239,6],
-"classKernel_1_1IsDegenerate__3.html#af8d9fbb96d139375f78f3b0d8989b878":[1,0,0,1,239,4],
-"classKernel_1_1IsHorizontal__2.html":[1,0,0,1,240]
+"classKernel_1_1IsDegenerate__3.html#a54569687958fd4914c48fa5d85d804a3":[1,0,0,1,239,1]
 };
