@@ -1,6 +1,6 @@
 var group__PkgKernelDKernelObjs =
 [
-    [ "Aff_transformation_d", "classCGAL_1_1Aff__transformation__d.html", [
+    [ "CGAL::Aff_transformation_d< Kernel >", "classCGAL_1_1Aff__transformation__d.html", [
       [ "LA", "classCGAL_1_1Aff__transformation__d.html#a4292bc487be965e90d5464ad93b09fc5", null ],
       [ "Matrix", "classCGAL_1_1Aff__transformation__d.html#abd21f60ed6258ea830372804b973fddb", null ],
       [ "Aff_transformation_d", "classCGAL_1_1Aff__transformation__d.html#adb46a9951bc7d27e81b21012c36f7ed7", null ],
@@ -12,11 +12,11 @@ var group__PkgKernelDKernelObjs =
       [ "Aff_transformation_d", "classCGAL_1_1Aff__transformation__d.html#aac4acf5808f21c417e478ca1e35d5e1d", null ],
       [ "Aff_transformation_d", "classCGAL_1_1Aff__transformation__d.html#ac74e4a1e5523cf042c44d47d7044abfa", null ],
       [ "dimension", "classCGAL_1_1Aff__transformation__d.html#ac8bd9d10882d4e6a83794040ec7ce35e", null ],
-      [ "inverse", "classCGAL_1_1Aff__transformation__d.html#a09a657eb112244f74e149a8b98482b25", null ],
-      [ "matrix", "classCGAL_1_1Aff__transformation__d.html#afae6dfb2d291b40aca3b93e69052163a", null ],
-      [ "operator*", "classCGAL_1_1Aff__transformation__d.html#a729ab7bea05f16cca8863a8e94a4a849", null ]
+      [ "inverse", "classCGAL_1_1Aff__transformation__d.html#a94f7184aeeb30455a9de4e8f4d3cdc2d", null ],
+      [ "matrix", "classCGAL_1_1Aff__transformation__d.html#ad6af8c14228a83c4d4b1061c82814f97", null ],
+      [ "operator*", "classCGAL_1_1Aff__transformation__d.html#aa7446dbfeaadc54b869c31977e12097d", null ]
     ] ],
-    [ "Direction_d", "classCGAL_1_1Direction__d.html", [
+    [ "CGAL::Direction_d< Kernel >", "classCGAL_1_1Direction__d.html", [
       [ "Base_direction", "classCGAL_1_1Direction__d.html#a903106ffd49f31567a2c629bf7144121", null ],
       [ "Delta_const_iterator", "classCGAL_1_1Direction__d.html#ad81dda4874ecadd951fb99adde6738c3", null ],
       [ "LA", "classCGAL_1_1Direction__d.html#a053af17cd4f3417781022adee38978a6", null ],
@@ -31,13 +31,13 @@ var group__PkgKernelDKernelObjs =
       [ "deltas_end", "classCGAL_1_1Direction__d.html#a8a9caacac4f5b506486f2ffe4657b4f0", null ],
       [ "dimension", "classCGAL_1_1Direction__d.html#a5efc85b3b2690950e2dff682422520fe", null ],
       [ "is_degenerate", "classCGAL_1_1Direction__d.html#a342db9560f60be60dcb2fc135f67e184", null ],
-      [ "operator-", "classCGAL_1_1Direction__d.html#ac006f1e2ae429b078ebef4ecf2229d22", null ],
+      [ "operator-", "classCGAL_1_1Direction__d.html#a28a03114368623d723a90dd2c8a1c7f3", null ],
       [ "operator[]", "classCGAL_1_1Direction__d.html#a44a05d801ea9ac51c0655224dd068557", null ],
-      [ "opposite", "classCGAL_1_1Direction__d.html#aa93a125f1865067313305dfc86ecfe8b", null ],
-      [ "transform", "classCGAL_1_1Direction__d.html#a793913718dbd1c4c4cd0431790729987", null ],
-      [ "vector", "classCGAL_1_1Direction__d.html#a92a148e760ae1e3815ccb0b685385cf9", null ]
+      [ "opposite", "classCGAL_1_1Direction__d.html#a81223b7185f75ff20d3321dc137fd94d", null ],
+      [ "transform", "classCGAL_1_1Direction__d.html#a95e9e154b7d51f11dff9fc53053c6997", null ],
+      [ "vector", "classCGAL_1_1Direction__d.html#a585b438260b23d93e060d4023aa392df", null ]
     ] ],
-    [ "Hyperplane_d", "classCGAL_1_1Hyperplane__d.html", [
+    [ "CGAL::Hyperplane_d< Kernel >", "classCGAL_1_1Hyperplane__d.html", [
       [ "Coefficient_const_iterator", "classCGAL_1_1Hyperplane__d.html#a59f8ad07b9541ad6c05232f230cc331c", null ],
       [ "LA", "classCGAL_1_1Hyperplane__d.html#a1b41ffba5fb8923c95ab422c10e58a40", null ],
       [ "Hyperplane_d", "classCGAL_1_1Hyperplane__d.html#a96bda4c593efd572142e9ad7ef30fcc5", null ],
@@ -57,25 +57,25 @@ var group__PkgKernelDKernelObjs =
       [ "has_on_positive_side", "classCGAL_1_1Hyperplane__d.html#af9c7e8cf6b5566201aae98d3ccfca549", null ],
       [ "operator[]", "classCGAL_1_1Hyperplane__d.html#a3fa79468674e83463618e39a7e6cdcca", null ],
       [ "oriented_side", "classCGAL_1_1Hyperplane__d.html#a8992b11d039d91d3214a288da40a8ca3", null ],
-      [ "orthogonal_direction", "classCGAL_1_1Hyperplane__d.html#a6ef80023ef061eef690a7d094a312488", null ],
-      [ "orthogonal_vector", "classCGAL_1_1Hyperplane__d.html#a9b06b5a8c3a274a896b73d0aba922197", null ],
-      [ "transform", "classCGAL_1_1Hyperplane__d.html#ad5a93fbf7e86ec52cfae8ff364f44647", null ],
+      [ "orthogonal_direction", "classCGAL_1_1Hyperplane__d.html#afbcc564a7a3e8ffda1546adbb45b70ea", null ],
+      [ "orthogonal_vector", "classCGAL_1_1Hyperplane__d.html#ad797503d408463682e73e1ad217311f9", null ],
+      [ "transform", "classCGAL_1_1Hyperplane__d.html#a9b49516b5ce6e2e740f4dbd181a0c637", null ],
       [ "weak_equality", "classCGAL_1_1Hyperplane__d.html#a7de58b9954c8dd29537b2ac926f608e5", null ]
     ] ],
-    [ "Iso_box_d", "classCGAL_1_1Iso__box__d.html", [
+    [ "CGAL::Iso_box_d< Kernel >", "classCGAL_1_1Iso__box__d.html", [
       [ "Iso_box_d", "classCGAL_1_1Iso__box__d.html#a5010ecbed9d38abfde8e6d767b972ef3", null ],
       [ "bounded_side", "classCGAL_1_1Iso__box__d.html#a8fd7993871ba2cba5da3a402f7cc046e", null ],
       [ "has_on_boundary", "classCGAL_1_1Iso__box__d.html#a388b37da48f128af91cd4867636d710f", null ],
       [ "has_on_bounded_side", "classCGAL_1_1Iso__box__d.html#a6342e0a380392c2a6c7ce9c816adbe47", null ],
       [ "has_on_unbounded_side", "classCGAL_1_1Iso__box__d.html#a004976d0db44fe5947f8088f4c63a67b", null ],
       [ "is_degenerate", "classCGAL_1_1Iso__box__d.html#a2da9d2704fd3446579af02782647341e", null ],
-      [ "max", "classCGAL_1_1Iso__box__d.html#a29e318a85a03e4c9c5cb86c370dc7c1f", null ],
-      [ "min", "classCGAL_1_1Iso__box__d.html#ad19c62016854bc3a239ca89130387849", null ],
+      [ "max", "classCGAL_1_1Iso__box__d.html#a2de9585eb7ab97078df20a904d4461b1", null ],
+      [ "min", "classCGAL_1_1Iso__box__d.html#a92296580564326b6bb4d36836ccf2477", null ],
       [ "operator!=", "classCGAL_1_1Iso__box__d.html#a8df66db052a721580135cf8ca82b4c96", null ],
       [ "operator==", "classCGAL_1_1Iso__box__d.html#a683e801b19aa4c8cc9fe4246f91128aa", null ],
       [ "volume", "classCGAL_1_1Iso__box__d.html#aa2abcf507012eaed6a250ee821fd0df6", null ]
     ] ],
-    [ "Line_d", "classCGAL_1_1Line__d.html", [
+    [ "CGAL::Line_d< Kernel >", "classCGAL_1_1Line__d.html", [
       [ "LA", "classCGAL_1_1Line__d.html#a38088d941bc15f3ef0b4faaf178f3004", null ],
       [ "Line_d", "classCGAL_1_1Line__d.html#aa2562b98856968f3d7c3503aa750ec31", null ],
       [ "Line_d", "classCGAL_1_1Line__d.html#a72fc22c5800b25e451fd8414028624ce", null ],
@@ -83,17 +83,17 @@ var group__PkgKernelDKernelObjs =
       [ "Line_d", "classCGAL_1_1Line__d.html#a7432ce7ce71cf1dbeb0c5a5cecbc8dbd", null ],
       [ "Line_d", "classCGAL_1_1Line__d.html#aeda33e811eb7c5501d1cef26e5a8c4b0", null ],
       [ "dimension", "classCGAL_1_1Line__d.html#a4077090e17d855317714f7dee3213a00", null ],
-      [ "direction", "classCGAL_1_1Line__d.html#a74866c107e9ef23894c021bbcaea7512", null ],
+      [ "direction", "classCGAL_1_1Line__d.html#a12b116e529ec78f87d118d9d689786a6", null ],
       [ "has_on", "classCGAL_1_1Line__d.html#a1063e21c1221847b388de35e435e1f4b", null ],
-      [ "operator+", "classCGAL_1_1Line__d.html#aab48ccbe7b3ef05d3386a51fc78e5533", null ],
-      [ "opposite", "classCGAL_1_1Line__d.html#abe92fda37f31efef0e5365e145e6d4c4", null ],
-      [ "point", "classCGAL_1_1Line__d.html#aca04f6ae0dff2ca378316d64d3c510cd", null ],
-      [ "projection", "classCGAL_1_1Line__d.html#ab2dec6a57f6bc44dfe9dd5ed214b50da", null ],
-      [ "transform", "classCGAL_1_1Line__d.html#a874614b2724f5860fabfa88dd85586dc", null ],
+      [ "operator+", "classCGAL_1_1Line__d.html#aff75d332e8e4089c196424520d502df1", null ],
+      [ "opposite", "classCGAL_1_1Line__d.html#ac594388cd3278d46bbd4606460f3625d", null ],
+      [ "point", "classCGAL_1_1Line__d.html#a85ee84a9776c7324634c9d1849ace569", null ],
+      [ "projection", "classCGAL_1_1Line__d.html#a5bc6dc781ac97d3916403a30d31d8ecb", null ],
+      [ "transform", "classCGAL_1_1Line__d.html#a3ad1cf95536aab9b2bc14c493f6bfc0b", null ],
       [ "parallel", "classCGAL_1_1Line__d.html#afbba4983ff01e6a7d2069524694cda32", null ],
       [ "weak_equality", "classCGAL_1_1Line__d.html#a79aefa331e9f933f5e2cc9564bbc2b03", null ]
     ] ],
-    [ "Point_d", "classCGAL_1_1Point__d.html", [
+    [ "CGAL::Point_d< Kernel >", "classCGAL_1_1Point__d.html", [
       [ "Cartesian_const_iterator", "classCGAL_1_1Point__d.html#a456a12baa4cb2e93701c89aee6155ef8", null ],
       [ "Homogeneous_const_iterator", "classCGAL_1_1Point__d.html#af13d3e6cdb17af9655c5ffb6f6542828", null ],
       [ "LA", "classCGAL_1_1Point__d.html#aa69b4ed65cc45c2a16f158334bc575c8", null ],
@@ -110,70 +110,70 @@ var group__PkgKernelDKernelObjs =
       [ "homogeneous", "classCGAL_1_1Point__d.html#a37d563e475d4ccdd53c35157193e17d6", null ],
       [ "homogeneous_begin", "classCGAL_1_1Point__d.html#a618fe67792d65e2740c39f6f86baa02b", null ],
       [ "homogeneous_end", "classCGAL_1_1Point__d.html#a6ec77480acea5f3002866f2b38a7c347", null ],
-      [ "operator+", "classCGAL_1_1Point__d.html#abfc50371770fff2468c4c4d4562dd8b4", null ],
-      [ "operator+=", "classCGAL_1_1Point__d.html#a4422092c73021fd1e02f46a37fd14e4e", null ],
-      [ "operator-", "classCGAL_1_1Point__d.html#ab46cf5cf18c58975e1e89a1200cbdd7c", null ],
-      [ "operator-", "classCGAL_1_1Point__d.html#a549de663024a046215cbdb6271117831", null ],
-      [ "operator-", "classCGAL_1_1Point__d.html#a920574d3c6dc70f24df1e1930b273a8f", null ],
-      [ "operator-=", "classCGAL_1_1Point__d.html#ad17782ad7b84b62cb8535011f8d12c51", null ],
+      [ "operator+", "classCGAL_1_1Point__d.html#a14020ed70adb122bd3cbd76166c74f22", null ],
+      [ "operator+=", "classCGAL_1_1Point__d.html#a063ea0c64813f0bf5284115aaafe05e0", null ],
+      [ "operator-", "classCGAL_1_1Point__d.html#a1a292e70d39707f0b2d296a335ede5c4", null ],
+      [ "operator-", "classCGAL_1_1Point__d.html#a7ce3b543722095d233b4ef51ddc0b83b", null ],
+      [ "operator-", "classCGAL_1_1Point__d.html#a3740bf8b51d9b1efb30e556c3a4a8577", null ],
+      [ "operator-=", "classCGAL_1_1Point__d.html#a8409e30f0683da612e23173f3da7178f", null ],
       [ "operator<", "classCGAL_1_1Point__d.html#a3d6471c6697e83c9ec4d4e4a8fe9e506", null ],
       [ "operator<=", "classCGAL_1_1Point__d.html#afb3f1f08e968e133fc603fd23308f837", null ],
       [ "operator==", "classCGAL_1_1Point__d.html#a743ffa47bb78fe92fa4431c06d29c24b", null ],
       [ "operator>", "classCGAL_1_1Point__d.html#abd8db377f33eeb7aa70e2fb41cdaf5d7", null ],
       [ "operator>=", "classCGAL_1_1Point__d.html#a27a6eac05d3442a5b3d73b640d5117ee", null ],
       [ "operator[]", "classCGAL_1_1Point__d.html#a432ba2948bbe51d3c8256cb4c16e1fd5", null ],
-      [ "transform", "classCGAL_1_1Point__d.html#aa888f781d72ecf2a028e32aec8c6bdbf", null ]
+      [ "transform", "classCGAL_1_1Point__d.html#a9364fd80d683ae88478746db412c4ba8", null ]
     ] ],
-    [ "Ray_d", "classCGAL_1_1Ray__d.html", [
+    [ "CGAL::Ray_d< Kernel >", "classCGAL_1_1Ray__d.html", [
       [ "LA", "classCGAL_1_1Ray__d.html#a51bee915c77c66d4edfe96fe976a01ba", null ],
       [ "Ray_d", "classCGAL_1_1Ray__d.html#a6dfd55ef7eb5bb39e6f298ddcf8841b3", null ],
       [ "Ray_d", "classCGAL_1_1Ray__d.html#a9ca8d96fcf96740de4c5b4f91029d857", null ],
       [ "Ray_d", "classCGAL_1_1Ray__d.html#a32d5d1a3fb0ed543bb2d588cadb41941", null ],
       [ "Ray_d", "classCGAL_1_1Ray__d.html#a50327bec419d7904f2b06c35acf8de5d", null ],
       [ "dimension", "classCGAL_1_1Ray__d.html#a9625fa318bb58eafa89ac3c6b2b81fdc", null ],
-      [ "direction", "classCGAL_1_1Ray__d.html#a7a2d407dd04d061c70579dbb7d5fce80", null ],
+      [ "direction", "classCGAL_1_1Ray__d.html#a68b7a55b6784e86f0e3a079bdfe73f5e", null ],
       [ "has_on", "classCGAL_1_1Ray__d.html#aaeaa5b0aed4825b9c96cbc394db9c2be", null ],
-      [ "operator+", "classCGAL_1_1Ray__d.html#a0e43a178065bd38d2f3f1d4a1ebe2b6e", null ],
-      [ "opposite", "classCGAL_1_1Ray__d.html#af4f080dfdd9a6e496197233233de4e88", null ],
-      [ "point", "classCGAL_1_1Ray__d.html#abfaa2c24c6c604f08bf9692cdcafa3e4", null ],
-      [ "source", "classCGAL_1_1Ray__d.html#a75d7bd0e849823217d57d3e8ddc2f1e2", null ],
-      [ "supporting_line", "classCGAL_1_1Ray__d.html#a0c79e58e66378559608c426fbe1852d7", null ],
-      [ "transform", "classCGAL_1_1Ray__d.html#a8c5d77cf280aa82ac2ae4500273b4faf", null ],
+      [ "operator+", "classCGAL_1_1Ray__d.html#a0665b9d94a395907b8e0d7a670685353", null ],
+      [ "opposite", "classCGAL_1_1Ray__d.html#af4f52af2a44f29c3289124899bebf5fb", null ],
+      [ "point", "classCGAL_1_1Ray__d.html#a4a2288891ed50ee1a3d9aa28ad781969", null ],
+      [ "source", "classCGAL_1_1Ray__d.html#a56f4c6a8b5580574be56b12bc83b2f00", null ],
+      [ "supporting_line", "classCGAL_1_1Ray__d.html#adbac394b8f11bdd72bbf1023eb1d92e4", null ],
+      [ "transform", "classCGAL_1_1Ray__d.html#a39c7f15042ce15d72769e053d0f86a1d", null ],
       [ "parallel", "classCGAL_1_1Ray__d.html#ab8e4fdfd1f0b26f0ae0a40fd5eef488d", null ]
     ] ],
-    [ "Segment_d", "classCGAL_1_1Segment__d.html", [
+    [ "CGAL::Segment_d< Kernel >", "classCGAL_1_1Segment__d.html", [
       [ "LA", "classCGAL_1_1Segment__d.html#a3a87a622436556d8eb6850c88a2016c3", null ],
       [ "Segment_d", "classCGAL_1_1Segment__d.html#a82462da31668b81e12e3acc57f162962", null ],
       [ "Segment_d", "classCGAL_1_1Segment__d.html#aa548199d0c194a59af44805fd159efb7", null ],
       [ "Segment_d", "classCGAL_1_1Segment__d.html#ad81bb8f75ee75811059f0f857ad6ab6c", null ],
       [ "dimension", "classCGAL_1_1Segment__d.html#a9395dcf19178f328ce6bdfd8c31bdc4e", null ],
-      [ "direction", "classCGAL_1_1Segment__d.html#af460764bf00bb4ad3ba5c6301b75b73b", null ],
+      [ "direction", "classCGAL_1_1Segment__d.html#a592c61026beb357f54a8d372fa760717", null ],
       [ "has_on", "classCGAL_1_1Segment__d.html#aa18af797886251e623c4671865b4df72", null ],
       [ "is_degenerate", "classCGAL_1_1Segment__d.html#a40ec6b9372ceb0656cff1e2fa96bdaa1", null ],
-      [ "max", "classCGAL_1_1Segment__d.html#a25d1684af7a48443dc9e0ad8500579d9", null ],
-      [ "min", "classCGAL_1_1Segment__d.html#a856014b414e5f80ebdad5dea967f0119", null ],
-      [ "operator+", "classCGAL_1_1Segment__d.html#a1f74c8f1ee548889cb11f66ab7051038", null ],
-      [ "operator[]", "classCGAL_1_1Segment__d.html#a74e3534b67653fbd93d553613ce7f2ee", null ],
-      [ "opposite", "classCGAL_1_1Segment__d.html#a0e8ff4b7a8ab68c212dda1803c234cc8", null ],
-      [ "point", "classCGAL_1_1Segment__d.html#abb3d058922c70677109412eb41349518", null ],
-      [ "source", "classCGAL_1_1Segment__d.html#ab15639fb3a81f228cbd2ad58c9148fe8", null ],
+      [ "max", "classCGAL_1_1Segment__d.html#a9cb6637450f571e135115fbf2d90822c", null ],
+      [ "min", "classCGAL_1_1Segment__d.html#a21ef38b064bb2d9f5d19c29c53d1d336", null ],
+      [ "operator+", "classCGAL_1_1Segment__d.html#a32c167412710039467767622d3342d9d", null ],
+      [ "operator[]", "classCGAL_1_1Segment__d.html#a78898a209bcde4244694afc03d9cd8bc", null ],
+      [ "opposite", "classCGAL_1_1Segment__d.html#a4468ebb3a84f17636a327424375b1a40", null ],
+      [ "point", "classCGAL_1_1Segment__d.html#a7cc56863ce72e036818f0536259b594d", null ],
+      [ "source", "classCGAL_1_1Segment__d.html#a32e903b6ab29432c6949addc7f7c3db3", null ],
       [ "squared_length", "classCGAL_1_1Segment__d.html#a71f91a59bf78d4fc2c1d24709de5adff", null ],
-      [ "supporting_line", "classCGAL_1_1Segment__d.html#ab0b0ec5783a9b7d60cf24a7f0ebbd122", null ],
-      [ "target", "classCGAL_1_1Segment__d.html#aceac029df3ae8c0f56b8a13595737ee7", null ],
-      [ "transform", "classCGAL_1_1Segment__d.html#a41f9eb9bb4fdae0c9e19df84c08e72a8", null ],
-      [ "vector", "classCGAL_1_1Segment__d.html#ac2ce7e4c38f2da0309f0a89387d32300", null ],
-      [ "vertex", "classCGAL_1_1Segment__d.html#ab65a63317c3722dd8a0a79542aeb3cfb", null ],
+      [ "supporting_line", "classCGAL_1_1Segment__d.html#a3c671122cbcfe27173347d60059d3d28", null ],
+      [ "target", "classCGAL_1_1Segment__d.html#a7ce235ec9ee255f6b8a8353f294a85e4", null ],
+      [ "transform", "classCGAL_1_1Segment__d.html#a106e3fd39345e972e81c23b76840716e", null ],
+      [ "vector", "classCGAL_1_1Segment__d.html#a8e250993721d80b1f832615e2a638970", null ],
+      [ "vertex", "classCGAL_1_1Segment__d.html#a6cc6d132dc6cc119793e8ceab124d83e", null ],
       [ "common_endpoint", "classCGAL_1_1Segment__d.html#a0d38020369f56eb0a80c03c1b8a03439", null ],
       [ "parallel", "classCGAL_1_1Segment__d.html#a120651370c9a329bfd48d4036723cf63", null ],
       [ "weak_equality", "classCGAL_1_1Segment__d.html#a5d6573fa0986a07cae4b1be52af2d726", null ]
     ] ],
-    [ "Sphere_d", "classCGAL_1_1Sphere__d.html", [
+    [ "CGAL::Sphere_d< Kernel >", "classCGAL_1_1Sphere__d.html", [
       [ "LA", "classCGAL_1_1Sphere__d.html#a5c0b709ea14dc1cf49b8088fe0aafe15", null ],
       [ "point_iterator", "classCGAL_1_1Sphere__d.html#a5ae64d06825e1ec4b5729d2d1739f9ae", null ],
       [ "Sphere_d", "classCGAL_1_1Sphere__d.html#aca7e2a872a0e152913e38f96cb3ab393", null ],
       [ "Sphere_d", "classCGAL_1_1Sphere__d.html#a6d59a4c3fc42e3ee7822c54517ff4dd0", null ],
       [ "bounded_side", "classCGAL_1_1Sphere__d.html#aaf3c458d451f0d3e5054d1f87e488b76", null ],
-      [ "center", "classCGAL_1_1Sphere__d.html#a870b0ed243aa75f921b3b0b051f820a4", null ],
+      [ "center", "classCGAL_1_1Sphere__d.html#ad0403469fc1ca6a2c7b358a4649161ac", null ],
       [ "dimension", "classCGAL_1_1Sphere__d.html#ad622d2d04e8ac1f620c36e3b25ee5046", null ],
       [ "has_on_boundary", "classCGAL_1_1Sphere__d.html#aa6a4abb8b5024687f46ed07688ce814d", null ],
       [ "has_on_bounded_side", "classCGAL_1_1Sphere__d.html#a6e20d81170e58ab7bcb0ce2b3cabca99", null ],
@@ -182,17 +182,17 @@ var group__PkgKernelDKernelObjs =
       [ "has_on_unbounded_side", "classCGAL_1_1Sphere__d.html#af68af2fdc7f94b05edef2bd9add3fa11", null ],
       [ "is_degenerate", "classCGAL_1_1Sphere__d.html#aebcbe3c205a998792f4a3ad804f8380a", null ],
       [ "is_legal", "classCGAL_1_1Sphere__d.html#a1071e0a4f9d6f45f86bbef533bb7f998", null ],
-      [ "operator+", "classCGAL_1_1Sphere__d.html#aa851bfc30e0c3f5e2b1e90e59b08ac14", null ],
-      [ "opposite", "classCGAL_1_1Sphere__d.html#af46273308ce3c278f7312be6dbbbdc57", null ],
+      [ "operator+", "classCGAL_1_1Sphere__d.html#a6a0ddeafc93be32e4366790a80968b72", null ],
+      [ "opposite", "classCGAL_1_1Sphere__d.html#a85a6c8d59672a38e92e4b3d45b8fcd10", null ],
       [ "orientation", "classCGAL_1_1Sphere__d.html#a10e9d92be370467747accb3bed0c92c9", null ],
       [ "oriented_side", "classCGAL_1_1Sphere__d.html#adb0876359790861163d4eb2a01d28f8c", null ],
-      [ "point", "classCGAL_1_1Sphere__d.html#a0afc0dc04171a277c229a7df5e679d85", null ],
+      [ "point", "classCGAL_1_1Sphere__d.html#a027647295d8cad082255531c74861984", null ],
       [ "points_begin", "classCGAL_1_1Sphere__d.html#a84413276df4788abcb5f8d8f92592750", null ],
       [ "points_end", "classCGAL_1_1Sphere__d.html#aa7effce8dc037fe9bd077105b9d22b00", null ],
       [ "squared_radius", "classCGAL_1_1Sphere__d.html#ad6402b3560a4d7c89e8531ff66aca1a4", null ],
       [ "weak_equality", "classCGAL_1_1Sphere__d.html#ad3dc610c7902c12a1820f8fca2515c5d", null ]
     ] ],
-    [ "Vector_d", "classCGAL_1_1Vector__d.html", [
+    [ "CGAL::Vector_d< Kernel >", "classCGAL_1_1Vector__d.html", [
       [ "Base_vector", "classCGAL_1_1Vector__d.html#acf0128cadf001ecf33603b94c10f2313", null ],
       [ "Cartesian_const_iterator", "classCGAL_1_1Vector__d.html#a3a4e780b2cf234f94d443b0c04df3752", null ],
       [ "Homogeneous_const_iterator", "classCGAL_1_1Vector__d.html#af3c5d874b637f27ce2e6f12648528bda", null ],
@@ -208,27 +208,27 @@ var group__PkgKernelDKernelObjs =
       [ "cartesian_begin", "classCGAL_1_1Vector__d.html#a2428612148969ddd4bfb4af570805e0d", null ],
       [ "cartesian_end", "classCGAL_1_1Vector__d.html#aa84f119ef69d31fe0845bd7c112060ca", null ],
       [ "dimension", "classCGAL_1_1Vector__d.html#a944a1c3eda179f213d6848f9bac93c51", null ],
-      [ "direction", "classCGAL_1_1Vector__d.html#a55eec4dfd3060c020cb3b63918f29abf", null ],
+      [ "direction", "classCGAL_1_1Vector__d.html#ac4dd3794dfd1621a8bc3b2e9c7daa6e2", null ],
       [ "homogeneous", "classCGAL_1_1Vector__d.html#a30a7fa8723c1b6fcbf68f664f265c099", null ],
       [ "homogeneous_begin", "classCGAL_1_1Vector__d.html#a303f14d91232cdd25ea22786cbacd830", null ],
       [ "homogeneous_end", "classCGAL_1_1Vector__d.html#a6c6af5a05242e434fe1f18625b2e5abc", null ],
       [ "is_zero", "classCGAL_1_1Vector__d.html#ae596c0142cb2d3f4fdbea49fe6a736ce", null ],
+      [ "operator*", "classCGAL_1_1Vector__d.html#ab93791339deff5d2f5faad3b3dfec6b5", null ],
+      [ "operator*", "classCGAL_1_1Vector__d.html#a3636fa8a4b6d0cdcc08ca761f774d4d5", null ],
       [ "operator*", "classCGAL_1_1Vector__d.html#a3e45bec815ca82356699ac8316f09e2f", null ],
-      [ "operator*", "classCGAL_1_1Vector__d.html#a2b9303234ec2c07d2af5eaaeaf8b0b80", null ],
-      [ "operator*", "classCGAL_1_1Vector__d.html#abd09dce01e7b7162dbb9ea49408936b8", null ],
-      [ "operator*=", "classCGAL_1_1Vector__d.html#a4b5d14e11f451b051aa88668953450d8", null ],
-      [ "operator*=", "classCGAL_1_1Vector__d.html#ac4a92845920a48e26ad5d2192fcd37ab", null ],
-      [ "operator+", "classCGAL_1_1Vector__d.html#a6ee4f81148c90458c588e006c5bb23eb", null ],
-      [ "operator+=", "classCGAL_1_1Vector__d.html#a6c27910961ae513264776fea005b5a48", null ],
-      [ "operator-", "classCGAL_1_1Vector__d.html#a0d2fbf22e5e6ecbfb3ca129defec7128", null ],
-      [ "operator-", "classCGAL_1_1Vector__d.html#a55ab793cb483b0165846c9ebee3047d0", null ],
-      [ "operator-=", "classCGAL_1_1Vector__d.html#a9c1bbfed0276ae4a9fb0c2c5396b0981", null ],
-      [ "operator/", "classCGAL_1_1Vector__d.html#abafc93a87df96c8cf4bcccf2e6f4fa04", null ],
-      [ "operator/", "classCGAL_1_1Vector__d.html#a15cd51caff1eda20f73bc8ae9610f710", null ],
-      [ "operator/=", "classCGAL_1_1Vector__d.html#aceb744cec73a75e3a3c1cb82cef464ba", null ],
-      [ "operator/=", "classCGAL_1_1Vector__d.html#a026f11b79417e53e343b72ed6b9c6f83", null ],
+      [ "operator*=", "classCGAL_1_1Vector__d.html#a41278e116e5722f162fe71c0f45f0310", null ],
+      [ "operator*=", "classCGAL_1_1Vector__d.html#a15d0f3596124c72357fee80819599d1e", null ],
+      [ "operator+", "classCGAL_1_1Vector__d.html#a3304d743c8357fedc3954dc69850f8d6", null ],
+      [ "operator+=", "classCGAL_1_1Vector__d.html#a365ff3327e86a90d86c9d5e98a3a20ae", null ],
+      [ "operator-", "classCGAL_1_1Vector__d.html#aa1e303bff4b1939e3670cb0e11a8edce", null ],
+      [ "operator-", "classCGAL_1_1Vector__d.html#aa2eceb6f3cbbca60237ae6deb2018a16", null ],
+      [ "operator-=", "classCGAL_1_1Vector__d.html#a4925f42397ae33014323459fe240afbd", null ],
+      [ "operator/", "classCGAL_1_1Vector__d.html#a75fe7006bd5e272b722a5002f45ff862", null ],
+      [ "operator/", "classCGAL_1_1Vector__d.html#a9261acb0cde2d37cdfc6269c90688029", null ],
+      [ "operator/=", "classCGAL_1_1Vector__d.html#a6c28e5ac83cc71b63f4827a6163d1039", null ],
+      [ "operator/=", "classCGAL_1_1Vector__d.html#ade38e140c6a25524259500d68c6617ba", null ],
       [ "operator[]", "classCGAL_1_1Vector__d.html#a841643d06a91c206839168242d0dd03a", null ],
       [ "squared_length", "classCGAL_1_1Vector__d.html#ac270ccd0dd4ed479360a8ef18142e66a", null ],
-      [ "transform", "classCGAL_1_1Vector__d.html#a4aafd61862713c3f03ece362159dc859", null ]
+      [ "transform", "classCGAL_1_1Vector__d.html#af12a14784542f396b38f06421b4fb042", null ]
     ] ]
 ];
\ No newline at end of file
