@@ -2,16 +2,15 @@ var indexSectionsWithContent =
 {
   0: "23abcdefghijklmnopqrstuvwxyz~",
   1: "abcdefghijklmnopqrstuvwxyz",
-  2: "abcfikrs",
+  2: "abcfkrs",
   3: "bcdefgilmnopqrstuw",
   4: "abcdefghijklmnopqrstuvwxyz~",
-  5: "abcdefghilmnopqrstuvwz",
+  5: "abcdefghilmnopqrstuvz",
   6: "abcdefghiklmnopqrstuvwxyz",
   7: "abcdefghilmopqrstuvw",
-  8: "fp",
-  9: "gop",
-  10: "23abcdefghiklmnopqrstuvw",
-  11: "abcdeghilmnoprstu"
+  8: "gop",
+  9: "23abcdefghiklmnopqrstuvw",
+  10: "abcdeghilmnoprstu"
 };
 
 var indexSectionNames =
@@ -24,10 +23,9 @@ var indexSectionNames =
   5: "variables",
   6: "typedefs",
   7: "enums",
-  8: "enumvalues",
-  9: "related",
-  10: "groups",
-  11: "pages"
+  8: "related",
+  9: "groups",
+  10: "pages"
 };
 
 var indexSectionLabels =
@@ -40,9 +38,8 @@ var indexSectionLabels =
   5: "Variables",
   6: "Typedefs",
   7: "Enumerations",
-  8: "Enumerator",
-  9: "Friends",
-  10: "Modules",
-  11: "Pages"
+  8: "Friends",
+  9: "Modules",
+  10: "Pages"
 };
 
