@@ -7,14 +7,8 @@ var classMeshVertexBase__3 =
     [ "increment_erase_counter", "classMeshVertexBase__3.html#a585bdb0eafea242296d7c4401e348372", null ],
     [ "index", "classMeshVertexBase__3.html#abebd1b0f3f700fe57a704928ace7defa", null ],
     [ "is_special", "classMeshVertexBase__3.html#acf93d7be2b44bd02fa14f1c25c5a9fe4", null ],
-    [ "meshing_info", "classMeshVertexBase__3.html#a7ca709d26d942509094f91bfe82b6e9f", null ],
-    [ "next_intrusive", "classMeshVertexBase__3.html#a2618b5f06435baf578f3020ed4328c07", null ],
-    [ "previous_intrusive", "classMeshVertexBase__3.html#a543f343c70e58d584f7228d54b92bf85", null ],
     [ "set_dimension", "classMeshVertexBase__3.html#a9fe48efb87f7ee8fe294f2053be1eb26", null ],
     [ "set_erase_counter", "classMeshVertexBase__3.html#a8b614f58cca0341bf2fdb9e4d6fdcbdc", null ],
     [ "set_index", "classMeshVertexBase__3.html#a3604c8c08cbb9d0b1f02dc53901fbd63", null ],
-    [ "set_meshing_info", "classMeshVertexBase__3.html#a6af96724c173eae92f5a05fe60149de1", null ],
-    [ "set_next_intrusive", "classMeshVertexBase__3.html#a78e47af6e63c1e69367f29ba9800cc47", null ],
-    [ "set_previous_intrusive", "classMeshVertexBase__3.html#a58d19d7e99731d7e605c75f3f7c82b78", null ],
     [ "set_special", "classMeshVertexBase__3.html#a6148b21c4599c439b85e16405a1f6ad8", null ]
 ];
\ No newline at end of file
