@@ -1,113 +1,6 @@
 var group__PkgNefS2Ref =
 [
-    [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html", [
-      [ "Plane_3", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#ae0424a139b3dcb803e0c4cf360d0517d", null ],
-      [ "RT", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#a48687941c364232ca0c0d9016d2240b4", null ],
-      [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#a69ef68cb7b9bc9370408bf8e531582f8", null ],
-      [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#a93e550629d2f0b5d588d84139e9ec559", null ],
-      [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#afdc103f0bee43a986a10c89456f4efaa", null ],
-      [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#ab0f5d6916caf1817681e76b7cedb20b6", null ],
-      [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#adb8b9cfcc1971304ced2378161630873", null ],
-      [ "has_on", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#a8fafa6ab4ed4aae6041a278123479ca3", null ],
-      [ "opposite", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#aefad1a962721626fb4136e950bab1882", null ],
-      [ "orthogonal_pole", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#ac88f9822dff95c1b7809769064f7c17f", null ],
-      [ "plane", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#a16169c62073ce4f9dab4ef1f7101d7e0", null ],
-      [ "equal_as_sets", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#a2572790fd86655d81590558f4306e844", null ]
-    ] ],
-    [ "Sphere_point", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html", [
-      [ "RT", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#a03d887e4629a5960c1815efbf6a39f04", null ],
-      [ "Sphere_point", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#a4150742980bc18b32ff4c1bdc0607c4d", null ],
-      [ "Sphere_point", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#a28334ed96653885f9cd2dba17f26aaea", null ],
-      [ "antipode", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#af7ffa207910b15b382214fdfbebfe7d7", null ],
-      [ "operator!=", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#aafab2e645490e534792b5d13dcf01930", null ],
-      [ "operator==", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#a4b23479df91835144f34203e2f8a1dbf", null ],
-      [ "x", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#ae4ce5e1a5b53731030e26ee9cc8d810a", null ],
-      [ "y", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#a1e6d45924dd42214d8d16863bbe8bcb2", null ],
-      [ "z", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#a58e24d1f0ecaf391b3ae973f2c781b86", null ]
-    ] ],
-    [ "Sphere_segment", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html", [
-      [ "Sphere_segment", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#aee926b610fa7630e7268643e8a84cefa", null ],
-      [ "Sphere_segment", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a3ef491962ffe79c5fe007c303d79418a", null ],
-      [ "Sphere_segment", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a8872ce1c3ace56c91a5cce21fa478620", null ],
-      [ "Sphere_segment", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#aa4e6f7cd4c4586314482609101552353", null ],
-      [ "complement", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a2b15da3c1c903e8440f845c681057277", null ],
-      [ "has_in_relative_interior", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#aaea148e6706e4b182a62e54ee5c651ab", null ],
-      [ "has_on", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a7ae0fb9e84a7f4b35114f0bcc94a4d43", null ],
-      [ "is_degenerate", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a3843b38726d24a4d15eff7d738ca4c23", null ],
-      [ "is_halfcircle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a4ab7011b5872e7daf7b72d0a69f68ffb", null ],
-      [ "is_long", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#af88e089d775b1f994729a0940128bdee", null ],
-      [ "is_short", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a0529c3e49c34399f82be3f5cb7cc715b", null ],
-      [ "opposite", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a7e82052615f2e41930e03cc4e0d7e358", null ],
-      [ "source", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#aeb11f78c896777066fcc93b7c22b1fbe", null ],
-      [ "sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a9729e7cbce63352206524a2e2af0a823", null ],
-      [ "target", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a176119deee34dbd79cd1bfc54de1bdd9", null ]
-    ] ],
-    [ "SFace_cycle_iterator", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html", [
-      [ "SHalfedge_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a99e61543ca653d8cdb120e2f719d3001", null ],
-      [ "SHalfloop_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a68eb4d4d6c5f0671f4a0230a11f71ea3", null ],
-      [ "SVertex_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a93ab0ab0a1bad2d61b636f4e0738c894", null ],
-      [ "SFace_cycle_iterator", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a5438a750fa7d61bb755a0f84ad80f061", null ],
-      [ "is_shalfedge", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a8e9de6d02027275c1853b16320c82f10", null ],
-      [ "is_shalfloop", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a826ef4015fb345e2bdba176d263e4f1a", null ],
-      [ "is_svertex", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a814695bd7fde079c2983b1b06de3b4f2", null ],
-      [ "operator SHalfedge_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a8e9396bff6342423b38aca85e9787074", null ],
-      [ "operator SHalfloop_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a7dbad204241fe4bec916ddba416f137c", null ],
-      [ "operator SVertex_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#ad1795e830154500a55cd887370d61602", null ]
-    ] ],
-    [ "SFace", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html", [
-      [ "Mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#a39dfccc0534b0840d273b37222cfc4a0", null ],
-      [ "Object_list", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#ae6735d0f40633af7d18a9aab346d852a", null ],
-      [ "SFace_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#a4f93bd924b76f207525acca58dd72c0a", null ],
-      [ "SFace_cycle_const_iterator", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#acd88c4b64a2ead3fcf610c194d6550c8", null ],
-      [ "Vertex_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#a9c5c4507c0515e1e726d76fb8a3c4e1b", null ],
-      [ "Volume_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#aae34802b814a67a054eee1b99de2dae8", null ],
-      [ "mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#a9d3ca9aaf93d168457d0fbe2eb496719", null ],
-      [ "sface_cycle_begin", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#a4222ce1d3400591f7905e542ed77afd7", null ],
-      [ "sface_cycle_end", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#ac96f446990a5cf93cc6f04fb6f610ff8", null ]
-    ] ],
-    [ "SHalfedge", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html", [
-      [ "Mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#ac0b071dec83f044ff667485faaeb3b03", null ],
-      [ "SFace_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a5b2c23ce9e2d36913120b2775a1c4597", null ],
-      [ "SHalfedge_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a5f5f889f8d84ab0a8e129421aa9938ae", null ],
-      [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#aafbfca3be049e8d7612249fbca2c0cc7", null ],
-      [ "SVertex_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a00c7c413425371e5807719188c35d1e2", null ],
-      [ "circle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a87ffed344db4e8d00ecc42c8f5ae71eb", null ],
-      [ "cyclic_adj_pred", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#aea86adc4a416a859cc9b8e2b752b64e4", null ],
-      [ "cyclic_adj_succ", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a6abff4061dadcbf623384efe47ab2768", null ],
-      [ "in_inner_sface_cycle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a77ae158ecf8b54d33255114f3a61c592", null ],
-      [ "in_outer_sface_cycle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a16a86c855607cf1726ab55e282f41e03", null ],
-      [ "incident_sface", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a2cb097e031a6c4ace607ab3d19c07dc4", null ],
-      [ "mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a6d744670ca843f8226db23663a2682ed", null ],
-      [ "snext", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a1917fb58adbdcc4129bb34ede20a18ef", null ],
-      [ "source", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#ac35aa378aa3cd534599c548ddc1204d6", null ],
-      [ "sprev", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a8401be9acade2651e96c372ce7d259db", null ],
-      [ "target", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a5af030f7266b247eef3de14add061257", null ],
-      [ "twin", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#aef33f22b68666c5ba0ea8e7b0919039a", null ]
-    ] ],
-    [ "SHalfloop", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html", [
-      [ "Mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#a163ba79956bdae06ea674874e6c87589", null ],
-      [ "SFace_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#a4469fab3547cbd2f7b64a64a61be8b78", null ],
-      [ "SHalfloop_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#a563c9cd8961f5e55f2df003a281296a8", null ],
-      [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#a825295087bc538521459a7914f8962f6", null ],
-      [ "circle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#ac2b7d54ae2f62289e9864a7349ea5181", null ],
-      [ "incident_sface", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#a97d681d57a05ce7aab91c25b8007e034", null ],
-      [ "mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#aa01d28e026addaf88e76d24dd2440db2", null ],
-      [ "twin", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#a282c5e7d1d2a3fb39d2bb8fca247ba51", null ]
-    ] ],
-    [ "SVertex", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html", [
-      [ "Mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#af7f009d9447748063b0da991606cc64e", null ],
-      [ "SFace_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#a3b8866c962541702a392bf5d12ec5d9f", null ],
-      [ "SHalfedge_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#ac015b56d4e03646a796312046dc03851", null ],
-      [ "Sphere_point", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#a972031a832c4fb082b3e0f334e9177fb", null ],
-      [ "SVertex_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#a2907ee33260f4c79411d820d3fce9f94", null ],
-      [ "incident_sface", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#a670d98a967db5b341f0d753e18a4296c", null ],
-      [ "is_isolated", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#a02d431efc38f1163ecfafb9807797d45", null ],
-      [ "mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#affd93ac16a8bc2b8b43ad5bbbd3995fe", null ],
-      [ "out_sedge", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#a9f7044d55de9f079eba37a0176dff7d2", null ],
-      [ "point", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#a3091959bf9a5eaca96f7a023d3363d4e", null ],
-      [ "twin", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#ac28b96a0eb02289254ac8e0e1e299001", null ]
-    ] ],
-    [ "Nef_polyhedron_S2", "classCGAL_1_1Nef__polyhedron__S2.html", [
+    [ "CGAL::Nef_polyhedron_S2< Traits >", "classCGAL_1_1Nef__polyhedron__S2.html", [
       [ "Mark", "classCGAL_1_1Nef__polyhedron__S2.html#ae8b6c72a01dce16a34766db6d98c2a31", null ],
       [ "Object_handle", "classCGAL_1_1Nef__polyhedron__S2.html#ade3314ff1e537734fecd18250fe35d66", null ],
       [ "SFace_const_handle", "classCGAL_1_1Nef__polyhedron__S2.html#a54eeaf9cfa515807ca7f78966758a817", null ],
@@ -133,20 +26,20 @@ var group__PkgNefS2Ref =
       [ "Nef_polyhedron_S2", "classCGAL_1_1Nef__polyhedron__S2.html#ae7d36187df693fd995f4045df77e533f", null ],
       [ "Nef_polyhedron_S2", "classCGAL_1_1Nef__polyhedron__S2.html#aa5f3cf1ffda6bd8f1ecab9a85a9ed618", null ],
       [ "Nef_polyhedron_S2", "classCGAL_1_1Nef__polyhedron__S2.html#a08d0608f7cb4ccf45db39f341aee422c", null ],
-      [ "boundary", "classCGAL_1_1Nef__polyhedron__S2.html#ab0b0ab4542cefe90bcd467d71a7ffb93", null ],
+      [ "boundary", "classCGAL_1_1Nef__polyhedron__S2.html#a32d1cff74875444252ff235cd1940870", null ],
       [ "check_integrity_and_topological_planarity", "classCGAL_1_1Nef__polyhedron__S2.html#a33cbc044c8064754a879f7c1395532e8", null ],
       [ "clear", "classCGAL_1_1Nef__polyhedron__S2.html#aee67b7d1b1b38c7757801d0356f950c3", null ],
-      [ "closure", "classCGAL_1_1Nef__polyhedron__S2.html#abc92b55c3f5214ad6bc13cbfe4cdcd25", null ],
-      [ "complement", "classCGAL_1_1Nef__polyhedron__S2.html#afc29e300fdc792168b5560ee6be5f362", null ],
+      [ "closure", "classCGAL_1_1Nef__polyhedron__S2.html#aa251387ab68c6166e9c71a24249f6610", null ],
+      [ "complement", "classCGAL_1_1Nef__polyhedron__S2.html#a29ae190e33900ce0478491a46cb92f16", null ],
       [ "contained_in_boundary", "classCGAL_1_1Nef__polyhedron__S2.html#a9dee6ba287bd900cdc3eb5b4152bec01", null ],
       [ "contains", "classCGAL_1_1Nef__polyhedron__S2.html#a02aece81255baaf9e81b5f5c44a193a7", null ],
-      [ "difference", "classCGAL_1_1Nef__polyhedron__S2.html#a798cf66cd3c9e601f3b33777f4d377bb", null ],
+      [ "difference", "classCGAL_1_1Nef__polyhedron__S2.html#a564e6a69ec435001c8e3b6b00d382675", null ],
       [ "has_shalfloop", "classCGAL_1_1Nef__polyhedron__S2.html#ad722e67acc04745db44c8454ab7a4cf9", null ],
-      [ "interior", "classCGAL_1_1Nef__polyhedron__S2.html#ab7de2939ddbf54a4ca4dbe70bf902e0f", null ],
-      [ "intersection", "classCGAL_1_1Nef__polyhedron__S2.html#a8f757a2ab79ee25519de9dc27f5f89ea", null ],
+      [ "interior", "classCGAL_1_1Nef__polyhedron__S2.html#aa5020704e4c2cfe378c7bf474090ad8f", null ],
+      [ "intersection", "classCGAL_1_1Nef__polyhedron__S2.html#a74feb914dcd494bab09df764947487eb", null ],
       [ "is_empty", "classCGAL_1_1Nef__polyhedron__S2.html#ad564764787931e772adefdc94447fcec", null ],
       [ "is_sphere", "classCGAL_1_1Nef__polyhedron__S2.html#aaf24fe73f032c4198ff5c495fa19befa", null ],
-      [ "join", "classCGAL_1_1Nef__polyhedron__S2.html#a23221418d4ca5ef6f101a8a5d7b97f52", null ],
+      [ "join", "classCGAL_1_1Nef__polyhedron__S2.html#ac138ef61880d23edc1b9508b77619b09", null ],
       [ "locate", "classCGAL_1_1Nef__polyhedron__S2.html#a0adb7471ee81ac7b1b4794c5f53ce877", null ],
       [ "number_of_connected_components", "classCGAL_1_1Nef__polyhedron__S2.html#aede130b74358f79b2d2394b8d24a6007", null ],
       [ "number_of_sedges", "classCGAL_1_1Nef__polyhedron__S2.html#a4bb0d7cc86da41049c2de60472c717bb", null ],
@@ -159,8 +52,115 @@ var group__PkgNefS2Ref =
       [ "print_statistics", "classCGAL_1_1Nef__polyhedron__S2.html#a62cb1c299dfda0bb6fb9418b83f49792", null ],
       [ "ray_shoot", "classCGAL_1_1Nef__polyhedron__S2.html#a8f46cec3bc496185f542dd3adfe6823c", null ],
       [ "ray_shoot_to_boundary", "classCGAL_1_1Nef__polyhedron__S2.html#a447bac92b5e441d5f37d81910ca60fca", null ],
-      [ "regularization", "classCGAL_1_1Nef__polyhedron__S2.html#ad558bf3c89f37d35436a9d829faad0de", null ],
+      [ "regularization", "classCGAL_1_1Nef__polyhedron__S2.html#a4f66eae4ac246aee70a679502773b1a1", null ],
       [ "shalfloop", "classCGAL_1_1Nef__polyhedron__S2.html#aab7dfa6f629176f4ca3d694cf08dc0f3", null ],
-      [ "symmetric_difference", "classCGAL_1_1Nef__polyhedron__S2.html#ada841dfc92c91a863a5a873f1e1e84fa", null ]
+      [ "symmetric_difference", "classCGAL_1_1Nef__polyhedron__S2.html#af95032ce8b3f4648e2fd8fa6f659dff0", null ]
+    ] ],
+    [ "CGAL::Nef_polyhedron_S2< Traits >::Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html", [
+      [ "Plane_3", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#ae0424a139b3dcb803e0c4cf360d0517d", null ],
+      [ "RT", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#a48687941c364232ca0c0d9016d2240b4", null ],
+      [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#a69ef68cb7b9bc9370408bf8e531582f8", null ],
+      [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#a93e550629d2f0b5d588d84139e9ec559", null ],
+      [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#afdc103f0bee43a986a10c89456f4efaa", null ],
+      [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#ab0f5d6916caf1817681e76b7cedb20b6", null ],
+      [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#adb8b9cfcc1971304ced2378161630873", null ],
+      [ "has_on", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#a8fafa6ab4ed4aae6041a278123479ca3", null ],
+      [ "opposite", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#aefad1a962721626fb4136e950bab1882", null ],
+      [ "orthogonal_pole", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#ac88f9822dff95c1b7809769064f7c17f", null ],
+      [ "plane", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#a16169c62073ce4f9dab4ef1f7101d7e0", null ],
+      [ "equal_as_sets", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__circle.html#a2572790fd86655d81590558f4306e844", null ]
+    ] ],
+    [ "CGAL::Nef_polyhedron_S2< Traits >::Sphere_point", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html", [
+      [ "RT", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#a03d887e4629a5960c1815efbf6a39f04", null ],
+      [ "Sphere_point", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#a4150742980bc18b32ff4c1bdc0607c4d", null ],
+      [ "Sphere_point", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#a28334ed96653885f9cd2dba17f26aaea", null ],
+      [ "antipode", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#af7ffa207910b15b382214fdfbebfe7d7", null ],
+      [ "operator!=", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#aafab2e645490e534792b5d13dcf01930", null ],
+      [ "operator==", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#a4b23479df91835144f34203e2f8a1dbf", null ],
+      [ "x", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#ae4ce5e1a5b53731030e26ee9cc8d810a", null ],
+      [ "y", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#a1e6d45924dd42214d8d16863bbe8bcb2", null ],
+      [ "z", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__point.html#a58e24d1f0ecaf391b3ae973f2c781b86", null ]
+    ] ],
+    [ "CGAL::Nef_polyhedron_S2< Traits >::Sphere_segment", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html", [
+      [ "Sphere_segment", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#aee926b610fa7630e7268643e8a84cefa", null ],
+      [ "Sphere_segment", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a3ef491962ffe79c5fe007c303d79418a", null ],
+      [ "Sphere_segment", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a8872ce1c3ace56c91a5cce21fa478620", null ],
+      [ "Sphere_segment", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#aa4e6f7cd4c4586314482609101552353", null ],
+      [ "complement", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a2b15da3c1c903e8440f845c681057277", null ],
+      [ "has_in_relative_interior", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#aaea148e6706e4b182a62e54ee5c651ab", null ],
+      [ "has_on", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a7ae0fb9e84a7f4b35114f0bcc94a4d43", null ],
+      [ "is_degenerate", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a3843b38726d24a4d15eff7d738ca4c23", null ],
+      [ "is_halfcircle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a4ab7011b5872e7daf7b72d0a69f68ffb", null ],
+      [ "is_long", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#af88e089d775b1f994729a0940128bdee", null ],
+      [ "is_short", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a0529c3e49c34399f82be3f5cb7cc715b", null ],
+      [ "opposite", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a7e82052615f2e41930e03cc4e0d7e358", null ],
+      [ "source", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#a01a9f49ddc6884cb4c3a303b1485cc4a", null ],
+      [ "sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#ad7566d9a404e718f54a5dfbef0122843", null ],
+      [ "target", "classCGAL_1_1Nef__polyhedron__S2_1_1Sphere__segment.html#ab707bd46a57e29950d4605a4177e5cf9", null ]
+    ] ],
+    [ "CGAL::Nef_polyhedron_S2< Traits >::SFace_cycle_iterator", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html", [
+      [ "SHalfedge_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a99e61543ca653d8cdb120e2f719d3001", null ],
+      [ "SHalfloop_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a68eb4d4d6c5f0671f4a0230a11f71ea3", null ],
+      [ "SVertex_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a93ab0ab0a1bad2d61b636f4e0738c894", null ],
+      [ "SFace_cycle_iterator", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a5438a750fa7d61bb755a0f84ad80f061", null ],
+      [ "is_shalfedge", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a8e9de6d02027275c1853b16320c82f10", null ],
+      [ "is_shalfloop", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a826ef4015fb345e2bdba176d263e4f1a", null ],
+      [ "is_svertex", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a814695bd7fde079c2983b1b06de3b4f2", null ],
+      [ "operator SHalfedge_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a8e9396bff6342423b38aca85e9787074", null ],
+      [ "operator SHalfloop_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#a7dbad204241fe4bec916ddba416f137c", null ],
+      [ "operator SVertex_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace__cycle__iterator.html#ad1795e830154500a55cd887370d61602", null ]
+    ] ],
+    [ "CGAL::Nef_polyhedron_S2< Traits >::SFace", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html", [
+      [ "Mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#a39dfccc0534b0840d273b37222cfc4a0", null ],
+      [ "Object_list", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#ae6735d0f40633af7d18a9aab346d852a", null ],
+      [ "SFace_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#a4f93bd924b76f207525acca58dd72c0a", null ],
+      [ "SFace_cycle_const_iterator", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#acd88c4b64a2ead3fcf610c194d6550c8", null ],
+      [ "Vertex_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#a9c5c4507c0515e1e726d76fb8a3c4e1b", null ],
+      [ "Volume_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#aae34802b814a67a054eee1b99de2dae8", null ],
+      [ "mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#a6762ef92db7ec581fbd335acdb198c39", null ],
+      [ "sface_cycle_begin", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#a4222ce1d3400591f7905e542ed77afd7", null ],
+      [ "sface_cycle_end", "classCGAL_1_1Nef__polyhedron__S2_1_1SFace.html#ac96f446990a5cf93cc6f04fb6f610ff8", null ]
+    ] ],
+    [ "CGAL::Nef_polyhedron_S2< Traits >::SHalfedge", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html", [
+      [ "Mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#ac0b071dec83f044ff667485faaeb3b03", null ],
+      [ "SFace_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a5b2c23ce9e2d36913120b2775a1c4597", null ],
+      [ "SHalfedge_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a5f5f889f8d84ab0a8e129421aa9938ae", null ],
+      [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#aafbfca3be049e8d7612249fbca2c0cc7", null ],
+      [ "SVertex_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a00c7c413425371e5807719188c35d1e2", null ],
+      [ "circle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#afa3d76a0b74f890d68c342cf3642e547", null ],
+      [ "cyclic_adj_pred", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#aea86adc4a416a859cc9b8e2b752b64e4", null ],
+      [ "cyclic_adj_succ", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a6abff4061dadcbf623384efe47ab2768", null ],
+      [ "in_inner_sface_cycle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a77ae158ecf8b54d33255114f3a61c592", null ],
+      [ "in_outer_sface_cycle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a16a86c855607cf1726ab55e282f41e03", null ],
+      [ "incident_sface", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a2cb097e031a6c4ace607ab3d19c07dc4", null ],
+      [ "mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#ac629e98ed386830924d29e4800293a7c", null ],
+      [ "snext", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a1917fb58adbdcc4129bb34ede20a18ef", null ],
+      [ "source", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#ac35aa378aa3cd534599c548ddc1204d6", null ],
+      [ "sprev", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a8401be9acade2651e96c372ce7d259db", null ],
+      [ "target", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#a5af030f7266b247eef3de14add061257", null ],
+      [ "twin", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfedge.html#aef33f22b68666c5ba0ea8e7b0919039a", null ]
+    ] ],
+    [ "CGAL::Nef_polyhedron_S2< Traits >::SHalfloop", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html", [
+      [ "Mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#a163ba79956bdae06ea674874e6c87589", null ],
+      [ "SFace_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#a4469fab3547cbd2f7b64a64a61be8b78", null ],
+      [ "SHalfloop_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#a563c9cd8961f5e55f2df003a281296a8", null ],
+      [ "Sphere_circle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#a825295087bc538521459a7914f8962f6", null ],
+      [ "circle", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#a338e90237687c51fd6c07b9b0a22d588", null ],
+      [ "incident_sface", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#a97d681d57a05ce7aab91c25b8007e034", null ],
+      [ "mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#a0fe39bf66d07801ae7c878cc10282935", null ],
+      [ "twin", "classCGAL_1_1Nef__polyhedron__S2_1_1SHalfloop.html#a282c5e7d1d2a3fb39d2bb8fca247ba51", null ]
+    ] ],
+    [ "CGAL::Nef_polyhedron_S2< Traits >::SVertex", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html", [
+      [ "Mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#af7f009d9447748063b0da991606cc64e", null ],
+      [ "SFace_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#a3b8866c962541702a392bf5d12ec5d9f", null ],
+      [ "SHalfedge_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#ac015b56d4e03646a796312046dc03851", null ],
+      [ "Sphere_point", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#a972031a832c4fb082b3e0f334e9177fb", null ],
+      [ "SVertex_const_handle", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#a2907ee33260f4c79411d820d3fce9f94", null ],
+      [ "incident_sface", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#a670d98a967db5b341f0d753e18a4296c", null ],
+      [ "is_isolated", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#a02d431efc38f1163ecfafb9807797d45", null ],
+      [ "mark", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#a7912c30f075256677879bcba8614a566", null ],
+      [ "out_sedge", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#a9f7044d55de9f079eba37a0176dff7d2", null ],
+      [ "point", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#aca2bb880f2d4240d2cfa45d4481a4b77", null ],
+      [ "twin", "classCGAL_1_1Nef__polyhedron__S2_1_1SVertex.html#ac28b96a0eb02289254ac8e0e1e299001", null ]
     ] ]
 ];
\ No newline at end of file
