@@ -1,8 +1,8 @@
 var examples =
 [
-    [ "Optimal_transportation_reconstruction_2/otr2_indexed_output_example.cpp", "Optimal_transportation_reconstruction_2_2otr2_indexed_output_example_8cpp-example.html", null ],
-    [ "Optimal_transportation_reconstruction_2/otr2_list_output_example.cpp", "Optimal_transportation_reconstruction_2_2otr2_list_output_example_8cpp-example.html", null ],
-    [ "Optimal_transportation_reconstruction_2/otr2_mass_example.cpp", "Optimal_transportation_reconstruction_2_2otr2_mass_example_8cpp-example.html", null ],
     [ "Optimal_transportation_reconstruction_2/otr2_simplest_example.cpp", "Optimal_transportation_reconstruction_2_2otr2_simplest_example_8cpp-example.html", null ],
-    [ "Optimal_transportation_reconstruction_2/otr2_simplest_example_with_tolerance.cpp", "Optimal_transportation_reconstruction_2_2otr2_simplest_example_with_tolerance_8cpp-example.html", null ]
+    [ "Optimal_transportation_reconstruction_2/otr2_simplest_example_with_tolerance.cpp", "Optimal_transportation_reconstruction_2_2otr2_simplest_example_with_tolerance_8cpp-example.html", null ],
+    [ "Optimal_transportation_reconstruction_2/otr2_list_output_example.cpp", "Optimal_transportation_reconstruction_2_2otr2_list_output_example_8cpp-example.html", null ],
+    [ "Optimal_transportation_reconstruction_2/otr2_indexed_output_example.cpp", "Optimal_transportation_reconstruction_2_2otr2_indexed_output_example_8cpp-example.html", null ],
+    [ "Optimal_transportation_reconstruction_2/otr2_mass_example.cpp", "Optimal_transportation_reconstruction_2_2otr2_mass_example_8cpp-example.html", null ]
 ];
\ No newline at end of file
