@@ -1,50 +1,50 @@
 var NAVTREEINDEX0 =
 {
-"Periodic_2_triangulation_2_2draw_periodic_2_triangulation_2_8cpp-example.html":[6,0],
-"Periodic_2_triangulation_2_2p2t2_adding_handles_8cpp-example.html":[6,1],
-"Periodic_2_triangulation_2_2p2t2_colored_vertices_8cpp-example.html":[6,2],
-"Periodic_2_triangulation_2_2p2t2_covering_8cpp-example.html":[6,3],
-"Periodic_2_triangulation_2_2p2t2_find_conflicts_8cpp-example.html":[6,4],
-"Periodic_2_triangulation_2_2p2t2_geometric_access_8cpp-example.html":[6,5],
-"Periodic_2_triangulation_2_2p2t2_info_insert_with_pair_iterator_2_8cpp-example.html":[6,6],
-"Periodic_2_triangulation_2_2p2t2_info_insert_with_transform_iterator_2_8cpp-example.html":[6,7],
-"Periodic_2_triangulation_2_2p2t2_info_insert_with_zip_iterator_2_8cpp-example.html":[6,8],
-"Periodic_2_triangulation_2_2p2t2_large_point_set_8cpp-example.html":[6,9],
-"Periodic_2_triangulation_2_2p2t2_simple_example_8cpp-example.html":[6,10],
-"annotated.html":[5],
-"citelist.html":[4],
+"Periodic_2_triangulation_2_2draw_periodic_2_triangulation_2_8cpp-example.html":[4,10],
+"Periodic_2_triangulation_2_2p2t2_adding_handles_8cpp-example.html":[4,1],
+"Periodic_2_triangulation_2_2p2t2_colored_vertices_8cpp-example.html":[4,2],
+"Periodic_2_triangulation_2_2p2t2_covering_8cpp-example.html":[4,3],
+"Periodic_2_triangulation_2_2p2t2_find_conflicts_8cpp-example.html":[4,4],
+"Periodic_2_triangulation_2_2p2t2_geometric_access_8cpp-example.html":[4,5],
+"Periodic_2_triangulation_2_2p2t2_info_insert_with_pair_iterator_2_8cpp-example.html":[4,6],
+"Periodic_2_triangulation_2_2p2t2_info_insert_with_transform_iterator_2_8cpp-example.html":[4,7],
+"Periodic_2_triangulation_2_2p2t2_info_insert_with_zip_iterator_2_8cpp-example.html":[4,8],
+"Periodic_2_triangulation_2_2p2t2_large_point_set_8cpp-example.html":[4,9],
+"Periodic_2_triangulation_2_2p2t2_simple_example_8cpp-example.html":[4,0],
+"annotated.html":[3],
+"citelist.html":[2],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html":[1,0,1,0],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a157bfdc10dbe46cf899c5429d5172bf3":[1,0,1,0,22],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a1635470cabe4d0504b1fb03fdd45e76d":[1,0,1,0,15],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a20603e4b01393dbaa5a31a01f6977901":[1,0,1,0,19],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a2e0ce96972f58b40518da5e3ecccac71":[1,0,1,0,10],
-"classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a34cddddc11eaaef8d13e86bafe5f1e54":[1,0,1,0,6],
+"classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a34cddddc11eaaef8d13e86bafe5f1e54":[1,0,1,0,5],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a3552eab50e2756dc2a6193af32a6b96b":[1,0,1,0,23],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a3def54906f31f7e5747b7f2f3bfc2629":[1,0,1,0,16],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a43cbaa4db314639bb57973f90a6aa3ae":[1,0,1,0,12],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a478caa4de31c4ee14034108ec97dd644":[1,0,1,0,0],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a4d84f4d99d481ae8acf2b597b12a7e60":[1,0,1,0,17],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a51958623ba58352a8fc86e1ca6de932e":[1,0,1,0,3],
-"classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a68b81fceb14c5fac17b8fbeaea554818":[1,0,1,0,5],
+"classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a68b81fceb14c5fac17b8fbeaea554818":[1,0,1,0,8],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a6a5d9bb6b40fcfba124f38bb1f8a9d75":[1,0,1,0,13],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a6c7ef531dadff9ae0eba21023e35bd70":[1,0,1,0,14],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a72dfa0ea59912bbfc19f03a5cc1a0e3a":[1,0,1,0,1],
-"classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a72e03f24915506823d4990b7e2267066":[1,0,1,0,4],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a7878410f014d65489f462240c94da27e":[1,0,1,0,21],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a85fa6343883a518deb3bec95b6a5eb80":[1,0,1,0,9],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a919c9488837279f1074cfa88956a6089":[1,0,1,0,2],
-"classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#aa77b2699b8a4441a4d54d725f64d1026":[1,0,1,0,7],
+"classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#a9b77dfeda17c042d6467cca8764a109a":[1,0,1,0,4],
+"classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#aa77b2699b8a4441a4d54d725f64d1026":[1,0,1,0,6],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#ab8de80b6a289a419a053e7f1e5af421d":[1,0,1,0,18],
-"classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#adcdfc7a996f3daed51739e452367440a":[1,0,1,0,11],
+"classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#adedcf4bacfcd248c600a4df697072c0e":[1,0,1,0,11],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#aea42a6a73e6e2e8f1d6811d12eba1231":[1,0,1,0,20],
-"classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#aeed3cfb5ce4944d96fb26622ef5f8b34":[1,0,1,0,8],
+"classCGAL_1_1Periodic__2__Delaunay__triangulation__2.html#aeed3cfb5ce4944d96fb26622ef5f8b34":[1,0,1,0,7],
 "classCGAL_1_1Periodic__2__Delaunay__triangulation__traits__2.html":[1,0,2,0],
 "classCGAL_1_1Periodic__2__offset__2.html":[1,0,1,1],
 "classCGAL_1_1Periodic__2__triangulation__2.html":[1,0,1,2],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a04472945eac034df894ea298eb1e12e8":[1,0,1,2,64],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a060a17079d2af889889f748e35cfea5d":[1,0,1,2,98],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a060a17079d2af889889f748e35cfea5d":[1,0,1,2,96],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a06a61efed5c17690630561be9743b215":[1,0,1,2,94],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a0b11751aa806fdcc7b7167b8de51a6d0":[1,0,1,2,84],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a0b11751aa806fdcc7b7167b8de51a6d0":[1,0,1,2,85],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a0b6adbd05f0f6344634adbc4c663bb2f":[1,0,1,2,113],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a0b9c475473dbf401ba43918e13740bd3":[1,0,1,2,87],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a0b9f8cc07bc4336261a0f81936b6001c":[1,0,1,2,92],
@@ -57,14 +57,14 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Periodic__2__triangulation__2.html#a1c549f1756d07d1feedc9a28f20378e6":[1,0,1,2,34],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a1d72b6e5ced525c86656cccba579085c":[1,0,1,2,112],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a1e9c60f7c9844a33edff96b95aeb6c85":[1,0,1,2,108],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a1f61d18e992af64f78a6edaee7b39ea4":[1,0,1,2,95],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a1f61d18e992af64f78a6edaee7b39ea4":[1,0,1,2,98],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a217b56b0d5a8c222573f520a69a696ee":[1,0,1,2,16],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a26f95ec77dfd20b2fca3a7538ba822e9":[1,0,1,2,12],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a27ebd793056fc9ebad1fefd4515bf43e":[1,0,1,2,49],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a2a093ffaeed515ad25970e014aabe172":[1,0,1,2,25],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a2b3ca0261dbf3ccce4aec15d13a6aaad":[1,0,1,2,104],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a2ded6dd34ca5659d51242381eea358c9":[1,0,1,2,56],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a2e7e515df84fe16b8cf0b7e20a885cdc":[1,0,1,2,69],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a316c2075592f8ff1a892775ee30d7cf6":[1,0,1,2,80],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a316c2075592f8ff1a892775ee30d7cf6":[1,0,1,2,81],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a3373801d444360b8897a33fc17b3374a":[1,0,1,2,11],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a33b83fe142fac3ac76130c4a76321b55":[1,0,1,2,90],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a34d20312521b3b0b7ccdf58da7482372":[1,0,1,2,71],
@@ -86,14 +86,14 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Periodic__2__triangulation__2.html#a4d430d7a064cb69747d12bf457bb4e34a79bfbe67dbcd1336d3eee428704186a5":[1,0,1,2,33,0],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a4d430d7a064cb69747d12bf457bb4e34a7c2d718a7146d1632fd043fb567d4298":[1,0,1,2,33,3],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a4d430d7a064cb69747d12bf457bb4e34aa6c144304fc01b1864f902364e8eafaa":[1,0,1,2,33,2],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a5000e19e6e815b5711606266fcfebfcb":[1,0,1,2,81],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a5000e19e6e815b5711606266fcfebfcb":[1,0,1,2,80],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a56efd2023a8dad11387a6dab86cf2e23":[1,0,1,2,46],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a596154147817e922c9e8b6833fadc9f1":[1,0,1,2,77],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a5ac40038d72641c38dc2bf572dd397db":[1,0,1,2,3],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a5c72444beaaa8b21ea4952b18b7b9033":[1,0,1,2,31],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a5dd5f37123fd6036efac066caadbea75":[1,0,1,2,10],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a623385e8969628e1f35052c3056138cf":[1,0,1,2,17],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a63646ae43f76fc1e0cd6915cc1e7488a":[1,0,1,2,96],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a63646ae43f76fc1e0cd6915cc1e7488a":[1,0,1,2,99],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a6396dce2195a599e28e23636c9d6aa38":[1,0,1,2,89],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a66e3f7c70f8f269f1e0f1ced801a1228":[1,0,1,2,38],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a69ece036ad0bda74bad5c4700821a047":[1,0,1,2,61],
@@ -109,7 +109,7 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Periodic__2__triangulation__2.html#a7262186403a9101fef5d7d0d753ad77da93741e5589eebbc9a6be6afc99b682c5":[1,0,1,2,32,0],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a7262186403a9101fef5d7d0d753ad77daf2f86d31e148354a2bc3b8441a60a669":[1,0,1,2,32,3],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a785ea610b603b3b46432a4f9f81ab487":[1,0,1,2,52],
-"classCGAL_1_1Periodic__2__triangulation__2.html#a7d0970c780da0bc2ef511650749538db":[1,0,1,2,99],
+"classCGAL_1_1Periodic__2__triangulation__2.html#a7d0970c780da0bc2ef511650749538db":[1,0,1,2,97],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a7d71fa08fe049290396b1adfdcf5cd52":[1,0,1,2,2],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a8263cfb2d6fdb66cf6602ff2ff827fe2":[1,0,1,2,0],
 "classCGAL_1_1Periodic__2__triangulation__2.html#a8937e8d64de92ee8fc5e157570bcaa6d":[1,0,1,2,53],
@@ -123,30 +123,30 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Periodic__2__triangulation__2.html#aa5ce096101abb3ebfd7b60b490ab1bf5":[1,0,1,2,60],
 "classCGAL_1_1Periodic__2__triangulation__2.html#aa9e8fd864a5283591ebe3a5b6604d2a7":[1,0,1,2,55],
 "classCGAL_1_1Periodic__2__triangulation__2.html#aaa33358e9b53e571bba25d262fc7bb6a":[1,0,1,2,1],
-"classCGAL_1_1Periodic__2__triangulation__2.html#aae936df8de73aebdcffc89aaecb7078e":[1,0,1,2,104],
 "classCGAL_1_1Periodic__2__triangulation__2.html#aaf01cb12bf4b184fd838335d465cf744":[1,0,1,2,36],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ab037f5564a6b3f98a60db6de52e56fdc":[1,0,1,2,20],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ab10f412ca47129b067c67c5eb5d2780e":[1,0,1,2,78],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ab45c9e3f8b5fda944f17a97a953f93ef":[1,0,1,2,45],
-"classCGAL_1_1Periodic__2__triangulation__2.html#ab72b975f18a9b39dc15bc154430fe9bb":[1,0,1,2,97],
+"classCGAL_1_1Periodic__2__triangulation__2.html#ab72b975f18a9b39dc15bc154430fe9bb":[1,0,1,2,95],
 "classCGAL_1_1Periodic__2__triangulation__2.html#abbbb71864b0c6785564a67ab5e713317":[1,0,1,2,19],
 "classCGAL_1_1Periodic__2__triangulation__2.html#abc024d3aeeea49fde0f114ae892f0e0e":[1,0,1,2,62],
 "classCGAL_1_1Periodic__2__triangulation__2.html#abfa83d109e9a2608d1116495a1d048fd":[1,0,1,2,82],
 "classCGAL_1_1Periodic__2__triangulation__2.html#abfd5e78c312b58c4dc0b8eeb5f83decb":[1,0,1,2,30],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ac26888c1f1c38f0a9807802057ae2c29":[1,0,1,2,86],
-"classCGAL_1_1Periodic__2__triangulation__2.html#ac3defc6baf6bf783f744ccac15e6519b":[1,0,1,2,105],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ac7e52719d9a4d39bbcba45fa20a8f907":[1,0,1,2,29],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ac7ed2f011842355b5755741b02722724":[1,0,1,2,110],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ac852932d4386c6ad317154d0ce347fd9":[1,0,1,2,68],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ac8b35e267db25beab4be97c747fe4329":[1,0,1,2,102],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ac9fd79dbd0298e5e0987594a265383f1":[1,0,1,2,66],
 "classCGAL_1_1Periodic__2__triangulation__2.html#acb1c89e24081ca23f37b5ce2d426b462":[1,0,1,2,41],
-"classCGAL_1_1Periodic__2__triangulation__2.html#acf2a664ccbc0145f564b3bee1715fa33":[1,0,1,2,85],
+"classCGAL_1_1Periodic__2__triangulation__2.html#acebdb6d3b1e4daa6d92ba130e62d0657":[1,0,1,2,105],
+"classCGAL_1_1Periodic__2__triangulation__2.html#acf2a664ccbc0145f564b3bee1715fa33":[1,0,1,2,84],
 "classCGAL_1_1Periodic__2__triangulation__2.html#acf8e2bcf27f50a38d57ba232471f9674":[1,0,1,2,35],
 "classCGAL_1_1Periodic__2__triangulation__2.html#acf9971f3bb7efc8969adcece9ecfcb61":[1,0,1,2,59],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ad0b641b6d52787dc8cfa4564bc99d1a9":[1,0,1,2,27],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ad0f41e452a03916a4b2d3dfb18b1984d":[1,0,1,2,58],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ad8a3d925e6fbeaacb1fe3933850112aa":[1,0,1,2,24],
+"classCGAL_1_1Periodic__2__triangulation__2.html#ad9263e34d9cc9eb3691744d2dafb9580":[1,0,1,2,49],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ad98bf6fd33252a5dd64fffaed1260686":[1,0,1,2,76],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ae0ab4958fda18b92080c54b064c47717":[1,0,1,2,18],
 "classCGAL_1_1Periodic__2__triangulation__2.html#ae0c5f6a41ec6e7e946525a3ae183459c":[1,0,1,2,65],
@@ -167,87 +167,87 @@ var NAVTREEINDEX0 =
 "classCGAL_1_1Periodic__2__triangulation__hierarchy__2.html":[1,0,1,3],
 "classCGAL_1_1Periodic__2__triangulation__traits__2.html":[1,0,2,1],
 "classCGAL_1_1Periodic__2__triangulation__vertex__base__2.html":[1,0,3,1],
-"classPeriodic__2DelaunayTriangulationTraits__2.html":[1,0,0,0],
-"classPeriodic__2DelaunayTriangulationTraits__2.html#a1c71501e84c9c64c2e098ee36eabe882":[1,0,0,0,1],
-"classPeriodic__2DelaunayTriangulationTraits__2.html#a77bebbb9f4325f22c9078da35c92d894":[1,0,0,0,2],
-"classPeriodic__2DelaunayTriangulationTraits__2.html#aac6362ce7874f20c8f78b06cdcc94594":[1,0,0,0,0],
-"classPeriodic__2DelaunayTriangulationTraits__2.html#aadee376b242d20649b917753a5957d8e":[1,0,0,0,3],
-"classPeriodic__2DelaunayTriangulationTraits__2.html#aca6eb316cb0b1df5a4fc7cb15c9f7e10":[1,0,0,0,5],
-"classPeriodic__2DelaunayTriangulationTraits__2.html#adfc767807f4dd12e6983cc6a4d6ff634":[1,0,0,0,4],
-"classPeriodic__2Offset__2.html":[1,0,0,1],
-"classPeriodic__2Offset__2.html#a00ad1b948ec12e340eec53b00f0178ca":[1,0,0,1,2],
-"classPeriodic__2Offset__2.html#a012db82ba30531cc42251126df2c262a":[1,0,0,1,4],
-"classPeriodic__2Offset__2.html#a0cfb887e52547f87f54042757622114c":[1,0,0,1,6],
-"classPeriodic__2Offset__2.html#a130fec53f5ad0943117cb1425cd94113":[1,0,0,1,10],
-"classPeriodic__2Offset__2.html#a1748a39bb55381d31e77621cebe24909":[1,0,0,1,15],
-"classPeriodic__2Offset__2.html#a2139b0d6714706306a29d8ed74fa6d2d":[1,0,0,1,16],
-"classPeriodic__2Offset__2.html#a2d3abc875eeb3cd0af273e58a5aa4504":[1,0,0,1,11],
-"classPeriodic__2Offset__2.html#a2ddf9fbecf50180ddea17436cdc7bd4b":[1,0,0,1,7],
-"classPeriodic__2Offset__2.html#a4c4fd62dfefa2695093400c8634b29d9":[1,0,0,1,3],
-"classPeriodic__2Offset__2.html#a64d1ad770cbbc4ec98ae588b49d8f5c5":[1,0,0,1,14],
-"classPeriodic__2Offset__2.html#a6673ca948eee733689efea306b1b5a2f":[1,0,0,1,8],
-"classPeriodic__2Offset__2.html#a84bf21463be8975a245e93556e6b8501":[1,0,0,1,12],
-"classPeriodic__2Offset__2.html#aa057f44bc806fb32e6df45c4d51219cf":[1,0,0,1,13],
-"classPeriodic__2Offset__2.html#aba9411cb4b05e19b1573ec103066d7d0":[1,0,0,1,9],
-"classPeriodic__2Offset__2.html#ae897661b3aab6b705b1ba88728d886d6":[1,0,0,1,1],
-"classPeriodic__2Offset__2.html#aed26e3740687d94b2f121d48150059fe":[1,0,0,1,5],
-"classPeriodic__2Offset__2.html#afdf3d04a44aeb21b90906c4af04df50f":[1,0,0,1,0],
-"classPeriodic__2TriangulationFaceBase__2.html":[1,0,0,2],
-"classPeriodic__2TriangulationFaceBase__2.html#a791d3dfac38be678339f12d53ece7f0e":[1,0,0,2,2],
-"classPeriodic__2TriangulationFaceBase__2.html#a7f1c444b696a89528de2d3aa7d824de5":[1,0,0,2,0],
-"classPeriodic__2TriangulationFaceBase__2.html#ae16bdd01d7eb10d4fcccdb3135b6f63d":[1,0,0,2,1],
-"classPeriodic__2TriangulationTraits__2.html":[1,0,0,3],
-"classPeriodic__2TriangulationTraits__2.html#a02581656f89b19dadb430bcdc4015e45":[1,0,0,3,15],
-"classPeriodic__2TriangulationTraits__2.html#a1a3b699579e4974bae7d8a6dab7f4b15":[1,0,0,3,23],
-"classPeriodic__2TriangulationTraits__2.html#a289ca49cd643c36fdf22e795772c0bf1":[1,0,0,3,20],
-"classPeriodic__2TriangulationTraits__2.html#a2a4651a1b334bb9044aac96bd69997bc":[1,0,0,3,17],
-"classPeriodic__2TriangulationTraits__2.html#a3f1881dede6391469d5e1cf279564de8":[1,0,0,3,7],
-"classPeriodic__2TriangulationTraits__2.html#a4983fdbd6a88c5475a3a237a3251079f":[1,0,0,3,0],
-"classPeriodic__2TriangulationTraits__2.html#a6abfc7fafee4db6f9bc50839c1a796dc":[1,0,0,3,22],
-"classPeriodic__2TriangulationTraits__2.html#a7521abd8845c942d454bac9bce40f300":[1,0,0,3,9],
-"classPeriodic__2TriangulationTraits__2.html#a768816066a5f5f0052530d56a509254c":[1,0,0,3,10],
-"classPeriodic__2TriangulationTraits__2.html#a93bd4db6752da676535db6bc32532ed0":[1,0,0,3,25],
-"classPeriodic__2TriangulationTraits__2.html#a97ab75ad2f5a3ea7d50868da55c66ade":[1,0,0,3,8],
-"classPeriodic__2TriangulationTraits__2.html#aaffe0f5840796f20f4d8ab0780b1bbf4":[1,0,0,3,24],
-"classPeriodic__2TriangulationTraits__2.html#ab12eb3c65b94e1bbe7a6106c4b5011c9":[1,0,0,3,13],
-"classPeriodic__2TriangulationTraits__2.html#ab7c30d2187455a5cf9393f3f6362bc64":[1,0,0,3,1],
-"classPeriodic__2TriangulationTraits__2.html#abe2dbf3015e6208926c76377fd0b8108":[1,0,0,3,16],
-"classPeriodic__2TriangulationTraits__2.html#abe2f590b802612209c24436cc264a85a":[1,0,0,3,6],
-"classPeriodic__2TriangulationTraits__2.html#ac7d9831e961148f750ea0b650d87a7c7":[1,0,0,3,12],
-"classPeriodic__2TriangulationTraits__2.html#ad078164ca673c11a6880ba19d8e2a72f":[1,0,0,3,3],
-"classPeriodic__2TriangulationTraits__2.html#ad2707ce0f788814fae7f42dfef253fdf":[1,0,0,3,18],
-"classPeriodic__2TriangulationTraits__2.html#ad4494418ec4972b694b69ee010c8114c":[1,0,0,3,11],
-"classPeriodic__2TriangulationTraits__2.html#ad4f22ed3e3d426a915a866c8d8992146":[1,0,0,3,4],
-"classPeriodic__2TriangulationTraits__2.html#adf6a6f703edc63a0d59736fe2e6edba3":[1,0,0,3,2],
-"classPeriodic__2TriangulationTraits__2.html#ae215ca417884ff6c3d5a2a0b4677726e":[1,0,0,3,5],
-"classPeriodic__2TriangulationTraits__2.html#ae2c35b0ddc579152c08d7179a628688d":[1,0,0,3,19],
-"classPeriodic__2TriangulationTraits__2.html#ae410125973b72577548ac6808fceadc8":[1,0,0,3,14],
-"classPeriodic__2TriangulationTraits__2.html#aeb9faf7b6b9b101dee9ee109ab3491af":[1,0,0,3,21],
-"classPeriodic__2TriangulationVertexBase__2.html":[1,0,0,4],
-"classPeriodic__2TriangulationVertexBase__2.html#a80c405c869765c282d8b9dee9e780033":[1,0,0,4,0],
-"classPeriodic__2TriangulationVertexBase__2.html#acd6691e4150836572ecfd33ab644449c":[1,0,0,4,2],
-"classPeriodic__2TriangulationVertexBase__2.html#acfe753db8292d77c195ceab78242b1c6":[1,0,0,4,1],
-"classPeriodic__2TriangulationVertexBase__2.html#ad7aa9e7aa299756823e5e068ee1b0779":[1,0,0,4,4],
-"classPeriodic__2TriangulationVertexBase__2.html#ae6e9fa07908252e62063982874c14cec":[1,0,0,4,3],
-"examples.html":[6],
+"classGraphicsSceneOptionsPeriodic2Triangulation2.html":[1,0,0,0],
+"classGraphicsSceneOptionsPeriodic2Triangulation2.html#a02b3711b82cae36a4c5fe9a7ed74eb33":[1,0,0,0,1],
+"classGraphicsSceneOptionsPeriodic2Triangulation2.html#a051f6b82241f8a0bf381a3c6913a93e3":[1,0,0,0,4],
+"classGraphicsSceneOptionsPeriodic2Triangulation2.html#a063ccdc1c2a5101d5ef94223a07fc85f":[1,0,0,0,0],
+"classGraphicsSceneOptionsPeriodic2Triangulation2.html#a170b664e4444f538db2d91b3d96d0333":[1,0,0,0,3],
+"classGraphicsSceneOptionsPeriodic2Triangulation2.html#a8c54c31658e8f71ddbff909e332e742a":[1,0,0,0,2],
+"classGraphicsSceneOptionsPeriodic2Triangulation2.html#ae82f7aba5fab9c177871cf9fff7d86da":[1,0,0,0,5],
+"classPeriodic__2DelaunayTriangulationTraits__2.html":[1,0,0,1],
+"classPeriodic__2DelaunayTriangulationTraits__2.html#a1c71501e84c9c64c2e098ee36eabe882":[1,0,0,1,1],
+"classPeriodic__2DelaunayTriangulationTraits__2.html#a77bebbb9f4325f22c9078da35c92d894":[1,0,0,1,2],
+"classPeriodic__2DelaunayTriangulationTraits__2.html#aac6362ce7874f20c8f78b06cdcc94594":[1,0,0,1,0],
+"classPeriodic__2DelaunayTriangulationTraits__2.html#aadee376b242d20649b917753a5957d8e":[1,0,0,1,3],
+"classPeriodic__2DelaunayTriangulationTraits__2.html#aca6eb316cb0b1df5a4fc7cb15c9f7e10":[1,0,0,1,5],
+"classPeriodic__2DelaunayTriangulationTraits__2.html#adfc767807f4dd12e6983cc6a4d6ff634":[1,0,0,1,4],
+"classPeriodic__2Offset__2.html":[1,0,0,2],
+"classPeriodic__2Offset__2.html#a00ad1b948ec12e340eec53b00f0178ca":[1,0,0,2,2],
+"classPeriodic__2Offset__2.html#a012db82ba30531cc42251126df2c262a":[1,0,0,2,4],
+"classPeriodic__2Offset__2.html#a0cfb887e52547f87f54042757622114c":[1,0,0,2,6],
+"classPeriodic__2Offset__2.html#a130fec53f5ad0943117cb1425cd94113":[1,0,0,2,10],
+"classPeriodic__2Offset__2.html#a1748a39bb55381d31e77621cebe24909":[1,0,0,2,15],
+"classPeriodic__2Offset__2.html#a2139b0d6714706306a29d8ed74fa6d2d":[1,0,0,2,16],
+"classPeriodic__2Offset__2.html#a2d3abc875eeb3cd0af273e58a5aa4504":[1,0,0,2,11],
+"classPeriodic__2Offset__2.html#a2ddf9fbecf50180ddea17436cdc7bd4b":[1,0,0,2,8],
+"classPeriodic__2Offset__2.html#a4c4fd62dfefa2695093400c8634b29d9":[1,0,0,2,3],
+"classPeriodic__2Offset__2.html#a64d1ad770cbbc4ec98ae588b49d8f5c5":[1,0,0,2,14],
+"classPeriodic__2Offset__2.html#a6673ca948eee733689efea306b1b5a2f":[1,0,0,2,7],
+"classPeriodic__2Offset__2.html#a84bf21463be8975a245e93556e6b8501":[1,0,0,2,12],
+"classPeriodic__2Offset__2.html#aa057f44bc806fb32e6df45c4d51219cf":[1,0,0,2,13],
+"classPeriodic__2Offset__2.html#aba9411cb4b05e19b1573ec103066d7d0":[1,0,0,2,9],
+"classPeriodic__2Offset__2.html#ae897661b3aab6b705b1ba88728d886d6":[1,0,0,2,1],
+"classPeriodic__2Offset__2.html#aed26e3740687d94b2f121d48150059fe":[1,0,0,2,5],
+"classPeriodic__2Offset__2.html#afdf3d04a44aeb21b90906c4af04df50f":[1,0,0,2,0],
+"classPeriodic__2TriangulationFaceBase__2.html":[1,0,0,3],
+"classPeriodic__2TriangulationFaceBase__2.html#a791d3dfac38be678339f12d53ece7f0e":[1,0,0,3,2],
+"classPeriodic__2TriangulationFaceBase__2.html#a7f1c444b696a89528de2d3aa7d824de5":[1,0,0,3,0],
+"classPeriodic__2TriangulationFaceBase__2.html#ae16bdd01d7eb10d4fcccdb3135b6f63d":[1,0,0,3,1],
+"classPeriodic__2TriangulationTraits__2.html":[1,0,0,4],
+"classPeriodic__2TriangulationTraits__2.html#a02581656f89b19dadb430bcdc4015e45":[1,0,0,4,15],
+"classPeriodic__2TriangulationTraits__2.html#a1a3b699579e4974bae7d8a6dab7f4b15":[1,0,0,4,23],
+"classPeriodic__2TriangulationTraits__2.html#a289ca49cd643c36fdf22e795772c0bf1":[1,0,0,4,20],
+"classPeriodic__2TriangulationTraits__2.html#a2a4651a1b334bb9044aac96bd69997bc":[1,0,0,4,17],
+"classPeriodic__2TriangulationTraits__2.html#a3f1881dede6391469d5e1cf279564de8":[1,0,0,4,7],
+"classPeriodic__2TriangulationTraits__2.html#a4983fdbd6a88c5475a3a237a3251079f":[1,0,0,4,0],
+"classPeriodic__2TriangulationTraits__2.html#a6abfc7fafee4db6f9bc50839c1a796dc":[1,0,0,4,22],
+"classPeriodic__2TriangulationTraits__2.html#a7521abd8845c942d454bac9bce40f300":[1,0,0,4,9],
+"classPeriodic__2TriangulationTraits__2.html#a768816066a5f5f0052530d56a509254c":[1,0,0,4,10],
+"classPeriodic__2TriangulationTraits__2.html#a93bd4db6752da676535db6bc32532ed0":[1,0,0,4,25],
+"classPeriodic__2TriangulationTraits__2.html#a97ab75ad2f5a3ea7d50868da55c66ade":[1,0,0,4,8],
+"classPeriodic__2TriangulationTraits__2.html#aaffe0f5840796f20f4d8ab0780b1bbf4":[1,0,0,4,24],
+"classPeriodic__2TriangulationTraits__2.html#ab12eb3c65b94e1bbe7a6106c4b5011c9":[1,0,0,4,13],
+"classPeriodic__2TriangulationTraits__2.html#ab7c30d2187455a5cf9393f3f6362bc64":[1,0,0,4,1],
+"classPeriodic__2TriangulationTraits__2.html#abe2dbf3015e6208926c76377fd0b8108":[1,0,0,4,16],
+"classPeriodic__2TriangulationTraits__2.html#abe2f590b802612209c24436cc264a85a":[1,0,0,4,6],
+"classPeriodic__2TriangulationTraits__2.html#ac7d9831e961148f750ea0b650d87a7c7":[1,0,0,4,12],
+"classPeriodic__2TriangulationTraits__2.html#ad078164ca673c11a6880ba19d8e2a72f":[1,0,0,4,3],
+"classPeriodic__2TriangulationTraits__2.html#ad2707ce0f788814fae7f42dfef253fdf":[1,0,0,4,18],
+"classPeriodic__2TriangulationTraits__2.html#ad4494418ec4972b694b69ee010c8114c":[1,0,0,4,11],
+"classPeriodic__2TriangulationTraits__2.html#ad4f22ed3e3d426a915a866c8d8992146":[1,0,0,4,4],
+"classPeriodic__2TriangulationTraits__2.html#adf6a6f703edc63a0d59736fe2e6edba3":[1,0,0,4,2],
+"classPeriodic__2TriangulationTraits__2.html#ae215ca417884ff6c3d5a2a0b4677726e":[1,0,0,4,5],
+"classPeriodic__2TriangulationTraits__2.html#ae2c35b0ddc579152c08d7179a628688d":[1,0,0,4,19],
+"classPeriodic__2TriangulationTraits__2.html#ae410125973b72577548ac6808fceadc8":[1,0,0,4,14],
+"classPeriodic__2TriangulationTraits__2.html#aeb9faf7b6b9b101dee9ee109ab3491af":[1,0,0,4,21],
+"classPeriodic__2TriangulationVertexBase__2.html":[1,0,0,5],
+"classPeriodic__2TriangulationVertexBase__2.html#a80c405c869765c282d8b9dee9e780033":[1,0,0,5,0],
+"classPeriodic__2TriangulationVertexBase__2.html#acd6691e4150836572ecfd33ab644449c":[1,0,0,5,2],
+"classPeriodic__2TriangulationVertexBase__2.html#acfe753db8292d77c195ceab78242b1c6":[1,0,0,5,1],
+"classPeriodic__2TriangulationVertexBase__2.html#ad7aa9e7aa299756823e5e068ee1b0779":[1,0,0,5,4],
+"classPeriodic__2TriangulationVertexBase__2.html#ae6e9fa07908252e62063982874c14cec":[1,0,0,5,3],
+"examples.html":[4],
 "group__PkgDrawPeriodic2Triangulation2.html":[1,0,5],
-"group__PkgDrawPeriodic2Triangulation2.html#gaf85df729a75a5ce787d12dcf9ec87175":[1,0,5,0],
+"group__PkgDrawPeriodic2Triangulation2.html#ga32f78e3c6c42b0de0e69f377bd6dd132":[1,0,5,2],
+"group__PkgDrawPeriodic2Triangulation2.html#ga797cc784e27c065e2b04415b8195a07e":[1,0,5,3],
+"group__PkgDrawPeriodic2Triangulation2.html#gadbb3768cc61c883746436cf59fa6a8c3":[1,0,5,1],
+"group__PkgDrawPeriodic2Triangulation2.html#gaf2c5b3b3d44cdc000f883c775e96d4f2":[1,0,5,4],
 "group__PkgPeriodic2Triangulation2Concepts.html":[1,0,0],
 "group__PkgPeriodic2Triangulation2Enums.html":[1,0,4],
 "group__PkgPeriodic2Triangulation2MainClasses.html":[1,0,1],
 "group__PkgPeriodic2Triangulation2Ref.html":[1,0],
 "group__PkgPeriodic2Triangulation2TraitsClasses.html":[1,0,2],
 "group__PkgPeriodic2Triangulation2VertexFaceClasses.html":[1,0,3],
-"hasModels.html":[3],
 "index.html":[0],
-"index.html":[],
-"index.html#P2T2ExampleAddingHandles":[0,5,1,1],
-"index.html#P2T2ExampleBasic":[0,5,0],
-"index.html#P2T2ExampleColor":[0,5,1,0],
-"index.html#P2T2ExampleCovering":[0,5,2],
-"index.html#P2T2ExampleGeometricAccess":[0,5,4],
-"index.html#P2T2ExampleLargePointSet":[0,5,3],
-"index.html#P2T2ExampleVertexBase":[0,5,1],
-"index.html#P2T2FlexDesign":[0,4,2],
-"index.html#P2T2_Delaunay":[0,2]
+"index.html":[]
 };
