@@ -1,9 +1,6 @@
 var structCGAL_1_1Polyhedral__envelope =
 [
-    [ "Point_3", "structCGAL_1_1Polyhedral__envelope.html#a49d2e4062a444ac963b77ea2a188558f", null ],
     [ "Polyhedral_envelope", "structCGAL_1_1Polyhedral__envelope.html#a891b808e7923aed227837b34f2e2f4dc", null ],
-    [ "Polyhedral_envelope", "structCGAL_1_1Polyhedral__envelope.html#af8fa17dfb5c36b071887b47efb797735", null ],
-    [ "Polyhedral_envelope", "structCGAL_1_1Polyhedral__envelope.html#a1073e8e60849d138df489913433fea4a", null ],
     [ "Polyhedral_envelope", "structCGAL_1_1Polyhedral__envelope.html#a1ecff8afd71b42e8757fa2e24d1d4555", null ],
     [ "Polyhedral_envelope", "structCGAL_1_1Polyhedral__envelope.html#a52a89d064aa67024105116416db80a60", null ],
     [ "Polyhedral_envelope", "structCGAL_1_1Polyhedral__envelope.html#a4609257ab34fa9b48ce3e35c8f7b5d98", null ],
@@ -11,9 +8,7 @@ var structCGAL_1_1Polyhedral__envelope =
     [ "operator()", "structCGAL_1_1Polyhedral__envelope.html#aa8dafcc6b164d83c385f210bc40f6218", null ],
     [ "operator()", "structCGAL_1_1Polyhedral__envelope.html#ae135094582463f12f6eb1b545f8574b7", null ],
     [ "operator()", "structCGAL_1_1Polyhedral__envelope.html#a235323a9a43dbc8a03720c7e7758d649", null ],
-    [ "operator()", "structCGAL_1_1Polyhedral__envelope.html#a81553453f9dbdbd5156c8b462262b29e", null ],
     [ "operator()", "structCGAL_1_1Polyhedral__envelope.html#a34319c5ca57545a1be3bf765879b0cab", null ],
-    [ "operator()", "structCGAL_1_1Polyhedral__envelope.html#adcc17b48082905b5de4a6064e8d3c873", null ],
-    [ "operator=", "structCGAL_1_1Polyhedral__envelope.html#a670bdde407105aab737903170e3a7d15", null ],
-    [ "operator=", "structCGAL_1_1Polyhedral__envelope.html#ac115eee33373d3e9bbdb41ce1844b0b7", null ]
+    [ "operator()", "structCGAL_1_1Polyhedral__envelope.html#a81553453f9dbdbd5156c8b462262b29e", null ],
+    [ "operator()", "structCGAL_1_1Polyhedral__envelope.html#adcc17b48082905b5de4a6064e8d3c873", null ]
 ];
\ No newline at end of file
