@@ -1,5 +1,11 @@
 var NAVTREEINDEX2 =
 {
+"index.html#Triangulation_2ARepresentationBasedonFaces":[0,1,1],
+"index.html#Triangulation_2AddingColors":[0,10,2],
+"index.html#Triangulation_2AddingHandles":[0,10,3],
+"index.html#Triangulation_2Design":[0,11],
+"index.html#Triangulation_2ExampleBuildingFromSoup":[0,8,3],
+"index.html#Triangulation_2ExampleBuildingaTriangulated":[0,8,2],
 "index.html#Triangulation_2Implementation":[0,3,1],
 "index.html#Triangulation_2SettingInformationWhileInserting":[0,10,4],
 "index.html#Triangulation_2TheFaceBaseClass":[0,7,1],
@@ -14,9 +20,7 @@ var NAVTREEINDEX2 =
 "index.html#Triangulation_2UsinganIteratorOverPairs":[0,10,5],
 "index.html#Triangulation_2UsingtheBoostTransformIterator":[0,10,7],
 "index.html#Triangulation_2UsingtheBoostZipIterator":[0,10,6],
-"models.html":[3],
 "modules.html":[1],
-"namespaceCGAL.html":[6,0],
 "pages.html":[],
 "structCGAL_1_1Exact__intersections__tag.html":[1,0,1,4],
 "structCGAL_1_1Exact__predicates__tag.html":[1,0,1,5],
