@@ -1,7 +1,7 @@
 var group__PkgTriangulation3TraitsClasses =
 [
-    [ "Regular_triangulation_euclidean_traits_3", "classCGAL_1_1Regular__triangulation__euclidean__traits__3.html", null ],
-    [ "Robust_weighted_circumcenter_filtered_traits_3", "classCGAL_1_1Robust__weighted__circumcenter__filtered__traits__3.html", [
+    [ "CGAL::Regular_triangulation_euclidean_traits_3< K, Weight >", "classCGAL_1_1Regular__triangulation__euclidean__traits__3.html", null ],
+    [ "CGAL::Robust_weighted_circumcenter_filtered_traits_3< K >", "classCGAL_1_1Robust__weighted__circumcenter__filtered__traits__3.html", [
       [ "Compute_squared_radius_3", "classCGAL_1_1Robust__weighted__circumcenter__filtered__traits__3.html#a158b483c8a865b4ea352e2fb8458814f", null ],
       [ "Compute_squared_radius_smallest_orthogonal_sphere_3", "classCGAL_1_1Robust__weighted__circumcenter__filtered__traits__3.html#a0d2e1fd39d4abf5fde79d54e36a14db5", null ],
       [ "Construct_weighted_circumcenter_3", "classCGAL_1_1Robust__weighted__circumcenter__filtered__traits__3.html#a55d72256d8e35161f06d9a5adb45e19e", null ],
