@@ -1,22 +1,26 @@
 var NAVTREEINDEX1 =
 {
+"classCGAL_1_1Triangulation__3.html#a80ba1634c96f534d18d2d2420f65561f":[1,0,1,2,64],
+"classCGAL_1_1Triangulation__3.html#a80f8771ed8bca545ca451afae14b77ed":[1,0,1,2,120],
 "classCGAL_1_1Triangulation__3.html#a81373c29a596ba2f1d6d93e62d1f0d79":[1,0,1,2,100],
 "classCGAL_1_1Triangulation__3.html#a822c7264ac03f629735cb85be4871e1f":[1,0,1,2,31],
 "classCGAL_1_1Triangulation__3.html#a83d347f8d914b78f17f6817fdb0b7a14":[1,0,1,2,184],
-"classCGAL_1_1Triangulation__3.html#a85d53f656ef4d67ccbf6eaed424e0a35":[1,0,1,2,97],
-"classCGAL_1_1Triangulation__3.html#a8766c9a0c2a84203be31537e5e015646":[1,0,1,2,127],
-"classCGAL_1_1Triangulation__3.html#a883fed00b53cae9e85feb20230f54dd9":[1,0,1,2,82],
-"classCGAL_1_1Triangulation__3.html#a89a5c93d1e8a43cef317ef289f1d5482":[1,0,1,2,91],
+"classCGAL_1_1Triangulation__3.html#a85d53f656ef4d67ccbf6eaed424e0a35":[1,0,1,2,98],
+"classCGAL_1_1Triangulation__3.html#a8766c9a0c2a84203be31537e5e015646":[1,0,1,2,126],
+"classCGAL_1_1Triangulation__3.html#a883fed00b53cae9e85feb20230f54dd9":[1,0,1,2,84],
+"classCGAL_1_1Triangulation__3.html#a89a5c93d1e8a43cef317ef289f1d5482":[1,0,1,2,94],
 "classCGAL_1_1Triangulation__3.html#a8aa85f88733d30aa3ec5385538e13ace":[1,0,1,2,115],
-"classCGAL_1_1Triangulation__3.html#a8bc2a0fa204265bf32f1e6dc103988b4":[1,0,1,2,131],
+"classCGAL_1_1Triangulation__3.html#a8bc2a0fa204265bf32f1e6dc103988b4":[1,0,1,2,130],
 "classCGAL_1_1Triangulation__3.html#a8f2932dc2d9c018421d195757d9c5ffa":[1,0,1,2,58],
+"classCGAL_1_1Triangulation__3.html#a914f44aa77c5096630f94af46f98cab5":[1,0,1,2,160],
+"classCGAL_1_1Triangulation__3.html#a951781437d62955aaae730b87c833498":[1,0,1,2,182],
 "classCGAL_1_1Triangulation__3.html#a95e37032ae2a232c6ac42b114fd7c432":[1,0,1,2,73],
-"classCGAL_1_1Triangulation__3.html#a997be4328927428bce5aee9f775e5e55":[1,0,1,2,101],
-"classCGAL_1_1Triangulation__3.html#a9d997837c2cb5ecca65658ccf6dc3010":[1,0,1,2,94],
-"classCGAL_1_1Triangulation__3.html#a9f0c69f352b9e7fd325980807778b031":[1,0,1,2,61],
+"classCGAL_1_1Triangulation__3.html#a997be4328927428bce5aee9f775e5e55":[1,0,1,2,104],
+"classCGAL_1_1Triangulation__3.html#a9d997837c2cb5ecca65658ccf6dc3010":[1,0,1,2,91],
+"classCGAL_1_1Triangulation__3.html#a9f0c69f352b9e7fd325980807778b031":[1,0,1,2,60],
 "classCGAL_1_1Triangulation__3.html#aa100228164b0cf78d5c2b1009c2df258":[1,0,1,2,14],
 "classCGAL_1_1Triangulation__3.html#aa35974d42ec9564687ffbe5f664cb906":[1,0,1,2,20],
-"classCGAL_1_1Triangulation__3.html#aa43e9ac9d97a9a2fa18ae18e21bb25b3":[1,0,1,2,120],
+"classCGAL_1_1Triangulation__3.html#aa43e9ac9d97a9a2fa18ae18e21bb25b3":[1,0,1,2,119],
 "classCGAL_1_1Triangulation__3.html#aa88be907873b0469824cc3b2212f2eee":[1,0,1,2,36],
 "classCGAL_1_1Triangulation__3.html#aa9814b11ee0a6e024fd3cee4cff066c3":[1,0,1,2,46],
 "classCGAL_1_1Triangulation__3.html#aacfd26fa0d3b2a8b2d8008af3b08930a":[1,0,1,2,49],
@@ -24,34 +28,33 @@ var NAVTREEINDEX1 =
 "classCGAL_1_1Triangulation__3.html#ab250045d0412b06d83977a0c2cf33ff9":[1,0,1,2,24],
 "classCGAL_1_1Triangulation__3.html#ab33c8cdfd6a571cf9635a531d2d261a0":[1,0,1,2,35],
 "classCGAL_1_1Triangulation__3.html#ab5b49dae39468e544c183142169208f1":[1,0,1,2,77],
-"classCGAL_1_1Triangulation__3.html#ab84793de9c9899d8ecc33cdac411d324":[1,0,1,2,134],
+"classCGAL_1_1Triangulation__3.html#ab84793de9c9899d8ecc33cdac411d324":[1,0,1,2,132],
 "classCGAL_1_1Triangulation__3.html#ab930d6f34c8346b5191e93ab79475c70":[1,0,1,2,7],
 "classCGAL_1_1Triangulation__3.html#ab9584da45f55288fb2b9d0624250bbf3":[1,0,1,2,67],
 "classCGAL_1_1Triangulation__3.html#aba04013896bdd4ea1398320869e2d886":[1,0,1,2,57],
-"classCGAL_1_1Triangulation__3.html#abdf765a8077bfc18de39734fbe7ab012":[1,0,1,2,102],
+"classCGAL_1_1Triangulation__3.html#abc8aafe82c32f53203d8d97069ef838d":[1,0,1,2,156],
+"classCGAL_1_1Triangulation__3.html#abdf765a8077bfc18de39734fbe7ab012":[1,0,1,2,101],
 "classCGAL_1_1Triangulation__3.html#abe601aa6506352a8df0877449bcf0dd3":[1,0,1,2,4],
 "classCGAL_1_1Triangulation__3.html#abf51c96f47c1e295fb984ad521634229":[1,0,1,2,92],
-"classCGAL_1_1Triangulation__3.html#ac00984a034bfe3b0f149498143ce76c8":[1,0,1,2,182],
 "classCGAL_1_1Triangulation__3.html#ac076eb6ecdeeeb2b5bf678a21b3d23ee":[1,0,1,2,10],
 "classCGAL_1_1Triangulation__3.html#ac2efcfbc0dcef89c512f65e4d13d4563":[1,0,1,2,185],
 "classCGAL_1_1Triangulation__3.html#ac31682068c1ff25dc5ccd6f366fd1156":[1,0,1,2,87],
-"classCGAL_1_1Triangulation__3.html#ac33649b83bd5c708f5157286cc263c60":[1,0,1,2,156],
 "classCGAL_1_1Triangulation__3.html#ac59a8c8f173db4a1e72b537bb59e16a5":[1,0,1,2,22],
 "classCGAL_1_1Triangulation__3.html#ac69f365fe85f589224868cdfc859c078":[1,0,1,2,163],
-"classCGAL_1_1Triangulation__3.html#ac6bd2d6740346b20377028653111b918":[1,0,1,2,183],
 "classCGAL_1_1Triangulation__3.html#ace9dd63ba3a24d11d9b829198e514535":[1,0,1,2,187],
+"classCGAL_1_1Triangulation__3.html#ad19deb77eb94761e9bf0934f39cb3fa5":[1,0,1,2,159],
 "classCGAL_1_1Triangulation__3.html#ad20bfae1b250b357d8ae5bc48eef1f10":[1,0,1,2,48],
 "classCGAL_1_1Triangulation__3.html#ad3353128386bbb51f79d0263e7f67337":[1,0,1,2,114],
 "classCGAL_1_1Triangulation__3.html#ad5f7bba4f49683befd2f70b35f2d7079":[1,0,1,2,122],
-"classCGAL_1_1Triangulation__3.html#ad66e030d66fdf1ee66e4c280e8894c71":[1,0,1,2,132],
+"classCGAL_1_1Triangulation__3.html#ad66e030d66fdf1ee66e4c280e8894c71":[1,0,1,2,131],
 "classCGAL_1_1Triangulation__3.html#ad8d7a1aa3b310ba8d86ede726746fcb3":[1,0,1,2,111],
 "classCGAL_1_1Triangulation__3.html#ad9890c64030969cd74f35a007cb6b049":[1,0,1,2,99],
 "classCGAL_1_1Triangulation__3.html#adb5f31ae685c84289b0d39c2c1b3cf3b":[1,0,1,2,169],
 "classCGAL_1_1Triangulation__3.html#adc409424d433ef56a79d5e71c02b8e15":[1,0,1,2,37],
 "classCGAL_1_1Triangulation__3.html#adcb08049b8d50168079bbba248f3344d":[1,0,1,2,74],
 "classCGAL_1_1Triangulation__3.html#ae0b4d6177ffbcbd6c6d58820df53b746":[1,0,1,2,161],
-"classCGAL_1_1Triangulation__3.html#ae26c070d4e465b8c6f95d63318080fe7":[1,0,1,2,143],
-"classCGAL_1_1Triangulation__3.html#ae28b76ae0e1f364fc55d1b67f5b57249":[1,0,1,2,165],
+"classCGAL_1_1Triangulation__3.html#ae26c070d4e465b8c6f95d63318080fe7":[1,0,1,2,142],
+"classCGAL_1_1Triangulation__3.html#ae28b76ae0e1f364fc55d1b67f5b57249":[1,0,1,2,164],
 "classCGAL_1_1Triangulation__3.html#ae443600f92d600b8e7d63a7fe2b5220c":[1,0,1,2,144],
 "classCGAL_1_1Triangulation__3.html#ae4a0565708ab5c23639c90c47bbec7cc":[1,0,1,2,33],
 "classCGAL_1_1Triangulation__3.html#ae53e08aa6f86bee125ef6ba075b0e973":[1,0,1,2,6],
@@ -62,7 +65,7 @@ var NAVTREEINDEX1 =
 "classCGAL_1_1Triangulation__3.html#af33632f0d268cc25d0df2caa57f69609":[1,0,1,2,108],
 "classCGAL_1_1Triangulation__3.html#af3ca792eed2f27ccb932d5f67ce4c6b9":[1,0,1,2,76],
 "classCGAL_1_1Triangulation__3.html#af412b76826082617ad5cd7a6428561b0":[1,0,1,2,54],
-"classCGAL_1_1Triangulation__3.html#af41ac521888fafda75100fcd36650aa4":[1,0,1,2,113],
+"classCGAL_1_1Triangulation__3.html#af41ac521888fafda75100fcd36650aa4":[1,0,1,2,112],
 "classCGAL_1_1Triangulation__3.html#af43b5f09e0fdcb9b8fff939133f2e814":[1,0,1,2,80],
 "classCGAL_1_1Triangulation__3.html#af50326c40f34f13a01bb0fd0935301f0":[1,0,1,2,174],
 "classCGAL_1_1Triangulation__3.html#af682021f6f9be1437fe29be125ad14e8":[1,0,1,2,71],
@@ -70,15 +73,15 @@ var NAVTREEINDEX1 =
 "classCGAL_1_1Triangulation__3.html#af8d044953011cb5ff6a5ecf87e6f308e":[1,0,1,2,23],
 "classCGAL_1_1Triangulation__3.html#afb40860f9602b54c62c0b7ad645278d3":[1,0,1,2,70],
 "classCGAL_1_1Triangulation__3.html#afba384e440c57f3bb0a71e4b4f7f9944":[1,0,1,2,175],
-"classCGAL_1_1Triangulation__3.html#afd3ed4f0381fdeefb8a9439caa435b2f":[1,0,1,2,98],
+"classCGAL_1_1Triangulation__3.html#afd3ed4f0381fdeefb8a9439caa435b2f":[1,0,1,2,96],
 "classCGAL_1_1Triangulation__3.html#afe3483443d5cc96aec2f0603095b95f5":[1,0,1,2,154],
 "classCGAL_1_1Triangulation__3.html#aff2c019af34403770e6e922d616eaf0f":[1,0,1,2,1],
 "classCGAL_1_1Triangulation__3.html#aff8be2085c18e293f6d1a26c282acbc7":[1,0,1,2,116],
 "classCGAL_1_1Triangulation__cell__base__3.html":[1,0,3,5],
 "classCGAL_1_1Triangulation__cell__base__with__info__3.html":[1,0,3,6],
-"classCGAL_1_1Triangulation__cell__base__with__info__3.html#a2ae1cf78e256118187274fa863c30f28":[1,0,3,6,1],
+"classCGAL_1_1Triangulation__cell__base__with__info__3.html#a0ae4a36e4f08b539afa78046581172ec":[1,0,3,6,2],
 "classCGAL_1_1Triangulation__cell__base__with__info__3.html#a70db744cb0f0c94766fc3391e73f96c6":[1,0,3,6,0],
-"classCGAL_1_1Triangulation__cell__base__with__info__3.html#ac7473e2a53171845318839e36ba5da04":[1,0,3,6,2],
+"classCGAL_1_1Triangulation__cell__base__with__info__3.html#a880070c5deb5e6df980607d4c563538a":[1,0,3,6,1],
 "classCGAL_1_1Triangulation__simplex__3.html":[1,0,3,7],
 "classCGAL_1_1Triangulation__simplex__3.html#a025ad829a6ac87e7dfbafe912ea90f6d":[1,0,3,7,21],
 "classCGAL_1_1Triangulation__simplex__3.html#a080d9123d1cf85f4e7c9a6a0c067ddfa":[1,0,3,7,13],
@@ -114,10 +117,10 @@ var NAVTREEINDEX1 =
 "classCGAL_1_1Triangulation__vertex__base__3.html#afe933467862407f26c4acf093cb2932c":[1,0,3,8,0],
 "classCGAL_1_1Triangulation__vertex__base__with__info__3.html":[1,0,3,9],
 "classCGAL_1_1Triangulation__vertex__base__with__info__3.html#a21608923f0f2237ebe4dec9bac4429e8":[1,0,3,9,0],
-"classCGAL_1_1Triangulation__vertex__base__with__info__3.html#a454086ccafc2b075af08ca670ebc8970":[1,0,3,9,2],
-"classCGAL_1_1Triangulation__vertex__base__with__info__3.html#a48ef017eb3be9190dcea607632b3449c":[1,0,3,9,1],
+"classCGAL_1_1Triangulation__vertex__base__with__info__3.html#a7e796efdf1cdf008de96bf00a47f9df4":[1,0,3,9,2],
+"classCGAL_1_1Triangulation__vertex__base__with__info__3.html#af8733e79f91a913771938750014f6dcf":[1,0,3,9,1],
 "classDelaunayTriangulationCellBase__3.html":[1,0,0,0],
-"classDelaunayTriangulationCellBase__3.html#a371fa7f48c076fd756f9bb551dbaeb10":[1,0,0,0,1],
+"classDelaunayTriangulationCellBase__3.html#a2d87229baef6bac08d5edc34f9a9c5cc":[1,0,0,0,1],
 "classDelaunayTriangulationCellBase__3.html#ab3336a7ed69363288406841b3b5d25d6":[1,0,0,0,0],
 "classDelaunayTriangulationTraits__3.html":[1,0,0,1],
 "classDelaunayTriangulationTraits__3.html#a03904f260f62776e9523c516a703cd2f":[1,0,0,1,0],
@@ -146,7 +149,7 @@ var NAVTREEINDEX1 =
 "classRegularTriangulationCellBase__3.html#a69eebf04c7667da87f4aba9af13862a7":[1,0,0,2,0],
 "classRegularTriangulationCellBase__3.html#a7558c075b519166e869d80ae03950d31":[1,0,0,2,4],
 "classRegularTriangulationCellBase__3.html#ac532d67ed29ef82a46225fc13142619d":[1,0,0,2,3],
-"classRegularTriangulationCellBase__3.html#adfa0b041ee3723a3b70ea1bc1c6deb17":[1,0,0,2,5],
+"classRegularTriangulationCellBase__3.html#adf0de2ecb1711dde9a36277879590350":[1,0,0,2,5],
 "classRegularTriangulationTraits__3.html":[1,0,0,4],
 "classRegularTriangulationTraits__3.html#a09d0071234b1669d30327154aabc0b90":[1,0,0,4,4],
 "classRegularTriangulationTraits__3.html#a1df35b3e1f34e7c7ba027e0360fe119f":[1,0,0,4,3],
@@ -171,17 +174,17 @@ var NAVTREEINDEX1 =
 "classRegularTriangulationTraits__3.html#aecba519c5776a5c3e7a7afffbeb161eb":[1,0,0,4,0],
 "classRegularTriangulationTraits__3.html#afd96447c4918cc4ac7ab96603d1720fd":[1,0,0,4,21],
 "classRegularTriangulationVertexBase__3.html":[1,0,0,5],
+"classRegularTriangulationVertexBase__3.html#a17dc9c9ef64fbb7468ad4fb04377a61d":[1,0,0,5,3],
 "classRegularTriangulationVertexBase__3.html#a26247e9984cac92a696ab3afb0d29eaf":[1,0,0,5,2],
-"classRegularTriangulationVertexBase__3.html#a3ff901345b8696661d6dbd7d91ec59a2":[1,0,0,5,4],
 "classRegularTriangulationVertexBase__3.html#a62909d9cc28eba54a764d384ae4f99dd":[1,0,0,5,5],
-"classRegularTriangulationVertexBase__3.html#a71bac5186cf10355cabeac6ebc5f127b":[1,0,0,5,3],
+"classRegularTriangulationVertexBase__3.html#a77c8b1412eb4d634e867e1147cf8eea2":[1,0,0,5,4],
 "classRegularTriangulationVertexBase__3.html#aa9defcd8be306fc7263e7f15df7a617e":[1,0,0,5,6],
 "classRegularTriangulationVertexBase__3.html#ac78e0c25a1cde244edcf72a5242e7ea2":[1,0,0,5,0],
 "classRegularTriangulationVertexBase__3.html#ae35d07164502f27be458b759f3b1d008":[1,0,0,5,1],
 "classTriangulationCellBaseWithInfo__3.html":[1,0,0,7],
+"classTriangulationCellBaseWithInfo__3.html#a4685e845e760926599f242bbb582c7d0":[1,0,0,7,2],
+"classTriangulationCellBaseWithInfo__3.html#a717e0c498bf2eb47dad954eace2e8200":[1,0,0,7,1],
 "classTriangulationCellBaseWithInfo__3.html#ab014d34b7f3ab8c2062db9eff9b5fa12":[1,0,0,7,0],
-"classTriangulationCellBaseWithInfo__3.html#abf5f31dc1e2ec747952e3df145f87308":[1,0,0,7,1],
-"classTriangulationCellBaseWithInfo__3.html#ae036dce6f91c9072757508aea833ed1a":[1,0,0,7,2],
 "classTriangulationCellBase__3.html":[1,0,0,6],
 "classTriangulationTraits__3.html":[1,0,0,8],
 "classTriangulationTraits__3.html#a2aaf3971767ce6afe91ba16fdf2d5ff3":[1,0,0,8,4],
@@ -206,35 +209,34 @@ var NAVTREEINDEX1 =
 "classTriangulationTraits__3.html#afb775fc0878f694eb5c93fe12cd35f38":[1,0,0,8,10],
 "classTriangulationVertexBaseWithInfo__3.html":[1,0,0,10],
 "classTriangulationVertexBaseWithInfo__3.html#a064e1358b091f51c902b53f5b58ad8a9":[1,0,0,10,0],
-"classTriangulationVertexBaseWithInfo__3.html#a2d2c0546fd10c73fd2fd55a35ce5240c":[1,0,0,10,1],
-"classTriangulationVertexBaseWithInfo__3.html#a4d776e2648ab29fa664a18615e729b09":[1,0,0,10,2],
+"classTriangulationVertexBaseWithInfo__3.html#a6a39a2bee5f7b4665696eda8e983e872":[1,0,0,10,2],
+"classTriangulationVertexBaseWithInfo__3.html#ad4284eb9c1a57c3cd9fa7b5d498de062":[1,0,0,10,1],
 "classTriangulationVertexBase__3.html":[1,0,0,9],
 "classTriangulationVertexBase__3.html#a1a95465bb7cd97804a94f2f99137dba7":[1,0,0,9,0],
+"classTriangulationVertexBase__3.html#a336efd64870303154dd6f67c37c7a7f0":[1,0,0,9,4],
 "classTriangulationVertexBase__3.html#a853c67c3c3203a8eb4664cd818238907":[1,0,0,9,1],
+"classTriangulationVertexBase__3.html#a8d0d2accd3b79f66bcc0feb6d145fb81":[1,0,0,9,3],
 "classTriangulationVertexBase__3.html#a999bd3683b050159648d930bed6eaf4d":[1,0,0,9,2],
 "classTriangulationVertexBase__3.html#a9d25c1bd36b2d68f942e70420197f711":[1,0,0,9,5],
-"classTriangulationVertexBase__3.html#aac569be63cc961e343e2fdf36adcfc2b":[1,0,0,9,4],
 "classTriangulationVertexBase__3.html#ab7644130787dc7b2ddee101866f53d47":[1,0,0,9,6],
-"classTriangulationVertexBase__3.html#ad433589a50d3488c5f01223802324a4c":[1,0,0,9,3],
 "classWeightedPoint.html":[1,0,0,11],
 "deprecated.html":[2],
-"examples.html":[7],
+"examples.html":[5],
 "group__PkgDrawTriangulation3.html":[1,0,4],
-"group__PkgDrawTriangulation3.html#ga6a09318e75a0fb017c3ee02521f62742":[1,0,4,0],
+"group__PkgDrawTriangulation3.html#ga072412258835c1d7e0e2ddd32eee6537":[1,0,4,3],
+"group__PkgDrawTriangulation3.html#ga6a09318e75a0fb017c3ee02521f62742":[1,0,4,2],
+"group__PkgDrawTriangulation3.html#ga9c5293cdc163d0b89f76fa827b36944d":[1,0,4,0],
+"group__PkgDrawTriangulation3.html#gad19c4dcbe23ac2820bea8cd68c0543e5":[1,0,4,1],
 "group__PkgIOTriangulation3.html":[1,0,5],
-"group__PkgIOTriangulation3.html#ga0c1a9ffba823502938c0c87ff91edbd4":[1,0,1,2,155],
-"group__PkgIOTriangulation3.html#ga0c1a9ffba823502938c0c87ff91edbd4":[1,0,5,1],
-"group__PkgIOTriangulation3.html#gabb84b5cde2cbb8c580790c10f3f0ddbb":[1,0,1,2,158],
-"group__PkgIOTriangulation3.html#gabb84b5cde2cbb8c580790c10f3f0ddbb":[1,0,5,2],
-"group__PkgIOTriangulation3.html#gadd94d0613e2dd9cdd2e88d2c74d5b1c8":[1,0,5,0],
-"group__PkgIOTriangulation3.html#gadd94d0613e2dd9cdd2e88d2c74d5b1c8":[1,0,1,2,65],
+"group__PkgIOTriangulation3.html#ga20493e5839004e16ccd5929397b2ec75":[1,0,5,0],
+"group__PkgIOTriangulation3.html#gaeea8fffe7fd436b5613b31b973f89563":[1,0,5,2],
+"group__PkgIOTriangulation3.html#gaf38f71bfe4880acf5f41844a5204997e":[1,0,5,1],
 "group__PkgTriangulation3Concepts.html":[1,0,0],
 "group__PkgTriangulation3Ref.html":[1,0],
-"group__PkgTriangulation3Ref.html#gaf59573ae46967c944a7a7b0b5790e4e6":[1,0,6],
+"group__PkgTriangulation3Ref.html#ga53546af7121912bb59adcb8801a3e663":[1,0,6],
 "group__PkgTriangulation3TraitsClasses.html":[1,0,2],
 "group__PkgTriangulation3TriangulationClasses.html":[1,0,1],
 "group__PkgTriangulation3VertexCellClasses.html":[1,0,3],
-"hasModels.html":[4],
 "index.html":[0],
 "index.html":[],
 "index.html#Triangulation3Draw":[0,4,11],
@@ -247,7 +249,5 @@ var NAVTREEINDEX1 =
 "index.html#Triangulation3secdesign":[0,3],
 "index.html#Triangulation3secexamples":[0,4],
 "index.html#Triangulation3secexamplescolor":[0,4,1,0],
-"index.html#Triangulation3secintro":[0,0],
-"index.html#Triangulation3seclocpol":[0,3,2],
-"index.html#Triangulation3secsimplex":[0,4,4]
+"index.html#Triangulation3secintro":[0,0]
 };
